ulms.factory('mainFactory', ['lodash', '$http', '$sce', '$timeout', function (lodash, $http, $sce, $timeout) {
    var service = {},
        curriculum = [],
        quizQuestions = [];

    service.labels = {};

    service.currentLesson = {
        lesson_number: '',
        post_id: '',
        title: '',
        subTitle: '',
        text: '',
        embed: '',
        type: '',
        quiz: false
    };

    service.currentQuiz = {
        startText: '',
        finishText: '',
        started: false,
        ended: false,
        duration: false,
        timer: false,
        totalQuestions: 0,
        results: false
    };

    service.courseInfo = {
        link: '',
        myCoursesLink: '',
        preloader: true
    };

    service.getLabels = function () {
        return service.labels;
    };

    service.getCourseInfo = function () {
        return service.courseInfo;
    };

    service.getCurriculum = function () {
        return curriculum;
    };

    service.getCurrentLesson = function () {
        return service.currentLesson;
    };

    service.getCurrentQuiz = function () {
        return service.currentQuiz;
    };

    service.getQuizQuestions = function () {
        return quizQuestions;
    };

    service.setCurriculum = function (newCurriculum) {
        curriculum.length = 0;
        angular.forEach(newCurriculum, function (val) {
            curriculum.push(val);
        });
        var active_lesson = lodash.find(curriculum, {active: true});
        if (active_lesson) {
            service.currentLesson.title = active_lesson.title;
            service.currentLesson.subTitle = lodash.replace(service.labels.currentLessonSubTitle, '%s', active_lesson.lesson_number);
            service.currentLesson.post_id = active_lesson.post_id;
            service.currentLesson.lesson_number = active_lesson.lesson_number;
            service.currentLesson.type = active_lesson.type;
            service.currentLesson.quiz = active_lesson.quiz;
            if (!active_lesson.quiz) {
                service.currentLesson.text = $sce.trustAsHtml(active_lesson.text);
                service.currentLesson.embed = $sce.trustAsHtml(active_lesson.embed);
            } else {
                service.currentQuiz.startText = $sce.trustAsHtml(active_lesson.text);
                service.currentQuiz.finishText = $sce.trustAsHtml(active_lesson.finish_text);
            }
        }

    };

    service.switchLesson = function (id) {
        service.courseInfo.preloader = true;
        var lesson = lodash.find(curriculum, {lesson_number: id});
        if (lesson) {
            $http({
                method: 'POST',
                url: ajaxurl,
                params: {
                    action: 'ulms_lesson_query',
                    lesson_id: lesson.post_id
                }
            }).success(function (data) {
                if (!data['error']) {
                    var current_lesson = lodash.find(curriculum, {active: true});
                    if (current_lesson) {
                        current_lesson.active = false;
                    }
                    lesson.active = true;

                    service.currentLesson.lesson_number = lesson.lesson_number;
                    service.currentLesson.post_id = lesson.post_id;
                    service.currentLesson.title = lesson.title;
                    service.currentLesson.subTitle = lodash.replace(service.labels.currentLessonSubTitle, '%s', lesson.lesson_number);
                    service.currentLesson.type = lesson.type;
                    service.currentLesson.quiz = lesson.quiz;

                    if (!data['quiz']) {
                        service.currentLesson.text = $sce.trustAsHtml(data['text']);
                        service.currentLesson.embed = $sce.trustAsHtml(data['embed']);
                    } else {
                        service.currentQuiz.startText = $sce.trustAsHtml(data['text']);
                        service.currentQuiz.finishText = $sce.trustAsHtml(data['finish_text']);
                        var passed_quiz = lodash.find(curriculum, {post_id: lesson.post_id, passed: true});
                        if (passed_quiz) {
                            service.currentQuiz.started = true;
                            service.currentQuiz.ended = true;
                            if (data['quiz_results']) {
                                service.currentQuiz.results = data['quiz_results'];
                            }
                        } else {
                            service.currentQuiz.started = false;
                            service.currentQuiz.ended = false;
                        }
                    }

                    jQuery('body,html').animate({
                        scrollTop: jQuery(".lessons-page .lesson-title-num").offset().top - 50
                    }, 500);

                } else {
                    console.log(data['error']);
                }
                service.courseInfo.preloader = false;
            });
        }
    };

    service.lessonComplete = function () {
        service.courseInfo.preloader = true;
        $http({
            method: 'POST',
            url: ajaxurl,
            params: {
                action: 'ulms_lesson_complete',
                lesson_id: service.currentLesson.post_id
            }
        }).success(function (data) {
            if (!data['error']) {
                var lesson_index = lodash.findIndex(curriculum, {lesson_number: service.currentLesson.lesson_number});
                if (lesson_index != -1) {
                    curriculum[lesson_index].passed = true;
                    if (curriculum[lesson_index + 2]) {
                        service.switchLesson(lesson_index + 2);
                    }else{
                        service.isCourseCompleted();
                    }
                } else {
                    service.courseInfo.preloader = false;
                }
            } else {
                console.log(data['error']);
            }
        });
    };

    service.lessonUncomplete = function () {
        service.courseInfo.preloader = true;
        $http({
            method: 'POST',
            url: ajaxurl,
            params: {
                action: 'ulms_lesson_uncomplete',
                lesson_id: service.currentLesson.post_id
            }
        }).success(function (data) {
            if (!data['error']) {
                var lesson_index = lodash.findIndex(curriculum, {lesson_number: service.currentLesson.lesson_number});
                if (lesson_index != -1) {
                    curriculum[lesson_index].passed = false;
                }
                service.courseInfo.preloader = false;
            } else {
                console.log(data['error']);
            }
        });
    };

    service.isLessonCompleled = function () {
        var lesson = curriculum[service.currentLesson.lesson_number - 1];
        if( lesson.passed ){
            return true;
        }else{
            return false;
        }
    };

    service.nextLesson = function (status) {
        var next_lesson_id = service.currentLesson.lesson_number;
        var lesson = lodash.find(curriculum, {lesson_number: next_lesson_id + 1});
        if( lesson ){
            if( ! status ){
                service.switchLesson(lesson.lesson_number);
            }else{
                return true;
            }
        }else{
            if( status ) {
                return false;
            }
        }
    };

    service.prevLesson = function (status) {
        var prev_lesson_id = service.currentLesson.lesson_number;
        var lesson = lodash.find(curriculum, {lesson_number: prev_lesson_id - 1});
        if( lesson ){
            if( ! status ){
                service.switchLesson(lesson.lesson_number);
            }else{
                return true;
            }
        }else{
            if( status ) {
                return false;
            }
        }
    };

    service.isCourseCompleted = function () {
        var not_passed_lesson = lodash.findIndex(curriculum, {passed: false});
        if (not_passed_lesson != -1) {
            service.switchLesson(not_passed_lesson + 1);
        } else {
            window.location.href = service.courseInfo.myCoursesLink;
        }
    };


    // Quiz

    service.quizStart = function () {
        service.courseInfo.preloader = true;
        $http({
            method: 'POST',
            url: ajaxurl,
            params: {
                action: 'ulms_start_quiz',
                quiz_id: service.currentLesson.post_id
            }
        }).success(function (data) {
            if (!data['error']) {
                service.currentQuiz.duration = data['duration'];
                service.currentQuiz.timer = data['duration'];
                service.currentQuiz.totalQuestions = data['total_questions'];
                quizQuestions.length = 0;
                if (data['questions']) {
                    angular.forEach(data['questions'], function (val) {
                        quizQuestions.push(val);
                    });
                }
                service.currentQuiz.started = true;
            } else {
                console.log(data['error']);
            }
            service.courseInfo.preloader = false;
        });
    };

    service.quizNextQuestion = function () {
        var active_question_index = lodash.findIndex(quizQuestions, {active: true});
        var inactive_question_index = lodash.findIndex(quizQuestions, {active: false});
        var new_question = quizQuestions[active_question_index + 1];
        if (!new_question) {
            new_question = quizQuestions[inactive_question_index];
        }
        quizQuestions[active_question_index].active = false;
        if (new_question) {
            new_question.active = true;
        }
    };

    service.quizGoToQuestion = function (question_index) {
        var active_question_index = lodash.findIndex(quizQuestions, {active: true});
        quizQuestions[active_question_index].active = false;
        quizQuestions[question_index].active = true;
    };

    service.getQuizCurrentQuestion = function () {
        var obj = {};
        var current_question = currentQuizQuestion();
        if (current_question) {
            obj.id = current_question.id;
            obj.number = current_question.number;
            obj.title = current_question.title;
            obj.quizQuestionsNum = lodash.replace(service.labels.quizQuestionsNum, '%1$d', current_question.number);
            obj.quizQuestionsNum = lodash.replace(obj.quizQuestionsNum, '%2$d', service.currentQuiz.totalQuestions);
            obj.options = current_question.options;
            obj.point = current_question.point;
            obj.answered = current_question.answered;
            obj.hint = current_question.hint;
            obj.isCorrect = current_question.isCorrect;
            obj.correctAnswer = current_question.correctAnswer;
            obj.passed = current_question.passed;
        }
        return obj;
    };

    service.quizAnswerQuestion = function () {
        service.courseInfo.preloader = true;
        $http({
            method: 'POST',
            url: ajaxurl,
            params: {
                action: 'ulms_check_quiz_answer',
                quiz_id: service.currentLesson.post_id,
                question_number: currentQuizQuestion().number,
                question_id: currentQuizQuestion().id,
                answered: currentQuizQuestion().answered
            }
        }).success(function (data) {
            if (!data['error']) {
                if (data['correct_answer']) {
                    var active_question_index = lodash.findIndex(quizQuestions, {active: true});
                    quizQuestions[active_question_index].passed = true;
                    if (data['correct_answer'] == currentQuizQuestion().answered) {
                        quizQuestions[active_question_index].isCorrect = true;
                    } else {
                        quizQuestions[active_question_index].isCorrect = false;
                    }
                    quizQuestions[active_question_index].correctAnswer = data['correct_answer'];
                    $timeout(function () {
                        service.quizNextQuestion();
                    }, 1000);
                }
            } else {
                console.log(data['error']);
            }
            service.courseInfo.preloader = false;
        });
    };

    service.markAnswer = function (option_id) {
        var current_question_index = lodash.findIndex(quizQuestions, {active: true});
        quizQuestions[current_question_index].answered = option_id;
    };

    var currentQuizQuestion = function () {
        return lodash.find(quizQuestions, {active: true});
    };

    service.finishQuiz = function () {
        service.courseInfo.preloader = true;
        $http({
            method: 'POST',
            url: ajaxurl,
            params: {
                action: 'ulms_get_quiz_results',
                time_spent: service.currentQuiz.duration - service.currentQuiz.timer,
                quiz_id: service.currentLesson.post_id
            }
        }).success(function (data) {
            if (!data['error']) {
                service.currentQuiz.ended = true;
                if (data['quiz_results']) {
                    service.currentQuiz.results = data['quiz_results'];
                }
                var quiz_index = lodash.findIndex(curriculum, {lesson_number: service.currentLesson.lesson_number});
                if (quiz_index != -1) {
                    curriculum[quiz_index].passed = true;
                }
            } else {
                console.log(data['error']);
            }
            service.courseInfo.preloader = false;
        });
    };

    return service;
}]);