<?php

if ( ! function_exists( 'ulms_session_init' ) ) {
	function ulms_session_init() {
		if ( ! session_id() ) {
			session_start();
		}
	}
}

add_action('init', 'ulms_session_init', 1);


$theme_info = wp_get_theme();

if ( ! defined( 'ULMS_THEME_VERSION' ) ) {
	define( 'ULMS_THEME_VERSION', ( WP_DEBUG ) ? time() : $theme_info->get( 'Version' ) );
}
if ( ! defined( 'ULMS_INC_PATH' ) ) {
	define( 'ULMS_INC_PATH', get_template_directory() . '/includes' );
}
if ( ! defined( 'ULMS_COURSES_POST_TYPE' ) ) {
	define( 'ULMS_COURSES_POST_TYPE', 'ulms_courses' );
}
if ( ! defined( 'ULMS_GROUPS_POST_TYPE' ) ) {
	define( 'ULMS_GROUPS_POST_TYPE', 'ulms_groups' );
}
if ( ! defined( 'ULMS_COURSES_LESSONS_POST_TYPE' ) ) {
	define( 'ULMS_COURSES_LESSONS_POST_TYPE', 'ulms_lessons' );
}
if ( ! defined( 'ULMS_COURSES_QUIZ_POST_TYPE' ) ) {
	define( 'ULMS_COURSES_QUIZ_POST_TYPE', 'ulms_quiz' );
}
if ( ! defined( 'ULMS_COURSES_QUESTION_POST_TYPE' ) ) {
	define( 'ULMS_COURSES_QUESTION_POST_TYPE', 'ulms_question' );
}
if ( ! defined( 'ULMS_VACANCY_POST_TYPE' ) ) {
	define( 'ULMS_VACANCY_POST_TYPE', 'ulms_vacancy' );
}
if ( ! defined( 'ULMS_TESTIMONIALS_POST_TYPE' ) ) {
	define( 'ULMS_TESTIMONIALS_POST_TYPE', 'ulms_testimonials' );
}
if ( ! defined( 'ULMS_USER_COMMENTS_POST_TYPE' ) ) {
	define( 'ULMS_USER_COMMENTS_POST_TYPE', 'ulms_user_comments' );
}
if ( ! defined( 'ULMS_COURSE_CATEGORY_SLUG' ) ) {
	define( 'ULMS_COURSE_CATEGORY_SLUG', 'ulms_courses_categories' );
}
if ( ! defined( 'ULMS_COURSE_LANGUAGES_CATEGORY_SLUG' ) ) {
	define( 'ULMS_COURSE_LANGUAGES_CATEGORY_SLUG', 'ulms_courses_languages' );
}
if ( ! defined( 'ULMS_TEACHERS_ROLE' ) ) {
	define( 'ULMS_TEACHERS_ROLE', 'ulms_instructor' );
}
if ( ! defined( 'ULMS_STUDENT_ROLE' ) ) {
	define( 'ULMS_STUDENT_ROLE', 'ulms_student' );
}
$upload_dir = wp_upload_dir();
if ( ! defined( 'ULMS_UPLOAD_DIR' ) ) {
	define( 'ULMS_UPLOAD_DIR', $upload_dir['basedir'] . '/runa-uploads' );
}
if ( ! defined( 'ULMS_UPLOAD_URL' ) ) {
	define( 'ULMS_UPLOAD_URL', $upload_dir['baseurl'] . '/runa-uploads' );
}

// Disable WMPL LANGUAGE SELECTOR CSS
define( 'ICL_DONT_LOAD_LANGUAGE_SELECTOR_CSS', true );

if ( ! isset( $content_width ) ) {
	$content_width = 1120;
}


if ( ! function_exists( 'ulms_theme_setup' ) ) {

	function ulms_theme_setup() {

		load_theme_textdomain( 'ulms', get_template_directory() . '/languages' );

		add_theme_support( 'woocommerce' );
		add_theme_support( 'post-thumbnails' );
		add_theme_support( 'title-tag' );
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption'
		) );

		add_role( ULMS_TEACHERS_ROLE, esc_html__( 'Instructor', 'ulms' ), array( 'read' => true ) );
		add_role( ULMS_STUDENT_ROLE, esc_html__( 'Student', 'ulms' ), array( 'read' => true ) );

		add_image_size( 'ulms-345x234-cropped', 345, 234, true );
		add_image_size( 'ulms-370x208-cropped', 370, 208, true );
		add_image_size( 'ulms-870x440-cropped', 870, 440, true );
		add_image_size( 'ulms-230x177-cropped', 230, 177, true );
		add_image_size( 'ulms-870x490-cropped', 870, 490, true );
		add_image_size( 'ulms-270x200-cropped', 270, 203, true );
		add_image_size( 'ulms-370x400-cropped', 370, 400, true );
		add_image_size( 'ulms-70x70-cropped', 70, 70, true );

		register_nav_menus(
			array(
				'ulms-primary_menu' => esc_html__( 'Top Menu', 'ulms' ),
				'ulms-footer_menu'  => esc_html__( 'Footer Menu', 'ulms' )
			)
		);

	}

}

add_action( 'after_setup_theme', 'ulms_theme_setup' );


if ( ! function_exists( 'ulms_register_sidebars' ) ) {
	function ulms_register_sidebars() {
		register_sidebar( array(
			'id'            => 'ulms-right-sidebar',
			'name'          => esc_html__( 'Right Sidebar', 'ulms' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h3 class="widget-title"><span class="title">',
			'after_title'   => '</span><span class="widget-title-line"></span></h3>',
		) );

		register_sidebar( array(
			'id'            => 'ulms-left-sidebar',
			'name'          => esc_html__( 'Left Sidebar', 'ulms' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h3 class="widget-title"><span class="title">',
			'after_title'   => '</span><span class="widget-title-line"></span></h3>',
		) );

		register_sidebar( array(
			'id'            => 'ulms-course-sidebar',
			'name'          => esc_html__( 'Course Sidebar', 'ulms' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h3 class="widget-title"><span class="title">',
			'after_title'   => '</span><span class="widget-title-line"></span></h3>',
		) );

		register_sidebar( array(
			'id'            => 'ulms-shop-sidebar',
			'name'          => esc_html__( 'Shop Sidebar', 'ulms' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h3 class="widget-title"><span class="title">',
			'after_title'   => '</span><span class="widget-title-line"></span></h3>',
		) );

		// Register Footer Sidebars
		for ( $footer = 1; $footer < 5; $footer ++ ) {
			register_sidebar( array(
				'id'            => 'ulms-footer-' . $footer,
				'name'          => esc_html__( 'Footer ', 'ulms' ) . $footer,
				'before_widget' => '<section id="%1$s" class="widget %2$s">',
				'after_widget'  => '</section>',
				'before_title'  => '<h3 class="widget-title">',
				'after_title'   => '</h3>',
			) );
		}
	}
}

add_action( 'widgets_init', 'ulms_register_sidebars', 50 );


if ( ! function_exists( 'ulms_wp_footer' ) ) {
	function ulms_wp_footer() {
		if ( ulms_option( 'frontend_customizer_enabled' ) ) {
			get_template_part( 'template-parts/frontend-customizer' );
		}
	}
}

add_action( 'wp_footer', 'ulms_wp_footer' );


if ( ! function_exists( 'ulms_load_scripts_and_styles' ) ) {
	function ulms_load_scripts_and_styles() {

		if ( ! is_admin() ) {

			global $wp_filesystem;

			if ( empty( $wp_filesystem ) ) {
				require_once ABSPATH . '/wp-admin/includes/file.php';
				WP_Filesystem();
			}


			/* Enqueue Styles */
			wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.min.css', null, ULMS_THEME_VERSION, 'all' );
			wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/assets/css/font-awesome.min.css', null, ULMS_THEME_VERSION, 'all' );
			wp_enqueue_style( 'jquery.fancybox', get_template_directory_uri() . '/assets/css/jquery.fancybox.css', null, ULMS_THEME_VERSION, 'all' );
			wp_enqueue_style( 'ulms-icons', get_template_directory_uri() . '/assets/css/ulms-icons.css', null, ULMS_THEME_VERSION, 'all' );
			wp_enqueue_style( 'ulms-default-font', ulms_fonts_url(), array(), ULMS_THEME_VERSION, 'all' );

			if ( $wp_filesystem->is_dir( ULMS_UPLOAD_DIR ) && ulms_option( 'color_skin', 'skin-1' ) != 'skin-1' ) {
				wp_enqueue_style( 'ulms-style', ULMS_UPLOAD_URL . '/style-' . ulms_option( 'color_skin', 'skin-1' ) . '.css', array(), ULMS_THEME_VERSION );
			} else {
				wp_enqueue_style( 'ulms-style', get_stylesheet_uri(), null, ULMS_THEME_VERSION, 'all' );
			}


			/* Enqueue Scripts */
			if ( ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) || ( is_author() && get_option( 'thread_comments' ) ) ) {
				wp_enqueue_script( 'comment-reply' );
			}

			wp_enqueue_script( 'ulms-script', get_template_directory_uri() . '/assets/js/all.min.js', array( 'jquery' ), ULMS_THEME_VERSION, true );

			if( ulms_option( 'facebook_client_id' ) ) {
				wp_add_inline_script( 'ulms-script', '
					window.fbAsyncInit = function() {
						FB.init({
							appId   : ' . esc_js( ulms_option( 'facebook_client_id' ) ) . ',
							xfbml   : true,
							version : "v2.6"
						});
					};
			
					(function(d, s, id){
						var js, fjs = d.getElementsByTagName(s)[0];
						if (d.getElementById(id)) {return;}
						js = d.createElement(s); js.id = id;
						js.src = "//connect.facebook.com/en_US/sdk.js";
						fjs.parentNode.insertBefore(js, fjs);
					}(document, "script", "facebook-jssdk"));
				');
			}


			if( ulms_option( 'frontend_customizer_enabled' ) ){
				wp_enqueue_script( 'ulms-frontend-customizer', get_template_directory_uri() . '/assets/js/frontend-customizer.js', array( 'jquery' ), ULMS_THEME_VERSION, true );
			}

			wp_localize_script( 'ulms-script', 'ajaxurl', admin_url( 'admin-ajax.php' ) );

			wp_localize_script( 'ulms-script', 'localized',
				array(
					'partials_url'  => get_template_directory_uri() . '/template-parts/ng-templates/',
					'partials_path' => parse_url( get_template_directory_uri() . '/template-parts/ng-templates/' )['path'],
					'upload_dir'    => ULMS_UPLOAD_URL
				)
			);
		}

	}
}

add_action( 'wp_enqueue_scripts', 'ulms_load_scripts_and_styles' );


if( ! function_exists( 'ulms_admin_styles' ) ){
	function ulms_admin_styles() {

		/* Enqueue Admin Styles */
		wp_enqueue_style( 'ulms-admin-style', get_template_directory_uri() . '/assets/css/admin/admin.min.css', null, ULMS_THEME_VERSION, 'all' );
		wp_enqueue_style( 'ulms-icons', get_template_directory_uri() . '/assets/css/ulms-icons.css', null, ULMS_THEME_VERSION, 'all' );
		wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/assets/css/font-awesome.min.css', null, ULMS_THEME_VERSION, 'all' );

		/* Enqueue Admin Scripts */
		wp_enqueue_media();
		wp_enqueue_script( 'jquery-ui-sortable' );
		wp_enqueue_script( 'ulms-admin-script', get_template_directory_uri() . '/assets/js/admin/admin.min.js', array( 'jquery' ), ULMS_THEME_VERSION, true );
		wp_enqueue_script( 'ulms-admin-custom-script', get_template_directory_uri() . '/assets/js/admin/custom.js', array( 'jquery' ), ULMS_THEME_VERSION, true );

		wp_localize_script( 'ulms-admin-script', 'ulms_icons_array', ulms_get_icons_array() );

	}
}

add_action( 'admin_enqueue_scripts', 'ulms_admin_styles' );


if ( ! function_exists( 'ulms_body_class' ) ) {
	function ulms_body_class( $classes ) {
		$post_id        = get_the_ID();
		$page_for_posts = get_option( 'page_for_posts' );
		if ( is_home() || is_category() || is_search() || is_tag() || is_tax() ) {
			$post_id = $page_for_posts;
		}

		if ( ! empty( $post_id ) && get_post_meta( $post_id, 'enable_transparent_header', true ) ) {
			$classes[] = 'header_transparent';
		}
		if ( ! empty( $post_id ) && get_post_meta( $post_id, 'enable_cta', true ) ) {
			$classes[] = 'has_cta';
		}
		$classes[] = ulms_get_header_style();

		$classes[] = ulms_option( 'header_mode', 'header-mode-static' );

		if ( ulms_option( 'boxed_layout', false ) ) {
			$classes[] = 'boxed-layout';
			$bg_image  = ulms_option( 'layout_bg_image', 'example-bg-1' );
			if ( $bg_image && $bg_image != 'custom' ) {
				$classes[] = $bg_image;
			}
		}

		return $classes;
	}
}

add_filter( 'body_class', 'ulms_body_class' );


if( ! function_exists( 'ulms_excerpt_more' ) ){
	function ulms_excerpt_more() {
		return '';
	}
}

add_filter( 'excerpt_more', 'ulms_excerpt_more' );


require_once( ULMS_INC_PATH . '/class-tgm-plugin-activation.php' );
require_once( ULMS_INC_PATH . '/ulms-tgm.php' );
require_once( ULMS_INC_PATH . '/redux-config.php' );
require_once( ULMS_INC_PATH . '/ulms-functions.php' );
require_once( ULMS_INC_PATH . '/ulms-breadcrumbs-navxt.php' );
require_once( ULMS_INC_PATH . '/ulms-account-functions.php' );
require_once( ULMS_INC_PATH . '/ulms-demo-import.php' );
require_once( ULMS_INC_PATH . '/ulms-custom-colors.php' );
if ( class_exists( 'WooCommerce' ) ) {
	require_once( ULMS_INC_PATH . '/ulms-woo.php' );
}
require_once( ULMS_INC_PATH . '/class-users.php' );
require_once( ULMS_INC_PATH . '/class-courses.php' );
require_once( ULMS_INC_PATH . '/class-course-status.php' );
require_once( ULMS_INC_PATH . '/class-groups.php' );
require_once( ULMS_INC_PATH . '/class-lessons.php' );
require_once( ULMS_INC_PATH . '/class-quizzes.php' );
require_once( ULMS_INC_PATH . '/class-questions.php' );
require_once( ULMS_INC_PATH . '/class-page-post-settings.php' );
require_once( ULMS_INC_PATH . '/class-testimonials.php' );
require_once( ULMS_INC_PATH . '/vc-config.php' );
require_once( ULMS_INC_PATH . '/walkers/class-ulms-walker-category.php' );
require_once( ULMS_INC_PATH . '/widgets/class-ulms-widget-contacts.php' );
require_once( ULMS_INC_PATH . '/widgets/class-ulms-widget-recent-posts.php' );
require_once( ULMS_INC_PATH . '/widgets/class-ulms-widget-course-categories.php' );
require_once( ULMS_INC_PATH . '/ulms-print-styles.php' );