<?php

class Runa_Course_Status extends Runa_Courses {

	private static $_instance = null;

	public static function getInstance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}

		return self::$_instance;
	}

	public function __construct() {
		add_action( 'wp_ajax_ulms_course_status_data', array( $this, 'course_status_data' ) );
		add_action( 'wp_ajax_nopriv_ulms_course_status_data', array( $this, 'course_status_data' ) );

		add_action( 'wp_ajax_ulms_lesson_query', array( $this, 'lesson_query' ) );
		add_action( 'wp_ajax_nopriv_ulms_lesson_query', array( $this, 'lesson_query' ) );

		add_action( 'wp_ajax_ulms_lesson_complete', array( $this, 'lesson_complete' ) );
		add_action( 'wp_ajax_nopriv_ulms_lesson_complete', array( $this, 'lesson_complete' ) );

		add_action( 'wp_ajax_ulms_lesson_uncomplete', array( $this, 'lesson_uncomplete' ) );
		add_action( 'wp_ajax_nopriv_ulms_lesson_uncomplete', array( $this, 'lesson_uncomplete' ) );

		add_action( 'wp_ajax_ulms_start_quiz', array( $this, 'start_quiz' ) );
		add_action( 'wp_ajax_nopriv_ulms_start_quiz', array( $this, 'start_quiz' ) );

		add_action( 'wp_ajax_ulms_check_quiz_answer', array( $this, 'check_quiz_answer' ) );
		add_action( 'wp_ajax_nopriv_ulms_check_quiz_answer', array( $this, 'check_quiz_answer' ) );

		add_action( 'wp_ajax_ulms_get_quiz_results', array( $this, 'get_quiz_results' ) );
		add_action( 'wp_ajax_nopriv_ulms_get_quiz_results', array( $this, 'get_quiz_results' ) );
	}

	public function accessChecker( $lesson_id = '' ){
		$user_id = get_current_user_id();

		if( ! $user_id || empty( $_COOKIE['course_id'] ) ){
			return false;
		}

		$course_data = $this->get_course( $_COOKIE['course_id'] );

		if( ! $course_data ){
			return false;
		}

		$user_courses = ( get_user_meta( $user_id, 'courses', true ) ) ? get_user_meta( $user_id, 'courses', true ) : array();

		if ( empty( $user_courses[ $_COOKIE['course_id'] ] ) ) {
			return false;
		}

		if( $lesson_id !== '' ){
			if ( ! $lesson_id ) {
				return false;
			}
			if ( ! get_post( $lesson_id ) ) {
				return false;
			}
			if ( ! in_array( $lesson_id, $course_data['curriculum'] ) ) {
				return false;
			}
		}

		return true;
	}

	public function course_status_data(){
		$data = array();

		if( ! $this->accessChecker() ){
			$data['error'] = esc_html__( 'access denied', 'ulms' );
			echo json_encode( $data );
			exit;
		}

		$data['strings'] = array(
			'lessonComplete'          => esc_html__( 'Lesson Complete', 'ulms' ),
			'markAsUncompleted'       => esc_html__( 'Mark as uncompleted', 'ulms' ),
			'backToCourse'            => esc_html__( 'Back To Course', 'ulms' ),
			'currentLessonSubTitle'   => esc_html__( 'Lesson %s', 'ulms' ),
			'description'             => esc_html__( 'Description', 'ulms' ),
			'quizQuestionsNum'        => esc_html__( 'Question %1$d of %2$d:', 'ulms' ),
			'points'                  => esc_html__( 'points', 'ulms' ),
			'startQuiz'               => esc_html__( 'Start Quiz', 'ulms' ),
			'finishQuiz'              => esc_html__( 'Finish Quiz', 'ulms' ),
			'quizOptionsInstructions' => esc_html__( 'Choose Correct Answer', 'ulms' ),
			'hint'                    => esc_html__( 'Hint', 'ulms' ),
			'answerQuestion'          => esc_html__( 'Answer question', 'ulms' ),
			'skip'                    => esc_html__( 'Skip', 'ulms' ),
			'nextQuestion'            => esc_html__( 'Next Question', 'ulms' ),
			'nextLesson'              => esc_html__( 'Next Lesson', 'ulms' ),
			'prevLesson'              => esc_html__( 'Previous Lesson', 'ulms' ),
			'retakeQuiz'              => esc_html__( 'Retake Quiz', 'ulms' ),
			'quizReport'              => esc_html__( 'Quiz Report', 'ulms' ),
			'markedAnswer'            => esc_html__( 'Marked Answer', 'ulms' ),
			'correctAnswer'           => esc_html__( 'Correct Answer', 'ulms' ),
			'correctlyAnswered'       => esc_html__( 'You have answered correctly', 'ulms' ),
			'quizSummary'             => esc_html__( 'Quiz Summary:', 'ulms' ),
			'didntPassed'             => esc_html__( 'Didn\'t Passed', 'ulms' ),
			'passedSuccessfully'      => esc_html__( 'Passed Successfully', 'ulms' ),
			'passed'                  => esc_html__( 'Passed', 'ulms' ),
			'questions'               => esc_html__( 'Questions', 'ulms' ),
			'correctAnswers'          => esc_html__( 'Correct Answers', 'ulms' ),
			'pointsObtained'          => esc_html__( 'Points Obtained', 'ulms' ),
			'minRequiredPoints'       => esc_html__( 'Min required points', 'ulms' ),
			'timeSpent'               => esc_html__( 'Time Spent', 'ulms' ),
			'quizWasntPassed'         => esc_html__( 'Quiz wasn\'t passed', 'ulms' ),
			'quizWasPassed'           => esc_html__( 'Quiz was passed', 'ulms' ),
			'correct'                 => esc_html__( 'correct', 'ulms' ),
			'notAnswered'             => esc_html__( 'Not Answered', 'ulms' ),
			'sec'                     => esc_html__( 'sec', 'ulms' ),
			'min'                     => esc_html__( 'min', 'ulms' ),
			'hour'                    => esc_html__( 'hour', 'ulms' ),
		);

		$curriculum = array();

		$course_data = $this->get_course( $_COOKIE['course_id'] );
		if( ! empty( $course_data['curriculum'] ) ){
			$i = $o = 0;
			$user_id = get_current_user_id();
			$user_courses = get_user_meta( $user_id, 'courses', true );

			// Clear course state
//			unset($user_courses[$_COOKIE['course_id']]['passed_lessons']);
//			update_user_meta( $user_id, 'courses', $user_courses );

			foreach ( $course_data['curriculum'] as $val ){
				$lesson = get_post( $val );
				if( $lesson ){
					$i++;
					$curriculum[ $i ] = array(
						'lesson_number' => $i,
						'post_id'       => $val,
						'title'         => $lesson->post_title,
						'type'          => ( get_post_meta( $val, 'lesson_type', true ) ? get_post_meta( $val, 'lesson_type', true ) : 'general' ),
						'passed'        => false,
						'quiz'          => false
					);
					if ( ! empty( $user_courses[ $_COOKIE['course_id'] ]['passed_lessons'] ) && in_array( $val, $user_courses[ $_COOKIE['course_id'] ]['passed_lessons'] ) ) {
						$curriculum[$i]['passed'] = true;
					}
					if( $o == 0 && $curriculum[$i]['passed'] == false ){
						$o                          = true;
						$curriculum[ $i ]['text']   = apply_filters( 'the_content', $lesson->post_content );
						$curriculum[ $i ]['embed']  = get_post_meta( $val, 'lesson_embed', true );
						$curriculum[ $i ]['active'] = true;
					}
					if( get_post_type( $val ) == ULMS_COURSES_QUIZ_POST_TYPE ){
						$curriculum[ $i ]['quiz']        = true;
						$curriculum[ $i ]['finish_text'] = apply_filters( 'the_content', get_post_meta( $val, 'quiz_final_message', true ) );
					}
				}
			}

			if( ! in_array( 'active', $curriculum ) ){
				$lesson = get_post( $curriculum[1]['post_id'] );
				$curriculum[1]['active'] = true;
				$curriculum[1]['text']   = apply_filters( 'the_content', $lesson->post_content );
				$curriculum[1]['embed']  = get_post_meta( $curriculum[1]['post_id'], 'lesson_embed', true );
			}

			if ( $curriculum ) {
				$data['curriculum'] = $curriculum;
			}

		}else{
			$data['error'] = esc_html__( 'curriculum not found', 'ulms' );
		}

		$account_url = wc_get_page_permalink( 'myaccount' );
		$data['course_link'] = get_the_permalink( $_COOKIE['course_id'] );
		$data['my_courses_link'] = esc_url( wc_get_endpoint_url( 'my-courses', '', $account_url ) );

		echo json_encode( $data );
		exit;
	}

	public function lesson_query(){
		$data = array();
		$lesson_id = $_REQUEST['lesson_id'] ? $_REQUEST['lesson_id'] : false;

		if( ! $this->accessChecker( $lesson_id ) ){
			$data['error'] = esc_html__( 'access denied' , 'ulms');
			echo json_encode( $data );
			exit;
		}

		$lesson        = get_post( $lesson_id );
		$data['text']  = apply_filters( 'the_content', $lesson->post_content );
		$data['embed'] = get_post_meta( $lesson_id, 'lesson_embed', true );

		if ( get_post_type( $lesson_id ) == ULMS_COURSES_QUIZ_POST_TYPE ) {
			$data['quiz']        = true;
			$data['finish_text'] = apply_filters( 'the_content', get_post_meta( $lesson_id, 'quiz_final_message', true ) );
		}

		$user_id = get_current_user_id();
		$user_quiz_result = get_user_meta( $user_id, 'quiz_result_' . $_COOKIE['course_id'] . '-' . $lesson_id, true );

		if( $user_quiz_result ){
			$data['quiz_results'] = $user_quiz_result;
		}

		echo json_encode( $data );
		exit;
	}

	public function lesson_complete(){
		$data = array();
		$lesson_id = $_REQUEST['lesson_id'] ? $_REQUEST['lesson_id'] : false;

		if( ! $this->accessChecker( $lesson_id ) ){
			$data['error'] = esc_html__( 'access denied', 'ulms' );
			echo json_encode( $data );
			exit;
		}

		$user_id = get_current_user_id();
		$user_courses = get_user_meta( $user_id, 'courses', true );
		$user_courses[ $_COOKIE['course_id'] ]['passed_lessons'][] = $lesson_id;
		update_user_meta( $user_id, 'courses', $user_courses );

		echo json_encode( $data );
		exit;
	}

	public function lesson_uncomplete(){
		$data = array();
		$lesson_id = $_REQUEST['lesson_id'] ? $_REQUEST['lesson_id'] : false;

		if( ! $this->accessChecker( $lesson_id ) ){
			$data['error'] = esc_html__( 'access denied', 'ulms' );
			echo json_encode( $data );
			exit;
		}

		$user_id = get_current_user_id();
		$user_courses = get_user_meta( $user_id, 'courses', true );
		$passed_lesson_key = array_search( $lesson_id, $user_courses[ $_COOKIE['course_id'] ]['passed_lessons'] );
		if( $passed_lesson_key !== false ){
			unset( $user_courses[ $_COOKIE['course_id'] ]['passed_lessons'][ $passed_lesson_key ] );
		}
		update_user_meta( $user_id, 'courses', $user_courses );

		echo json_encode( $data );
		exit;
	}

	public function start_quiz(){
		$data = array();

		$quiz_id = $_REQUEST['quiz_id'] ? $_REQUEST['quiz_id'] : false;

		if( ! $this->accessChecker( $quiz_id ) ){
			$data['error'] = esc_html__( 'access denied', 'ulms' );
			echo json_encode( $data );
			exit;
		}

		$quiz_duration = get_post_meta( $quiz_id, 'quiz_duration', true ) ? get_post_meta( $quiz_id, 'quiz_duration', true ) : 1;
		$quiz_duration_parameter = get_post_meta( $quiz_id, 'quiz_duration_parameter', true ) ? get_post_meta( $quiz_id, 'quiz_duration_parameter', true ) : 1;
		$data['duration'] = $quiz_duration * $quiz_duration_parameter;
		$data['questions'] = array();
		$questions = get_post_meta( $quiz_id, 'quiz_questions', true );
		$total_points = 0;
		if( $questions ){
			$i = 0;
			foreach ($questions as $question){ $i++;
				$data['questions'][ $i ] = array(
					'id'      => $question['question_id'],
					'number'  => $i,
					'title'   => get_the_title( $question['question_id'] ),
					'point'   => $question['question_point'],
					'hint'    => apply_filters( 'the_content', get_post_meta( $question['question_id'], 'question_hint', true ) ),
					'options' => array()
				);
				$total_points += $question['question_point'];
				if( $i == 1 ){
					$data['questions'][$i]['active'] = true;
				}
				$question_options = get_post_meta( $question['question_id'], 'question_options', true );
				if( $question_options ){
					$data['questions'][$i]['options'] = $question_options;
				}
			}
		}
		$data['total_questions'] = count($questions);

		if( empty( $data['error'] ) ){
			$user_id = get_current_user_id();
			$user_courses = get_user_meta( $user_id, 'courses', true );
			$user_courses[ $_COOKIE['course_id'] ]['passed_lessons'][] = $quiz_id;
			update_user_meta( $user_id, 'courses', $user_courses );

			// Clear course state
//			delete_user_meta( $user_id, 'quiz_result_' . $_COOKIE['course_id'] . '-' . $quiz_id );

			if( $user_quiz_result = get_user_meta( $user_id, 'quiz_result_' . $_COOKIE['course_id'] . '-' . $quiz_id, true ) ){
				$user_quiz_result['results'][] = array(
					'date'            => current_time( 'timestamp' ),
					'questions'       => $data['questions'],
					'correct_answers' => 0,
					'points_obtained' => 0,
					'total_points'    => $total_points
				);
			}else{
				$user_quiz_result = array(
					'required_points' => get_post_meta( $quiz_id, 'quiz_required_points', true ),
					'total_questions' => $data['total_questions'],
					'results'         => array(
						array(
							'date'            => current_time( 'timestamp' ),
							'questions'       => $data['questions'],
							'correct_answers' => 0,
							'points_obtained' => 0,
							'total_points'    => $total_points
						)
					)
				);
			}

			update_user_meta( $user_id, 'quiz_result_' . $_COOKIE['course_id'] . '-' . $quiz_id, $user_quiz_result );
		}

		echo json_encode( $data );
		exit;
	}

	public function check_quiz_answer(){
		$data = array();

		$quiz_id = $_REQUEST['quiz_id'] ? $_REQUEST['quiz_id'] : false;
		$question_id = $_REQUEST['question_id'] ? $_REQUEST['question_id'] : false;
		$question_number = $_REQUEST['question_number'] ? $_REQUEST['question_number'] : '';
		$answered = ( isset( $_REQUEST['answered'] ) ) ? $_REQUEST['answered'] : '';

		if ( ! $this->accessChecker( $quiz_id ) ) {
			$data['error'] = esc_html__( 'access denied', 'ulms' );
			echo json_encode( $data );
			exit;
		}

		if ( $question = get_post( $question_id ) ) {
			$data['correct_answer'] = get_post_meta( $question_id, 'question_answer', true );

			$user_id = get_current_user_id();
			if ( $user_quiz_result = get_user_meta( $user_id, 'quiz_result_' . $_COOKIE['course_id'] . '-' . $quiz_id, true ) ) {
				$user_quiz_result['results'][ count( $user_quiz_result['results'] ) - 1 ]['questions'][ $question_number ]['correct']  = $data['correct_answer'];
				$user_quiz_result['results'][ count( $user_quiz_result['results'] ) - 1 ]['questions'][ $question_number ]['answered'] = $answered;
				if ( $data['correct_answer'] == $answered ) {
					$user_quiz_result['results'][ count( $user_quiz_result['results'] ) - 1 ]['correct_answers'] += 1;
					$user_quiz_result['results'][ count( $user_quiz_result['results'] ) - 1 ]['points_obtained'] += $user_quiz_result['results'][ count( $user_quiz_result['results'] ) - 1 ]['questions'][ $question_number ]['point'];
				}
				update_user_meta( $user_id, 'quiz_result_' . $_COOKIE['course_id'] . '-' . $quiz_id, $user_quiz_result );
			}

		} else {
			$data['error'] = esc_html__( 'question not found', 'ulms' );
		}

		echo json_encode( $data );
		exit;
	}

	public function get_quiz_results() {
		$data    = array();
		$quiz_id = $_REQUEST['quiz_id'] ? $_REQUEST['quiz_id'] : false;
		if ( ! $this->accessChecker( $quiz_id ) ) {
			$data['error'] = esc_html__( 'access denied', 'ulms' );
			echo json_encode( $data );
			exit;
		}
		$user_id          = get_current_user_id();
		$user_quiz_result = get_user_meta( $user_id, 'quiz_result_' . $_COOKIE['course_id'] . '-' . $quiz_id, true );
		if ( isset( $_REQUEST['time_spent'] ) ) {
			$user_quiz_result['results'][ count( $user_quiz_result['results'] ) - 1 ]['time_spent'] = $_REQUEST['time_spent'];
			update_user_meta( $user_id, 'quiz_result_' . $_COOKIE['course_id'] . '-' . $quiz_id, $user_quiz_result );
		}
		$data['quiz_results'] = $user_quiz_result;
		echo json_encode( $data );
		exit;
	}

}

Runa_Course_Status::getInstance();