<?php

class Runa_Courses {

	private static $_instance = null;

	public static function getInstance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}

		return self::$_instance;
	}

	public function __construct() {
		add_action( 'init', array( $this, 'register_meta' ) );
		add_action( 'admin_menu', array( $this, 'add_meta_box' ) );
		add_action( 'save_post', array( $this, 'save_post' ) );
		add_action( 'save_post', array( $this, 'woo_save_post' ) );
		add_action( 'pre_get_posts', array( $this, 'query_setup' ) );
		add_action( 'wp_ajax_runa_load_courses', array( $this, 'load_courses' ) );
		add_action( 'wp_ajax_nopriv_runa_load_courses', array( $this, 'load_courses' ) );
		add_action( 'wp_ajax_runa_query_courses', array( $this, 'get_courses' ) );
		add_action( 'wp_ajax_nopriv_runa_query_courses', array( $this, 'get_courses' ) );

		add_action( 'woocommerce_order_status_completed', array( $this, 'add_course_to_user' ) );

		add_filter( 'manage_' . ULMS_COURSES_POST_TYPE . '_posts_columns', array( $this, 'admin_posts_columns_labels' ) );
		add_action( 'manage_' . ULMS_COURSES_POST_TYPE . '_posts_custom_column', array( $this, 'admin_custom_columns' ), 10, 2 );
		add_filter( 'manage_edit-' . ULMS_COURSES_POST_TYPE . '_sortable_columns', array( $this, 'admin_sortable_columns' ) );
		add_action( 'pre_get_posts', array( $this, 'admin_order_by_columns' ) );

		if ( ! empty( $_POST['take_course'] ) && ! empty( $_POST['course_id'] ) && wp_verify_nonce( $_POST['take_course'], 'runa-take-course-' . $_POST['course_id'] ) ) {
			add_action( 'init', array( $this, 'take_course' ) );
		}
		if ( ! empty( $_POST['delete_course'] ) && wp_verify_nonce( $_POST['delete_course'], 'runa-delete-course-nonce' ) && ! empty( $_POST['course_id'] ) ) {
			$this->delete_course( $_POST['course_id'] );
		}
	}

	public function add_course_to_user( $order_id ){
		$order = new WC_Order($order_id);
		$items = $order->get_items();
		$user_id = $order->user_id;
		$user_courses = (get_user_meta($user_id, 'courses', true)) ? get_user_meta($user_id, 'courses', true) : array();
		foreach ($items as $item) {
			$courses = get_post_meta($item['product_id'], '_courses_included', true);
			$groups = get_post_meta($item['product_id'], '_groups_included', true);
			foreach ($courses as $course_id) {
				if (empty($user_courses[$course_id])) {
					$user_courses[$course_id] = array(
						'time' => strtotime($order->order_date)
					);
					update_user_meta($user_id, 'courses', $user_courses);
					$students = get_post_meta($course_id, 'students', true);
					$students++;
					update_post_meta($course_id, 'students', $students);
				}
			}
			foreach( $groups as $group_id ){
				$group_course_id = get_post_meta( $group_id, 'group_course', true );
				if( $group_course_id && empty( $user_courses[$group_course_id] ) ){
					$user_courses[$group_course_id] = array(
						'time' => strtotime($order->order_date),
						'group_id' => $group_id
					);
					update_user_meta($user_id, 'courses', $user_courses);

					$students = get_post_meta($group_id, 'group_students', true);
					$students++;
					update_post_meta($group_id, 'group_students', $students);

					$students = get_post_meta($group_course_id, 'students', true);
					$students++;
					update_post_meta($group_course_id, 'students', $students);
				}

			}
		}
	}

	public function take_course() {
		$course_id = (int) $_POST['course_id'];
		$data      = $this->get_course( $course_id );
		if ( $data ) {
			if ( class_exists( 'WooCommerce' ) ) {
				$user_id      = get_current_user_id();
				$user_courses = ( get_user_meta( $user_id, 'courses', true ) ) ? get_user_meta( $user_id, 'courses', true ) : array();

				if ( ! empty( $user_courses[ $data['ID'] ] ) ) {
					setcookie( 'course_id', $data['ID'], 0, '/' );
					if( $course_start_page_id = ulms_option( 'course_start_page_id' ) ){
						wp_redirect( esc_url( get_permalink( $course_start_page_id ) ) );
					}else{
						wp_die( esc_html__( 'Page with the "Course Start" template not selected', 'ulms' ) );
					}
					exit;
				}

				if ( ! $this->is_available( $course_id ) ) {
					wp_redirect( esc_url( get_permalink( $course_id ) . '?error=true' ) );
					exit;
				}

				if ( $data['course_type'] == 'onsite' ) {
					wp_redirect( esc_url( get_permalink( $course_id ) . '#course-groups' ) );
					exit;
				}

				if( ! is_user_logged_in() ){
					wp_redirect( esc_url( wc_get_endpoint_url( 'my-courses', '', wc_get_page_permalink( 'myaccount' ) ) ) );
					exit;
				}

				if ( ! empty( $data['free'] ) ) {
					if ( empty( $user_courses[ $data['ID'] ] ) ) {
						$user_courses[ $data['ID'] ] = array(
							'time' => current_time( 'timestamp' )
						);
						update_user_meta( $user_id, 'courses', $user_courses );
						$students = get_post_meta( $course_id, 'students', true );
						$students ++;
						update_post_meta( $course_id, 'students', $students );
						wp_redirect( esc_url( wc_get_endpoint_url( 'my-courses', '?notice=1', wc_get_page_permalink( 'myaccount' ) ) ) );
						exit;
					}
				} else {
					WC()->cart->add_to_cart( $data['associated_product'] );
					wp_redirect( wc_get_cart_url() );
					exit;
				}
			} else {
				wp_redirect( esc_url( home_url( '/' ) ) );
				exit;
			}
		} else {
			return false;
		}

	}

	public function is_available( $course_id ) {
		$max_students = get_post_meta( $course_id, 'max_students', true );
		$students = get_post_meta( $course_id, 'students', true );
		if( ! $max_students ){
			return true;
		}else if( $students < $max_students ){
			return true;
		}else{
			return false;
		}
	}

	public function delete_course( $course_id ) {
		$course_id    = (int) $course_id;
		$user_id      = get_current_user_id();
		$user_courses = ( get_user_meta( $user_id, 'courses', true ) ) ? get_user_meta( $user_id, 'courses', true ) : array();
		if ( isset( $user_courses[ $course_id ] ) ) {
			unset( $user_courses[ $course_id ] );
			update_user_meta( $user_id, 'courses', $user_courses );
			$students = get_post_meta( $course_id, 'students', true );
			$students --;
			update_post_meta( $course_id, 'students', $students );
		}
	}

	public function load_courses() {
		$json            = array();
		$json['button']  = '';
		$json['content'] = '';
		$offset          = intval( $_POST['offset'] );
		$per_page        = intval( $_POST['per_page'] );
		$cat             = esc_attr( $_POST['cat'] );
		$new_offset      = $offset + $per_page;
		$query_args      = array(
			'post_type'      => ULMS_COURSES_POST_TYPE,
			'offset'         => $offset,
			'posts_per_page' => $per_page
		);
		if ( ! empty( $cat ) && $cat != 'all' ) {
			$query_args[ ULMS_COURSE_CATEGORY_SLUG ] = $cat;
		}
		$courses = new WP_Query( $query_args );
		if ( $courses->have_posts() ) {
			ob_start();
			while ( $courses->have_posts() ) {
				$courses->the_post();
				get_template_part( 'template-parts/course/loop', 'grid' );
			}
			$json['content'] = ob_get_contents();
			ob_end_clean();

			if ( $courses->found_posts > $new_offset ) {
				$json['button'] = '<a href="#" onclick="load_courses(jQuery(this), ' . esc_js( $new_offset ) . ', ' . esc_js( $per_page ) . ', \'' . esc_js( $cat ) . '\'); return false;"><i style="opacity: 0;" class="fa fa-circle-o-notch fa-spin"></i><span>' . esc_html__( 'Show More', 'ulms' ) . '</span><i class="fa fa-angle-down"></i></a>';
			} else {
				$json['button'] = '';
			}

			wp_reset_postdata();
		}

		echo json_encode( $json );
		exit;
	}

	public function get_courses() {
		$json         = array();
		$user_courses = get_user_meta( get_current_user_id(), 'courses', true );
		if ( ! empty( $_POST['category'] ) && ! is_wp_error( get_term( $_POST['category'] ), ULMS_COURSE_CATEGORY_SLUG ) ) {
			$current_link = get_term_link( $_POST['category'], ULMS_COURSE_CATEGORY_SLUG );
		} else {
			$current_link = get_permalink( ulms_option( 'courses_page' ) );
		}
		$json['url']        = $current_link . '?' . http_build_query( $_POST );
		$json['content']    = '';
		$json['pagination'] = '';
		$json['class']      = 'grid';

		$layout = ( ! empty( $_POST['layout'] ) && $_POST['layout'] == 'list' ) ? 'list' : 'grid';

		$meta_query = array();

		if ( ! empty( $_POST['type'] ) && $_POST['type'] == 'free' ) {
			$meta_query['type'] = array(
				'key'     => 'free_course',
				'value'   => '1',
				'compare' => '='
			);
		}
		if ( ! empty( $_POST['type'] ) && $_POST['type'] == 'paid' ) {
			$meta_query['type'] = array(
				'key'     => 'free_course',
				'value'   => '0',
				'compare' => '='
			);
		}

		$query_args = array(
			'post_type'      => ULMS_COURSES_POST_TYPE,
			'meta_query'     => $meta_query,
			'posts_per_page' => ulms_option( 'courses_limit', 6 )
		);

		if( ! empty( $_POST['type'] ) && $_POST['type'] == 'my' && $user_courses ){
			$query_args['post__in'] = array_keys( $user_courses );
		}
		if ( ! empty( $_POST['sort_by'] ) && $_POST['sort_by'] == 'alphabet_asc' ) {
			$query_args['orderby'] = 'title';
			$query_args['order']   = 'ASC';
		}
		if ( ! empty( $_POST['sort_by'] ) && $_POST['sort_by'] == 'alphabet_desc' ) {
			$query_args['orderby'] = 'title';
			$query_args['order']   = 'DESC';
		}
		if ( ! empty( $_POST['sort_by'] ) && $_POST['sort_by'] == 'price_asc' ) {
			$query_args['meta_key'] = 'price';
			$query_args['orderby']  = 'meta_value_num';
			$query_args['order']    = 'ASC';
		}
		if ( ! empty( $_POST['sort_by'] ) && $_POST['sort_by'] == 'price_desc' ) {
			$query_args['meta_key'] = 'price';
			$query_args['orderby']  = 'meta_value_num';
			$query_args['order']    = 'DESC';
		}

		if ( ! empty( $_POST['category'] ) && ! is_wp_error( get_term( $_POST['category'] ), ULMS_COURSE_CATEGORY_SLUG ) ) {
			$query_args[ ULMS_COURSE_CATEGORY_SLUG ] = $_POST['category'];
		}

		$courses = new WP_Query( $query_args );
		if ( $courses->have_posts() ) {
			ob_start();
			while ( $courses->have_posts() ) {
				$courses->the_post();
				if ( $layout == 'grid' ) {
					get_template_part( 'template-parts/course/loop', 'grid' );
					$json['class'] = 'grid';
				} else {
					$json['class'] = 'list';
					get_template_part( 'template-parts/course/loop', 'list' );
				}
			}
			$json['content'] = ob_get_contents();
			ob_end_clean();

		}

		$json['pagination'] = paginate_links( array(
			'base'      => $current_link . '%_%' . '?' . http_build_query( $_POST ),
			'type'      => 'list',
			'prev_text' => '<i class="fa fa-chevron-left"></i>',
			'next_text' => '<i class="fa fa-chevron-right"></i>',
			'total'     => $courses->max_num_pages
		) );

		wp_reset_postdata();

		echo json_encode( $json );
		exit;
	}

	public static function get_course( $course_id = '' ) {
		$course_id = ( $course_id ) ? $course_id : get_the_ID();
		if ( $course_id && ! get_post( $course_id ) ) {
			return false;
		}

		$data      = array();
		$user_courses = get_user_meta( get_current_user_id(), 'courses', true );

		$data['ID']             = $course_id;
		$data['curriculum']     = get_post_meta( $course_id, 'curriculum', true );
		$data['total_lessons']  = 0;
		$data['teachers']       = get_post_meta( $course_id, 'teachers', true );
		$data['course_type']    = get_post_meta( $course_id, 'course_type', true );
		$data['groups']         = get_post_meta( $course_id, 'groups', true );
		$data['certificates']   = get_post_meta( $course_id, 'certificates', true );
		$data['group_pictures'] = get_post_meta( $course_id, 'group_pictures', true );
		$data['students']       = get_post_meta( $course_id, 'students', true );
		$data['max_students']   = get_post_meta( $course_id, 'max_students', true );
		$data['lectures']       = get_post_meta( $course_id, 'lectures', true );
		$data['quizzes']        = get_post_meta( $course_id, 'quizzes', true );
		$data['duration']       = get_post_meta( $course_id, 'duration', true );
		$data['skill_level']    = get_post_meta( $course_id, 'skill_level', true );
		$data['language_ids']   = get_post_meta( $course_id, 'languages', true );
		$data['schedule']       = array();
		$data['languages']      = '';
		if( $data['language_ids'] ){
			foreach ( $data['language_ids'] as $lang ){
				$lang_term = get_term_by( 'id', $lang, ULMS_COURSE_LANGUAGES_CATEGORY_SLUG );
				if( $data['languages'] ){
					$data['languages'] .= ', ' . $lang_term->name;
				}else{
					$data['languages'] .= $lang_term->name;
				}
			}
		}

		$attachments_private = get_post_meta( $course_id, 'attachments_private', true );
		$attachments         = get_post_meta( $course_id, 'course_attachments', true );

		if( ( ! $attachments_private || isset( $user_courses[ $course_id ] ) ) && $attachments ){
			$data['attachments'] = $attachments;
		}else{
			$data['attachments'] = array();
		}

		if( $data['curriculum'] ){
			foreach( $data['curriculum'] as $curriculum ){
				$lesson = get_post( $curriculum );
				if( $lesson ){
					$data['total_lessons'] += 1;
				}
			}
		}
		$group_prices = array();
		if( $data['groups'] && $data['course_type'] == 'onsite' ){
			$i=0;
			foreach ( $data['groups'] as $group_id ){
				$group_info = Runa_Groups::get_group( $group_id );
				if( Runa_Groups::is_available( $group_id ) ){
					$group_prices[] = $group_info['price'];
				}
				$group_schedule = $group_info['schedule_array'];
				if( ! empty( $group_schedule ) ){
					foreach ($group_schedule as $schedule){
						if( ! empty( $schedule['datetime_start'] ) ){
							$data['schedule'][$i] = array(
								'title' => get_the_title( $group_id ),
								'start' => str_replace( ' ', 'T', $schedule['datetime_start'] ),
								'url'   => get_the_permalink( $group_id )
							);
							if( ! empty( $schedule['datetime_end'] ) ){
								$data['schedule'][$i]['end'] = str_replace( ' ', 'T', $schedule['datetime_end'] );
							}
							if( ! empty( $schedule['repeat'] ) ){
								$data['schedule'][$i]['dow'] = $schedule['repeat'];
							}
							$i++;
						}
					}
				}
			}
		}
		$data['certificate']        = get_post_meta( $course_id, 'certificate', true );
		$data['average_rating']     = ulms_get_average_rating();
		$data['associated_product'] = get_post_meta( $course_id, 'associated_product', true );
		$data['free']               = get_post_meta( $course_id, 'free_course', true );
		$data['sale_price']         = '';
		$data['regular_price']      = '';
		$data['price']              = '';
		$data['price_html']         = '<span class="woocommerce-Price-amount">' . esc_html__( 'Free', 'ulms' ) . '</span>';

		if ( class_exists( 'WooCommerce' ) ) {
			$_product = wc_get_product( $data['associated_product'] );
			if ( $_product && ! $data['free'] ) {
				$data['price']         = $_product->get_price();
				$data['sale_price']    = $_product->get_sale_price();
				$data['regular_price'] = $_product->get_regular_price();
				$data['price_html']    = $_product->get_price_html();
				if ( ! $_product->get_price_html() ) {
					$data['free']       = true;
					$data['price_html'] = '<span class="woocommerce-Price-amount">' . esc_html__( 'Free', 'ulms' ) . '</span>';
				}
			}
		}

		if( $group_prices ){
			$group_min_price = min( $group_prices );
			$group_max_price = max( $group_prices );
			if( empty( $group_min_price ) ){
				$data['price_html'] = '<span class="woocommerce-Price-amount">' . esc_html__( 'Free', 'ulms' ) . '</span>';
				$data['free'] = true;
			}else{
				if( $group_min_price == $group_max_price ){
					$data['price_html'] = wc_price(max( $group_prices ));
				}else{
					$data['price_html'] = '<span class="price-range">' . wc_price($group_min_price) . ' - ' . wc_price($group_max_price) . '</span>';
				}
				$data['free'] = false;
			}
		}

		return $data;
	}

	public function query_setup( $query ){
		if ( $query->is_tax( ULMS_COURSE_CATEGORY_SLUG ) && ! is_admin() ) {
			$query->set( 'posts_per_page', ulms_option( 'courses_limit', 6 ) );
		}
	}

	public function register_meta() {
		register_meta( 'post', 'course_type', 'esc_attr' );
		register_meta( 'post', 'enable_share_buttons', 'esc_attr' );

		register_meta( 'post', 'lectures', 'esc_attr' );
		register_meta( 'post', 'max_students', 'absint' );
		register_meta( 'post', 'students', 'absint' );
		register_meta( 'post', 'quizzes', 'absint' );
		register_meta( 'post', 'duration', 'esc_attr' );
		register_meta( 'post', 'skill_level', 'esc_attr' );
		register_meta( 'post', 'certificate', 'esc_attr' );

		register_meta( 'post', 'attachments_private', 'absint' );

		register_meta( 'post', 'free_course', 'absint' );
		register_meta( 'post', 'associated_product', 'esc_attr' );

		register_meta( 'post', 'enable_cta', 'absint' );
		register_meta( 'post', 'cta_icon', 'esc_attr' );
		register_meta( 'post', 'cta_title', 'esc_attr' );
		register_meta( 'post', 'cta_button_text', 'esc_attr' );
		register_meta( 'post', 'cta_button_link', 'esc_url' );

	}

	public function add_meta_box() {
		add_meta_box( 'runa-course-settings', esc_html__( 'Course Settings', 'ulms' ), array(
			$this,
			'course_settings_render'
		), array( ULMS_COURSES_POST_TYPE ), 'normal' );
	}

	public function course_settings_render() {
		global $post;

		$course_type          = $post->course_type;
		$groups               = get_post_meta( $post->ID, 'groups', true );
		$enable_share_buttons = $post->enable_share_buttons;
		$teachers             = get_post_meta( $post->ID, 'teachers', true );
		$lectures             = ( $post->lectures ) ? $post->lectures : 0;
		$max_students         = ( $post->max_students ) ? $post->max_students : 0;
		$students             = ( $post->students ) ? $post->students : 0;
		$quizzes              = ( $post->quizzes ) ? $post->quizzes : 0;
		$duration             = $post->duration;
		$skill_level          = $post->skill_level;
		$languages            = get_post_meta( $post->ID, 'languages', true );
		$certificate          = $post->certificate;
		$curriculum           = get_post_meta( $post->ID, 'curriculum', true );
		$certificates         = get_post_meta( $post->ID, 'certificates', true );
		$group_pictures       = get_post_meta( $post->ID, 'group_pictures', true );
		$course_attachments   = get_post_meta( $post->ID, 'course_attachments', true );
		$attachments_private  = ( $post->attachments_private ) ? $post->attachments_private : 0;
		$free_course          = $post->free_course;
		$associated_product   = $post->associated_product;
		$enable_cta           = $post->enable_cta;
		$cta_icon             = $post->cta_icon;
		$cta_title            = $post->cta_title;
		$cta_button_text      = $post->cta_button_text;
		$cta_button_link      = $post->cta_button_link;

		?>

		<div class="runa-tabs">
			<ul class="runa-tabs-nav">
				<li>
					<a class="active" href="#general">
						<i class="fa fa-cog"></i>
						<span><?php esc_html_e( 'General', 'ulms' ); ?></span>
					</a>
				</li>
				<li>
					<a href="#details">
						<i class="fa fa-bars"></i>
						<span><?php esc_html_e( 'Details', 'ulms' ); ?></span>
					</a>
				</li>
				<li>
					<a href="#curriculum">
						<i class="fa fa-pencil-square-o"></i>
						<span><?php esc_html_e( 'Curriculum', 'ulms' ); ?></span>
					</a>
				</li>
				<li>
					<a href="#certificates">
						<i class="fa fa-certificate"></i>
						<span><?php esc_html_e( 'Certificates', 'ulms' ); ?></span>
					</a>
				</li>
				<li class="onsite-param">
					<a href="#group-pictures">
						<i class="fa fa-picture-o"></i>
						<span><?php esc_html_e( 'Group Pictures', 'ulms' ); ?></span>
					</a>
				</li>
				<li>
					<a href="#course-attachments">
						<i class="fa fa-files-o"></i>
						<span><?php esc_html_e( 'Attachments', 'ulms' ); ?></span>
					</a>
				</li>
				<li class="online-param">
					<a href="#product">
						<i class="fa fa-shopping-cart"></i>
						<span><?php esc_html_e( 'Course Product', 'ulms' ); ?></span>
					</a>
				</li>
				<li>
					<a href="#cta">
						<i class="fa fa-flag-o"></i>
						<span><?php esc_html_e( 'Call To Action', 'ulms' ); ?></span>
					</a>
				</li>
			</ul>
			<div class="runa-tabs-tab active" id="general">
				<div class="options-group">
					<div class="form-field">
						<label for="course_type">
							<span><?php esc_html_e( 'Course Type', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Choose online or onsite course type', 'ulms' ); ?>"></i>
						</label>
						<select name="course_type" class="s2_2" id="course_type">
							<option value="online" <?php selected( $course_type, 'online' ); ?>><?php esc_html_e( 'Online', 'ulms' ); ?></option>
							<option value="onsite" <?php selected( $course_type, 'onsite' ); ?>><?php esc_html_e( 'Onsite', 'ulms' ); ?></option>
						</select>
					</div>
				</div>
				<div class="options-group onsite-param">
					<div class="form-field">
						<label for="groups">
							<span><?php esc_html_e( 'Groups', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Choose group to associate with course', 'ulms' ); ?>"></i>
						</label>
						<select name="groups[]" class="s2" id="groups" multiple>
							<?php
							$query_groups = get_posts( array(
								'post_type'      => ULMS_GROUPS_POST_TYPE,
								'posts_per_page' => -1
							) );
							?>
							<?php if ( $query_groups ): ?>
								<?php foreach ( $query_groups as $group ): ?>
									<option value="<?php echo esc_attr( $group->ID ); ?>" <?php if ( $groups ) { selected( true, in_array( $group->ID, $groups ) ); } ?>><?php echo esc_html( get_the_title( $group->ID ) ); ?></option>
								<?php endforeach; ?>
							<?php endif; ?>
						</select>
					</div>
				</div>
				<div class="options-group">
					<div class="form-field">
						<label for="teachers">
							<span><?php esc_html_e( 'Teachers', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Choose teachers to associate with course', 'ulms' ); ?>"></i>
						</label>
						<select name="teachers[]" class="s2" id="teachers" multiple>
							<?php
							$users_list = get_users( array(
								'role'   => ULMS_TEACHERS_ROLE,
								'fields' => array( 'ID', 'display_name' )
							) );
							?>
							<?php if ( $users_list ): ?>
								<?php foreach ( $users_list as $user ): ?>
									<option value="<?php echo esc_attr( $user->ID ); ?>" <?php if ( $teachers ) { selected( true, in_array( $user->ID, $teachers ) ); } ?>><?php echo esc_html( $user->display_name ); ?></option>
								<?php endforeach; ?>
							<?php endif; ?>
						</select>
					</div>
				</div>
			</div>
			<div class="runa-tabs-tab" id="details">
				<div class="options-group">
					<div class="form-field">
						<label for="lectures">
							<span><?php esc_html_e( 'Lectures', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Numbers of lectures in course', 'ulms' ); ?>"></i>
						</label>
						<input id="lectures" class="input-form" type="number" min="0" step="1" name="lectures" value="<?php echo esc_attr( $lectures ); ?>"/>
					</div>
				</div>
				<div class="options-group">
					<div class="form-field">
						<label for="max_students">
							<span><?php esc_html_e( 'Maximum students', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Maximum number of students can be enroll this course', 'ulms' ); ?>"></i>
						</label>
						<input id="max_students" class="input-form" type="number" name="max_students" min="0" step="1" value="<?php echo esc_attr( $max_students ); ?>"/>
					</div>
				</div>
				<div class="options-group">
					<div class="form-field">
						<label for="students">
							<span><?php esc_html_e( 'Students enrolled', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Number of students enrolled in course', 'ulms' ); ?>"></i>
						</label>
						<input id="students" class="input-form" type="number" name="students" min="0" step="1" value="<?php echo esc_attr( $students ); ?>"/>
					</div>
				</div>
				<div class="options-group">
					<div class="form-field">
						<label for="quizzes">
							<span><?php esc_html_e( 'Quizzes', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Number of quizzes in course', 'ulms' ); ?>"></i>
						</label>
						<input id="quizzes" class="input-form" type="number" min="0" step="1" name="quizzes" value="<?php echo esc_attr( $quizzes ); ?>"/>
					</div>
				</div>
				<div class="options-group">
					<div class="form-field">
						<label for="duration">
							<span><?php esc_html_e( 'Duration', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Total duration of course', 'ulms' ); ?>"></i>
						</label>
						<input id="duration" class="input-form" type="text" name="duration" value="<?php echo esc_attr( $duration ); ?>"/>
					</div>
				</div>
				<div class="options-group">
					<div class="form-field">
						<label for="skill_level">
							<span><?php esc_html_e( 'Skill level', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Required level of student knowledge', 'ulms' ); ?>"></i>
						</label>
						<input id="skill_level" class="input-form" type="text" name="skill_level" value="<?php echo esc_attr( $skill_level ); ?>"/>
					</div>
				</div>
				<div class="options-group">
					<div class="form-field">
						<label for="language">
							<span><?php esc_html_e( 'Language', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Course language', 'ulms' ); ?>"></i>
						</label>
						<select name="languages[]" class="s2" id="group_languages" multiple>
							<?php
							$all_languages = get_terms( ULMS_COURSE_LANGUAGES_CATEGORY_SLUG, array(
								'hide_empty' => false
							) );
							?>
							<?php if ( $all_languages ): ?>
								<?php foreach ( $all_languages as $language ): ?>
									<option value="<?php echo esc_attr( $language->term_id ); ?>" <?php if ( $languages ) { selected( true, in_array( $language->term_id, $languages ) ); } ?>><?php echo esc_html( $language->name ); ?></option>
								<?php endforeach; ?>
							<?php endif; ?>
						</select>
					</div>
				</div>
				<div class="options-group">
					<div class="form-field">
						<label for="certificate">
							<span><?php esc_html_e( 'Certificate', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Course certificate', 'ulms' ); ?>"></i>
						</label>
						<select name="certificate" class="s2_2" id="certificate">
							<option value="no" <?php selected( $certificate, 'no' ); ?>><?php esc_html_e( 'No', 'ulms' ); ?></option>
							<option value="yes" <?php selected( $certificate, 'yes' ); ?>><?php esc_html_e( 'Yes', 'ulms' ); ?></option>
						</select>
					</div>
				</div>
				<div class="options-group">
					<div class="form-field">
						<label for="enable_share_buttons">
							<span><?php esc_html_e( 'Share Buttons', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Buttons for sharing course in social networks', 'ulms' ); ?>"></i>
						</label>
						<select name="enable_share_buttons" class="s2_2" id="enable_share_buttons">
							<option value="enable" <?php selected( $enable_share_buttons, 'enable' ); ?>><?php esc_html_e( 'Enable', 'ulms' ); ?></option>
							<option value="disable" <?php selected( $enable_share_buttons, 'disable' ); ?>><?php esc_html_e( 'Disable', 'ulms' ); ?></option>
						</select>
					</div>
				</div>
			</div>
			<div class="runa-tabs-tab" id="curriculum">
				<?php
				$all_lessons       = get_posts( array(
					'post_type'      => ULMS_COURSES_LESSONS_POST_TYPE,
					'posts_per_page' => - 1,
					'meta_query'     => array(
						array(
							'key'     => 'lesson_courses',
							'value'   => $post->ID,
							'compare' => 'LIKE'
						)
					)
				) );
				$all_lessons_array = array();
				if ( $all_lessons ) {
					foreach ( $all_lessons as $val ) {
						$all_lessons_array[] = array(
							'id'   => $val->ID,
							'text' => get_the_title( $val->ID )
						);
					}
				}

				$all_quizzes       = get_posts( array(
					'post_type'      => ULMS_COURSES_QUIZ_POST_TYPE,
					'posts_per_page' => - 1,
					'meta_query'     => array(
						array(
							'key'     => 'quiz_courses',
							'value'   => $post->ID,
							'compare' => 'LIKE'
						)
					)
				) );
				$all_quizzes_array = array();
				if ( $all_quizzes ) {
					foreach ( $all_quizzes as $val ) {
						$all_quizzes_array[] = array(
							'id'   => $val->ID,
							'text' => get_the_title( $val->ID )
						);
					}
				}
				?>
				<div class="curiculum-wr">
					<a class="curiculum_add_section button button-primary button-large" href="#"><?php esc_html_e( 'Add Section', 'ulms' ); ?></a>
					<a class="curiculum_add_lesson button button-primary button-large" href="#"><?php esc_html_e( 'Add lesson', 'ulms' ); ?></a>
					<a class="curiculum_add_quiz button button-primary button-large" href="#"><?php esc_html_e( 'Add quiz', 'ulms' ); ?></a>
					<ul id="sortable-curriculum" class="curriculum-sortable">
						<?php if ( $curriculum ): ?>
							<?php foreach ( $curriculum as $key => $val ): ?>
								<?php
								$curr_type = 'section';
								$curr_icon = 'fa fa-font';
								if ( get_post_type( $val ) == ULMS_COURSES_LESSONS_POST_TYPE ) {
									$curr_type = 'lesson';
									$curr_icon = 'fa fa-file-text-o';
								} elseif ( get_post_type( $val ) == ULMS_COURSES_QUIZ_POST_TYPE ) {
									$curr_type = 'quiz';
									$curr_icon = 'fa fa-check-square-o';
								}
								?>
								<li>
									<i class="handle <?php echo esc_attr( $curr_icon ); ?>"></i>
									<?php if ( $curr_type == 'lesson' ): ?>
										<select class="value s2" name="curriculum[<?php echo esc_attr( $key ); ?>]">
											<?php foreach ( $all_lessons as $lesson ): ?>
												<option <?php selected( $lesson->ID, $val ); ?> value="<?php echo esc_attr( $lesson->ID ); ?>"><?php echo esc_html( get_the_title( $lesson->ID ) ); ?></option>
											<?php endforeach; ?>
										</select>
									<?php elseif ( $curr_type == 'quiz' ): ?>
										<select class="value s2" name="curriculum[<?php echo esc_attr( $key ); ?>]">
											<?php foreach ( $all_quizzes as $quiz ): ?>
												<option <?php selected( $quiz->ID, $val ); ?> value="<?php echo esc_attr( $quiz->ID ); ?>"><?php echo esc_html( get_the_title( $quiz->ID ) ); ?></option>
											<?php endforeach; ?>
										</select>
									<?php else: ?>
										<input type="text" class="value" name="curriculum[<?php echo esc_attr( $key ); ?>]" value="<?php echo esc_attr( $val ); ?>"/>
									<?php endif; ?>
									<a class="remove" href="#"><i class="fa fa-times"></i></a>
								</li>
							<?php endforeach; ?>
						<?php endif; ?>
					</ul>
					<script type="text/javascript">
						var all_lessons_array = [];
						var all_quizzes_array = [];
						<?php if( $all_lessons_array ): ?>
						all_lessons_array = <?php echo json_encode( $all_lessons_array ); ?>;
						<?php endif; ?>
						<?php if( $all_quizzes_array ): ?>
						all_quizzes_array = <?php echo json_encode( $all_quizzes_array ); ?>;
						<?php endif; ?>
					</script>
				</div>
			</div>
			<div class="runa-tabs-tab" id="certificates">
				<div class="image-gallery-wr">
					<a onclick="runa_add_images( jQuery('#certificates-gallery'), 'certificates' ); return false;" class="button button-primary button-large" href="#"><?php esc_html_e( 'Add Certificate', 'ulms' ); ?></a>
					<ul class="image-gallery" id="certificates-gallery">
						<?php if ( $certificates ): ?>
							<?php foreach ( $certificates as $key => $val ): ?>
								<?php if ( $thumbnail = wp_get_attachment_image_src( $val ) ): ?>
									<li>
										<div class="image-wr">
											<a onclick="runa_remove_image( jQuery(this), jQuery('#certificates-gallery'), 'certificates' ); return false;" href="#" class="remove"><i class="fa fa-times"></i></a>
											<img src="<?php echo esc_url( $thumbnail[0] ); ?>" alt=""/>
										</div>
										<input class="value" type="hidden" name="certificates[<?php echo esc_attr( $key ); ?>]" value="<?php echo esc_attr( $val ); ?>"/>
									</li>
								<?php endif; ?>
							<?php endforeach; ?>
						<?php endif; ?>
					</ul>
				</div>
			</div>
			<div class="runa-tabs-tab" id="group-pictures">
				<div class="image-gallery-wr">
					<a onclick="runa_add_images( jQuery('#group-pictures-gallery'), 'group_pictures' ); return false;" class="button button-primary button-large" href="#"><?php esc_html_e( 'Add Image', 'ulms' ); ?></a>
					<ul class="image-gallery" id="group-pictures-gallery">
						<?php if ( $group_pictures ): ?>
							<?php foreach ( $group_pictures as $key => $val ): ?>
								<?php if ( $thumbnail = wp_get_attachment_image_src( $val ) ): ?>
									<li>
										<div class="image-wr">
											<a onclick="runa_remove_image( jQuery(this), jQuery('#group-pictures-gallery'), 'group_pictures' ); return false;" href="#" class="remove"><i class="fa fa-times"></i></a>
											<img src="<?php echo esc_url( $thumbnail[0] ); ?>" alt=""/>
										</div>
										<input class="value" type="hidden" name="group_pictures[<?php echo esc_attr( $key ); ?>]" value="<?php echo esc_attr( $val ); ?>"/>
									</li>
								<?php endif; ?>
							<?php endforeach; ?>
						<?php endif; ?>
					</ul>
				</div>
			</div>
			<div class="runa-tabs-tab" id="course-attachments">
				<div class="options-group">
					<div class="form-field">
						<label for="attachments_private">
							<input type="checkbox" name="attachments_private" id="attachments_private" value="1" <?php checked( 1, $attachments_private ); ?> />
							<span><?php esc_html_e( 'Private', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Show only to the participants', 'ulms' ); ?>"></i>
						</label>
					</div>
				</div>
				<div class="files-list-wr">
					<a onclick="runa_add_attachments( jQuery('#course-attachments-list'), 'course_attachments' ); return false;" class="button button-primary button-large" href="#">
						<?php esc_html_e( 'Add Attachment', 'ulms' ); ?>
					</a>
					<ul class="files-list" id="course-attachments-list">
						<?php if ( $course_attachments ): ?>
							<?php foreach ( $course_attachments as $key => $val ): ?>
								<?php if( $attachment = get_post( $val ) ): ?>
									<li>
										<?php $attached_file = get_attached_file( $val ); ?>
										<i class="handle <?php echo esc_attr( ulms_get_file_icon( $attached_file ) ); ?>"></i>
										<div class="title"><a href="<?php echo esc_url( get_edit_post_link( $val ) ); ?>" target="_blank"><?php echo esc_html( basename( $attached_file ) ); ?></a></div>
										<a onclick="runa_remove_image( jQuery(this), jQuery('#course-attachments-list'), 'course_attachments' ); return false;" href="#" class="remove"><i class="fa fa-times"></i></a>
										<input class="value" type="hidden" name="course_attachments[<?php echo esc_attr( $key ); ?>]" value="<?php echo esc_attr( $val ); ?>"/>
									</li>
								<?php endif; ?>
							<?php endforeach; ?>
						<?php endif; ?>
					</ul>
				</div>
			</div>
			<div class="runa-tabs-tab" id="product">
				<div class="options-group">
					<div class="form-field">
						<label for="free_course">
							<input type="checkbox" name="free_course" id="free_course" value="1" <?php checked( 1, $free_course ); ?> />
							<span><?php esc_html_e( 'Free Course', 'ulms' ); ?></span>
						</label>
					</div>
				</div>
				<?php
				$query_products = new WP_Query( array(
					'post_type'      => 'product',
					'posts_per_page' => 9999
				) );
				?>
				<?php if ( $query_products->have_posts() ): ?>
					<div class="options-group">
						<div class="form-field">
							<label for="associated_product">
								<span><?php esc_html_e( 'Associated Product', 'ulms' ); ?></span>
								<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Choose product to associate with course and to set a price', 'ulms' ); ?>"></i>
							</label>
							<select name="associated_product" class="s2" id="associated_product">
								<option value="0"><?php esc_html_e( '--Not chosen--', 'ulms' ); ?></option>
								<?php while ( $query_products->have_posts() ): $query_products->the_post(); ?>
									<option value="<?php echo esc_attr( get_the_ID() ); ?>" <?php selected( $associated_product, get_the_ID() ); ?>><?php echo esc_html( get_the_title() ); ?></option>
								<?php endwhile;
								wp_reset_postdata(); ?>
							</select>
						</div>
					</div>
				<?php endif; ?>
			</div>
			<div class="runa-tabs-tab" id="cta">
				<div class="options-group">
					<div class="form-field">
						<label for="enable_cta">
							<input type="checkbox" name="enable_cta" id="enable_cta" value="1" <?php checked( 1, $enable_cta ); ?> />
							<span><?php esc_html_e( 'Enable', 'ulms' ); ?></span>
						</label>
					</div>
				</div>
				<div class="options-group">
					<div class="form-field">
						<label for="cta_icon">
							<span><?php esc_html_e( 'Icon', 'ulms' ); ?></span>
						</label>
						<input id="cta_icon" class="input-form" type="text" name="cta_icon" value="<?php echo esc_attr( $cta_icon ); ?>"/>
					</div>
					<script type="text/javascript">
						jQuery(document).ready(function ($) {
							$('#cta_icon').fontIconPicker({
								source: ulms_icons_array,
								theme: 'fip-grey'
							});
						});
					</script>
				</div>
				<div class="options-group">
					<div class="form-field">
						<label for="cta_title">
							<span><?php esc_html_e( 'Title', 'ulms' ); ?></span>
						</label>
						<input id="cta_title" class="input-form" type="text" name="cta_title" value="<?php echo esc_attr( $cta_title ); ?>"/>
					</div>
				</div>
				<div class="options-group">
					<div class="form-field">
						<label for="cta_button_text">
							<span><?php esc_html_e( 'Button Text', 'ulms' ); ?></span>
						</label>
						<input id="cta_button_text" class="input-form" type="text" name="cta_button_text" value="<?php echo esc_attr( $cta_button_text ); ?>"/>
					</div>
				</div>
				<div class="options-group">
					<div class="form-field">
						<label for="cta_button_link">
							<span><?php esc_html_e( 'Button Link', 'ulms' ); ?></span>
						</label>
						<input id="cta_button_link" class="input-form" type="text" name="cta_button_link" value="<?php echo esc_attr( $cta_button_link ); ?>"/>
					</div>
				</div>
			</div>
		</div>

		<?php
	}

	public function save_post( $post_id ) {
		global $post;

		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return;
		}

		if ( ! is_object( $post ) ) {
			return;
		}

		if ( ULMS_COURSES_POST_TYPE != $post->post_type ) {
			return;
		}

		if ( ! current_user_can( 'edit_post', $post->ID ) ) {
			return;
		}

		$course_type          = isset( $_POST['course_type'] ) ? $_POST['course_type'] : 'online';
		$groups               = isset( $_POST['groups'] ) ? $_POST['groups'] : '';
		$enable_share_buttons = isset( $_POST['enable_share_buttons'] ) ? $_POST['enable_share_buttons'] : 'enable';
		$teachers             = isset( $_POST['teachers'] ) ? $_POST['teachers'] : '';
		$lectures             = isset( $_POST['lectures'] ) ? $_POST['lectures'] : 0;
		$max_students         = isset( $_POST['max_students'] ) ? $_POST['max_students'] : 0;
		$students             = isset( $_POST['students'] ) ? $_POST['students'] : 0;
		$quizzes              = isset( $_POST['quizzes'] ) ? $_POST['quizzes'] : 0;
		$duration             = isset( $_POST['duration'] ) ? $_POST['duration'] : '';
		$skill_level          = isset( $_POST['skill_level'] ) ? $_POST['skill_level'] : '';
		$languages            = isset( $_POST['languages'] ) ? $_POST['languages'] : '';
		$certificate          = isset( $_POST['certificate'] ) ? $_POST['certificate'] : 'no';
		$curriculum           = isset( $_POST['curriculum'] ) ? $_POST['curriculum'] : '';
		$certificates         = isset( $_POST['certificates'] ) ? $_POST['certificates'] : '';
		$group_pictures       = isset( $_POST['group_pictures'] ) ? $_POST['group_pictures'] : '';
		$free_course          = isset( $_POST['free_course'] ) ? 1 : 0;
		$associated_product   = isset( $_POST['associated_product'] ) ? $_POST['associated_product'] : '';
		if ( ! $associated_product ) {
			$free_course = true;
		}
		$enable_cta          = isset( $_POST['enable_cta'] ) ? 1 : 0;
		$cta_icon            = isset( $_POST['cta_icon'] ) ? $_POST['cta_icon'] : '';
		$cta_title           = isset( $_POST['cta_title'] ) ? $_POST['cta_title'] : '';
		$cta_button_text     = isset( $_POST['cta_button_text'] ) ? $_POST['cta_button_text'] : '';
		$cta_button_link     = isset( $_POST['cta_button_link'] ) ? $_POST['cta_button_link'] : '';
		$course_attachments  = isset( $_POST['course_attachments'] ) ? $_POST['course_attachments'] : '';
		$attachments_private = isset( $_POST['attachments_private'] ) ? $_POST['attachments_private'] : 0;

		update_post_meta( $post->ID, 'course_type', $course_type );
		update_post_meta( $post->ID, 'groups', $groups );
		update_post_meta( $post->ID, 'enable_share_buttons', $enable_share_buttons );
		update_post_meta( $post->ID, 'teachers', $teachers );
		update_post_meta( $post->ID, 'lectures', $lectures );
		update_post_meta( $post->ID, 'max_students', $max_students );
		update_post_meta( $post->ID, 'students', $students );
		update_post_meta( $post->ID, 'quizzes', $quizzes );
		update_post_meta( $post->ID, 'duration', $duration );
		update_post_meta( $post->ID, 'skill_level', $skill_level );
		update_post_meta( $post->ID, 'languages', $languages );
		update_post_meta( $post->ID, 'certificate', $certificate );
		update_post_meta( $post->ID, 'curriculum', $curriculum );
		update_post_meta( $post->ID, 'certificates', $certificates );
		update_post_meta( $post->ID, 'group_pictures', $group_pictures );
		update_post_meta( $post->ID, 'free_course', $free_course );
		update_post_meta( $post->ID, 'associated_product', $associated_product );
		update_post_meta( $post->ID, 'enable_cta', $enable_cta );
		update_post_meta( $post->ID, 'cta_title', $cta_title );
		update_post_meta( $post->ID, 'cta_icon', $cta_icon );
		update_post_meta( $post->ID, 'cta_button_text', $cta_button_text );
		update_post_meta( $post->ID, 'cta_button_link', $cta_button_link );
		update_post_meta( $post->ID, 'course_attachments', $course_attachments );
		update_post_meta( $post->ID, 'attachments_private', $attachments_private );
	}

	public function woo_save_post( $post_id ) {
		global $post;

		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return;
		}

		if ( ! is_object( $post ) ) {
			return;
		}

		if ( 'product' != $post->post_type ) {
			return;
		}

		if ( ! current_user_can( 'edit_post', $post->ID ) ) {
			return;
		}

		$_courses_included = isset( $_POST['_courses_included'] ) ? $_POST['_courses_included'] : '';
		update_post_meta( $post->ID, '_courses_included', $_courses_included );

		$_groups_included = isset( $_POST['_groups_included'] ) ? $_POST['_groups_included'] : '';
		update_post_meta( $post->ID, '_groups_included', $_groups_included );

	}

	public function admin_posts_columns_labels( $existing_columns ) {
		unset( $existing_columns['title'], $existing_columns['comments'], $existing_columns['date'], $existing_columns['author'] );
		$columns['cb']    = '<input type="checkbox" />';
		$columns['thumb']  = '<i class="fa fa-picture-o" aria-hidden="true"></i>';
		$columns['title']  = esc_html__( 'Title', 'ulms' );
		$columns['course_type']  = esc_html__( 'Course Type', 'ulms' );
		$columns['course_product'] = esc_html__( 'Associated Product', 'ulms' );

		return array_merge( $columns, $existing_columns );
	}

	public function admin_custom_columns( $column, $post_id ) {
		$course_type = get_post_meta( $post_id, 'course_type', true );
		switch ( $column ) {

			case 'thumb' :
				echo '<a href="' . get_edit_post_link( $post_id ) . '">' . get_the_post_thumbnail( $post_id, 'thumbnail' ) . '</a>';
				break;

			case 'course_type' :
				if ( $course_type == 'online' ):
					esc_html_e( 'Online', 'ulms' );
				elseif ( $course_type == 'onsite' ):
					esc_html_e( 'Onsite', 'ulms' );
				endif;
				break;

			case 'course_product' :
				$product_id = get_post_meta( $post_id, 'associated_product', true );
				$free_course = get_post_meta( $post_id, 'free_course', true );
				if ( $product_id && empty( $free_course ) ) {
					echo '<a href="' . esc_url( get_the_permalink( $product_id ) ) . '">' . esc_html( get_the_title( $product_id ) ) . '</a>';
				} elseif ( $course_type == 'onsite' ) {
					echo '-';
				} else {
					esc_html_e( 'Free', 'ulms' );
				}
				break;

		}
	}

	public function admin_sortable_columns( $columns ) {
		$custom['course_type'] = 'course_type';
		return wp_parse_args( $custom, $columns );
	}

	public function admin_order_by_columns( $query ) {
		if ( ! is_admin() ) {
			return;
		}

		$orderby = $query->get( 'orderby' );

		switch ($orderby){
			case 'course_type' :
				$query->set( 'meta_key', 'course_type' );
				$query->set( 'orderby', 'meta_value_num' );
				break;
		}
	}

}

Runa_Courses::getInstance();