<?php

class Runa_Groups {

	private static $_instance = NULL;

	public static function getInstance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}

		return self::$_instance;
	}

	public function __construct() {
		add_action( 'init', array( $this, 'register_meta' ) );
		add_action( 'admin_menu', array( $this, 'add_meta_box' ) );
		add_action( 'save_post', array( $this, 'save_post' ) );
		add_filter( 'manage_' . ULMS_GROUPS_POST_TYPE . '_posts_columns', array( $this, 'admin_posts_columns_labels' ) );
		add_action( 'manage_' . ULMS_GROUPS_POST_TYPE . '_posts_custom_column', array( $this, 'admin_custom_columns' ), 10, 2 );
		add_filter( 'manage_edit-' . ULMS_GROUPS_POST_TYPE . '_sortable_columns', array( $this, 'admin_sortable_columns' ) );
		add_action( 'pre_get_posts', array( $this, 'admin_order_by_columns' ) );
		if ( ! empty( $_POST['take_group'] ) && ! empty( $_POST['group_id'] ) && wp_verify_nonce( $_POST['take_group'], 'runa-take-group-' . $_POST['group_id'] ) ) {
			add_action( 'init', array( $this, 'take_group' ) );
		}
	}

	public function take_group() {
		$group_id = (int) $_POST['group_id'];
		$data      = $this->get_group( $group_id );
		if ( $data ) {
			if ( class_exists( 'WooCommerce' ) ) {
				$user_id      = get_current_user_id();
				$user_courses = ( get_user_meta( $user_id, 'courses', true ) ) ? get_user_meta( $user_id, 'courses', true ) : array();

				if ( ! empty( $user_courses[ $data['course_id'] ] ) ) {
					setcookie( 'course_id', $data['course_id'], 0, '/' );
					wp_redirect( esc_url( get_permalink( ulms_option( 'course_start_page_id' ) ) ) );
					exit;
				}

				if ( ! $this->is_available( $group_id ) ) {
					wp_redirect( esc_url( get_permalink( $group_id ) . '?error=true' ) );
					exit;
				}

				if( ! is_user_logged_in() ){
					wp_redirect( esc_url( wc_get_endpoint_url( 'my-courses', '', wc_get_page_permalink( 'myaccount' ) ) ) );
					exit;
				}

				if ( ! empty( $data['free'] ) ) {
					if ( empty( $user_courses[ $data['course_id'] ] ) ) {
						$user_courses[ $data['course_id'] ] = array(
							'time' => current_time( 'timestamp' ),
							'group_id' => $data['ID']
						);
						update_user_meta( $user_id, 'courses', $user_courses );
						$students = get_post_meta( $group_id, 'group_students', true );
						$students ++;
						update_post_meta( $group_id, 'group_students', $students );
						wp_redirect( esc_url( wc_get_endpoint_url( 'my-courses', '?notice=1', wc_get_page_permalink( 'myaccount' ) ) ) );
						exit;
					}
				} else {
					WC()->cart->add_to_cart( $data['associated_product'] );
					wp_redirect( wc_get_cart_url() );
					exit;
				}
			} else {
				wp_redirect( esc_url( home_url( '/' ) ) );
				exit;
			}
		} else {
			return false;
		}

	}

	public function admin_posts_columns_labels( $existing_columns ) {
		unset( $existing_columns['title'], $existing_columns['comments'], $existing_columns['date'], $existing_columns['author'] );
		$columns['cb']    = '<input type="checkbox" />';
		$columns['thumb']  = '<i class="fa fa-picture-o" aria-hidden="true"></i>';
		$columns['title']  = esc_html__( 'Title', 'ulms' );
		$columns['group_course'] = esc_html__( 'Course', 'ulms' );
		$columns['group_product'] = esc_html__( 'Associated Product', 'ulms' );
		$columns['group_teachers'] = esc_html__( 'Teachers', 'ulms' );

		return array_merge( $columns, $existing_columns );
	}

	public function admin_custom_columns( $column, $post_id ) {
		switch ( $column ) {

			case 'thumb' :
				echo '<a href="' . get_edit_post_link( $post_id ) . '">' . get_the_post_thumbnail( $post_id, 'thumbnail' ) . '</a>';
				break;

			case 'group_course' :
				if( $group_course_id = get_post_meta( $post_id, 'group_course', true ) ){
					echo '<a href="' . esc_url( get_the_permalink( $group_course_id ) ) . '">' . esc_html( get_the_title( $group_course_id ) ) . '</a>';
				}
				break;

			case 'group_product' :
				if( $group_product_id = get_post_meta( $post_id, 'group_associated_product', true ) ){
					echo '<a href="' . esc_url( get_the_permalink( $group_product_id ) ) . '">' . esc_html( get_the_title( $group_product_id ) ) . '</a>';
				}else{
					esc_html_e( 'Free', 'ulms' );
				}
				break;

			case 'group_teachers' :
				$group_teachers = get_post_meta( $post_id, 'group_teachers', true );
				$teachers_array = array();
				if( $group_teachers ){
					foreach ( $group_teachers as $teacher_id ) {
						$teacher_info = get_userdata( $teacher_id );
						$teachers_array[] = '<a href="' . esc_url( get_author_posts_url( $teacher_info->ID ) ) . '">' . esc_html( $teacher_info->display_name ) . '</a>';
					}
				}
				if( $teachers_array ){
					echo implode( ', ', $teachers_array );
				}
				break;

		}
	}

	public function admin_sortable_columns( $columns ) {
		$custom['group_course'] = 'group_course';
		return wp_parse_args( $custom, $columns );
	}

	public function admin_order_by_columns( $query ) {
		if ( ! is_admin() ) {
			return;
		}

		$orderby = $query->get( 'orderby' );

		switch ($orderby){
			case 'group_course' :
				$query->set( 'meta_key', 'group_course' );
				$query->set( 'orderby', 'meta_value_num' );
				break;
		}
	}

	public static function get_group( $group_id = '' ) {
		$group_id = ( $group_id ) ? $group_id : get_the_ID();
		if ( $group_id && ! get_post( $group_id ) ) {
			return false;
		}
		$data         = array();
		$user_courses = get_user_meta( get_current_user_id(), 'courses', true );

		$data['ID']                       = $group_id;
		$data['teachers']                 = get_post_meta( $group_id, 'group_teachers', true );
		$data['course_id']                = get_post_meta( $group_id, 'group_course', true );
		$data['students']                 = get_post_meta( $group_id, 'group_students', true );
		$data['max_students']             = get_post_meta( $group_id, 'group_max_students', true );
		$data['language']                 = get_post_meta( $group_id, 'group_language', true );
		$data['associated_product']       = get_post_meta( $group_id, 'group_associated_product', true );
		$data['free']                     = get_post_meta( $group_id, 'free_group', true );
		$data['status']                   = get_post_meta( $group_id, 'group_status', true );
		$data['language_ids']             = get_post_meta( $group_id, 'group_languages', true );
		$data['group_days_label']         = get_post_meta( $group_id, 'group_days_label', true );
		$data['group_time_label']         = get_post_meta( $group_id, 'group_time_label', true );
		$data['group_pictures']           = get_post_meta( $group_id, 'group_pictures', true );
		$data['students_learned']         = get_post_meta( $group_id, 'students_learned', true );
		$data['students_learned_private'] = get_post_meta( $group_id, 'students_learned_private', true );
		$data['schedule_array']           = get_post_meta( $group_id, 'schedule', true );
		$data['schedule']                 = array();
		$data['languages']                = '';

		$attachments_private = get_post_meta( $group_id, 'attachments_private', true );
		$attachments         = get_post_meta( $group_id, 'group_attachments', true );

		if( ( ! $attachments_private || isset( $user_courses[ $group_id ] ) ) && $attachments ){
			$data['attachments'] = $attachments;
		}else{
			$data['attachments'] = array();
		}

		if( $data['language_ids'] ){
			foreach ( $data['language_ids'] as $lang ){
				$lang_term = get_term_by( 'id', $lang, ULMS_COURSE_LANGUAGES_CATEGORY_SLUG );
				if( $data['languages'] ){
					$data['languages'] .= ', ' . $lang_term->name;
				}else{
					$data['languages'] .= $lang_term->name;
				}
			}
		}

		if( $data['schedule_array'] ){
			$i=0;
			foreach ($data['schedule_array'] as $schedule){
				if( ! empty( $schedule['datetime_start'] ) ){
					$data['schedule'][$i] = array(
						'title' => get_the_title( $group_id ),
						'start' => str_replace( ' ', 'T', $schedule['datetime_start'] ),
						'url'   => get_the_permalink( $group_id )
					);
					if( ! empty( $schedule['datetime_end'] ) ){
						$data['schedule'][$i]['end'] = str_replace( ' ', 'T', $schedule['datetime_end'] );
					}
					if( ! empty( $schedule['repeat'] ) ){
						$data['schedule'][$i]['dow'] = $schedule['repeat'];
					}
					$i++;
				}
			}
		}

		$data['sale_price']         = '';
		$data['regular_price']      = '';
		$data['price']              = '';
		$data['price_html']         = '<span class="woocommerce-Price-amount">' . esc_html__( 'Free', 'ulms' ) . '</span>';

		if ( class_exists( 'WooCommerce' ) ) {
			$_product = wc_get_product( $data['associated_product'] );
			if ( $_product && ! $data['free'] ) {
				$data['price']         = $_product->get_price();
				$data['sale_price']    = $_product->get_sale_price();
				$data['regular_price'] = $_product->get_regular_price();
				$data['price_html']    = $_product->get_price_html();
				if ( ! $_product->get_price_html() ) {
					$data['free']       = true;
					$data['price_html'] = '<span class="woocommerce-Price-amount">' . esc_html__( 'Free', 'ulms' ) . '</span>';
				}
			}
		}

		if( ! self::is_available( $group_id ) ){
			$data['status'] = 'closed';
		}

		return $data;
	}

	public static function is_available( $group_id ) {
		if( get_post_meta( $group_id, 'group_max_students', true ) == 'closed' ){
			return false;
		}
		$max_students = get_post_meta( $group_id, 'group_max_students', true );
		$students = get_post_meta( $group_id, 'group_students', true );
		if( ! $max_students ){
			return true;
		}else if( $students < $max_students ){
			return true;
		}else{
			return false;
		}
	}

	public function register_meta() {
		register_meta( 'post', 'group_course', 'absint' );
		register_meta( 'post', 'group_status', 'esc_attr' );
		register_meta( 'post', 'group_max_students', 'absint' );
		register_meta( 'post', 'group_students', 'absint' );
		register_meta( 'post', 'group_days_label', 'esc_attr' );
		register_meta( 'post', 'group_time_label', 'esc_attr' );

		register_meta( 'post', 'students_learned_private', 'absint' );
		register_meta( 'post', 'attachments_private', 'absint' );

		register_meta( 'post', 'free_group', 'absint' );
		register_meta( 'post', 'group_associated_product', 'esc_attr' );
	}

	public function add_meta_box() {
		add_meta_box( 'runa-group-settings', esc_html__( 'Group Settings', 'ulms' ), array( $this, 'group_settings_render' ), array( ULMS_GROUPS_POST_TYPE ), 'normal' );
	}

	public function group_settings_render() {
		global $post;
		$group_course       = ( $post->group_course ) ? $post->group_course : 0;
		$group_status       = ( $post->group_status ) ? $post->group_status : 0;
		$group_teachers     = get_post_meta( $post->ID, 'group_teachers', true );
		$group_languages    = get_post_meta( $post->ID, 'group_languages', true );
		$group_max_students = ( $post->group_max_students ) ? $post->group_max_students : 0;
		$group_students     = ( $post->group_students ) ? $post->group_students : 0;
		$group_days_label   = $post->group_days_label;
		$group_time_label   = $post->group_time_label;

		$group_pictures    = get_post_meta( $post->ID, 'group_pictures', true );
		$group_attachments = get_post_meta( $post->ID, 'group_attachments', true );

		$students_learned         = get_post_meta( $post->ID, 'students_learned', true );
		$students_learned_private = ( $post->students_learned_private ) ? $post->students_learned_private : 0;
		$attachments_private      = ( $post->attachments_private ) ? $post->attachments_private : 0;

		$schedule = get_post_meta( $post->ID, 'schedule', true );

		$free_group               = $post->free_group;
		$group_associated_product = $post->group_associated_product;
		?>

		<div class="runa-tabs">
			<ul class="runa-tabs-nav">
				<li>
					<a class="active" href="#general">
						<i class="fa fa-cog"></i>
						<span><?php esc_html_e( 'General', 'ulms' ); ?></span>
					</a>
				</li>
				<li>
					<a href="#group-pictures">
						<i class="fa fa-picture-o"></i>
						<span><?php esc_html_e( 'Group Pictures', 'ulms' ); ?></span>
					</a>
				</li>
				<li>
					<a href="#group-students">
						<i class="fa fa-users"></i>
						<span><?php esc_html_e( 'Group Students', 'ulms' ); ?></span>
					</a>
				</li>
				<li>
					<a href="#group-attachments">
						<i class="fa fa-files-o"></i>
						<span><?php esc_html_e( 'Attachments', 'ulms' ); ?></span>
					</a>
				</li>
				<li>
					<a href="#product">
						<i class="fa fa-shopping-cart"></i>
						<span><?php esc_html_e( 'Group Product', 'ulms' ); ?></span>
					</a>
				</li>
				<li>
					<a href="#schedule">
						<i class="fa fa-calendar"></i>
						<span><?php esc_html_e( 'Schedule', 'ulms' ); ?></span>
					</a>
				</li>
			</ul>
			<div class="runa-tabs-tab active" id="general">
				<div class="options-group">
					<div class="form-field">
						<label for="group_course">
							<span><?php esc_html_e( 'Course', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Select course to associate with current group', 'ulms' ); ?>"></i>
						</label>
						<select name="group_course" class="s2" id="group_course">
							<?php
							$courses_list = new WP_Query( array(
								'post_type' => ULMS_COURSES_POST_TYPE,
								'posts_per_page' => -1
							) );
							?>
							<?php if ( $courses_list->have_posts() ): ?>
								<?php while ( $courses_list->have_posts() ): $courses_list->the_post(); ?>
									<option value="<?php echo esc_attr( get_the_ID() ); ?>" <?php selected( get_the_ID(), $group_course) ; ?>><?php echo esc_html( get_the_title() ); ?></option>
								<?php endwhile; wp_reset_postdata(); ?>
							<?php endif; ?>
						</select>
					</div>
				</div>
				<div class="options-group">
					<div class="form-field">
						<label for="group_status">
							<span><?php esc_html_e( 'Status', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Availability of group for new students', 'ulms' ); ?>"></i>
						</label>
						<select name="group_status" class="s2" id="group_status">
							<option value="open" <?php selected( 'open', $group_status) ; ?>><?php esc_html_e( 'Open', 'ulms' ); ?></option>
							<option value="closed" <?php selected( 'closed', $group_status) ; ?>><?php esc_html_e( 'Closed', 'ulms' ); ?></option>
						</select>
					</div>
				</div>
				<div class="options-group">
					<div class="form-field">
						<label for="group_teachers">
							<span><?php esc_html_e( 'Teachers', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Teachers associated with current group', 'ulms' ); ?>"></i>
						</label>
						<select name="group_teachers[]" class="s2" multiple id="group_teachers">
							<?php
							$users_list = get_users( array(
								'role'   => ULMS_TEACHERS_ROLE,
								'fields' => array( 'ID', 'display_name' )
							) );
							?>
							<?php if ( $users_list ): ?>
								<?php foreach ( $users_list as $user ): ?>
									<option value="<?php echo esc_attr( $user->ID ); ?>" <?php if ( $group_teachers ) { selected( true, in_array( $user->ID, $group_teachers ) ); } ?>><?php echo esc_html( $user->display_name ); ?></option>
								<?php endforeach; ?>
							<?php endif; ?>
						</select>
					</div>
				</div>
				<div class="options-group">
					<div class="form-field">
						<label for="group_max_students">
							<span><?php esc_html_e( 'Maximum students', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Maximum number of students in current group', 'ulms' ); ?>"></i>
						</label>
						<input id="group_max_students" class="input-form" type="number" name="group_max_students" min="0" step="1" value="<?php echo esc_attr( $group_max_students ); ?>"/>
					</div>
				</div>
				<div class="options-group">
					<div class="form-field">
						<label for="group_students">
							<span><?php esc_html_e( 'Students enrolled', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Number of students enrolled in current group', 'ulms' ); ?>"></i>
						</label>
						<input id="group_students" class="input-form" type="number" name="group_students" min="0" step="1" value="<?php echo esc_attr( $group_students ); ?>"/>
					</div>
				</div>
				<div class="options-group">
					<div class="form-field">
						<label for="group_languages">
							<span><?php esc_html_e( 'Languages', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Group language', 'ulms' ); ?>"></i>
						</label>
						<select name="group_languages[]" class="s2" id="group_languages" multiple>
							<?php
							$languages = get_terms( ULMS_COURSE_LANGUAGES_CATEGORY_SLUG, array(
								'hide_empty' => false
							) );
							?>
							<?php if ( $languages ): ?>
								<?php foreach ( $languages as $language ): ?>
									<option value="<?php echo esc_attr( $language->term_id ); ?>" <?php if ( $group_languages ) { selected( true, in_array( $language->term_id, $group_languages ) ); } ?>><?php echo esc_html( $language->name ); ?></option>
								<?php endforeach; ?>
							<?php endif; ?>
						</select>
					</div>
				</div>
				<div class="options-group">
					<div class="form-field">
						<label for="group_days_label">
							<span><?php esc_html_e( 'Days Label', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Day of the week for a brief information on group list', 'ulms' ); ?>"></i>
						</label>
						<input id="group_days_label" class="input-form" type="text" name="group_days_label" value="<?php echo esc_attr( $group_days_label ); ?>"/>
					</div>
				</div>
				<div class="options-group">
					<div class="form-field">
						<label for="group_time_label">
							<span><?php esc_html_e( 'Time Label', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Lessons time for a brief information in group list', 'ulms' ); ?>"></i>
						</label>
						<input id="group_time_label" class="input-form" type="text" name="group_time_label" value="<?php echo esc_attr( $group_time_label ); ?>"/>
					</div>
				</div>
			</div>
			<div class="runa-tabs-tab" id="group-pictures">
				<div class="image-gallery-wr">
					<a onclick="runa_add_images( jQuery('#group-pictures-gallery'), 'group_pictures' ); return false;" class="button button-primary button-large" href="#"><?php esc_html_e( 'Add Image', 'ulms' ); ?></a>
					<ul class="image-gallery" id="group-pictures-gallery">
						<?php if ( $group_pictures ): ?>
							<?php foreach ( $group_pictures as $key => $val ): ?>
								<?php if ( $thumbnail = wp_get_attachment_image_src( $val ) ): ?>
									<li>
										<div class="image-wr">
											<a onclick="runa_remove_image( jQuery(this), jQuery('#group-pictures-gallery'), 'group_pictures' ); return false;" href="#" class="remove"><i class="fa fa-times"></i></a>
											<img src="<?php echo esc_url( $thumbnail[0] ); ?>" alt=""/>
										</div>
										<input class="value" type="hidden" name="group_pictures[<?php echo esc_attr( $key ); ?>]" value="<?php echo esc_attr( $val ); ?>"/>
									</li>
								<?php endif; ?>
							<?php endforeach; ?>
						<?php endif; ?>
					</ul>
				</div>
			</div>
			<div class="runa-tabs-tab" id="group-students">
				<div class="options-group">
					<div class="form-field">
						<label for="students_learned_private">
							<input type="checkbox" name="students_learned_private" id="students_learned_private" value="1" <?php checked( 1, $students_learned_private ); ?> />
							<span><?php esc_html_e( 'Private', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Show only to the participants', 'ulms' ); ?>"></i>
						</label>
					</div>
				</div>
				<div class="options-group">
					<div class="form-field">
						<label for="students_learned">
							<span><?php esc_html_e( 'Students', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Students associated with group', 'ulms' ); ?>"></i>
						</label>

						<select name="students_learned[]" class="s2" multiple id="students_learned">
							<?php
							$users_list = get_users( array(
								'role'   => ULMS_STUDENT_ROLE,
								'fields' => array( 'ID', 'display_name' )
							) );
							?>
							<?php if ( $users_list ): ?>
								<?php foreach ( $users_list as $user ): ?>
									<option value="<?php echo esc_attr( $user->ID ); ?>" <?php if ( $students_learned ) { selected( true, in_array( $user->ID, $students_learned ) ); } ?>><?php echo esc_html( $user->display_name ); ?></option>
								<?php endforeach; ?>
							<?php endif; ?>

						</select>
					</div>
				</div>
			</div>
			<div class="runa-tabs-tab" id="group-attachments">
				<div class="options-group">
					<div class="form-field">
						<label for="attachments_private">
							<input type="checkbox" name="attachments_private" id="attachments_private" value="1" <?php checked( 1, $attachments_private ); ?> />
							<span><?php esc_html_e( 'Private', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Show only to the participants', 'ulms' ); ?>"></i>
						</label>
					</div>
				</div>
				<div class="files-list-wr">
					<a onclick="runa_add_attachments( jQuery('#group-attachments-list'), 'group_attachments' ); return false;" class="button button-primary button-large" href="#">
						<?php esc_html_e( 'Add Attachment', 'ulms' ); ?>
					</a>
					<ul class="files-list" id="group-attachments-list">
						<?php if ( $group_attachments ): ?>
							<?php foreach ( $group_attachments as $key => $val ): ?>
								<?php if( $attachment = get_post( $val ) ): ?>
									<li>
										<?php $attached_file = get_attached_file( $val ); ?>
										<i class="handle <?php echo esc_attr( ulms_get_file_icon( $attached_file ) ); ?>"></i>
										<div class="title"><a href="<?php echo esc_url( get_edit_post_link( $val ) ); ?>" target="_blank"><?php echo esc_html( basename( $attached_file ) ); ?></a></div>
										<a onclick="runa_remove_image( jQuery(this), jQuery('#group-attachments-list'), 'group_attachments' ); return false;" href="#" class="remove"><i class="fa fa-times"></i></a>
										<input class="value" type="hidden" name="group_attachments[<?php echo esc_attr( $key ); ?>]" value="<?php echo esc_attr( $val ); ?>"/>
									</li>
								<?php endif; ?>
							<?php endforeach; ?>
						<?php endif; ?>
					</ul>
				</div>
			</div>
			<div class="runa-tabs-tab" id="product">
				<div class="options-group">
					<div class="form-field">
						<label for="free_course">
							<input type="checkbox" name="free_group" id="free_group" value="1" <?php checked( 1, $free_group ); ?> />
							<span><?php esc_html_e( 'Free Group', 'ulms' ); ?></span>
						</label>
					</div>
				</div>
				<?php
				$query_products = new WP_Query( array(
					'post_type'      => 'product',
					'posts_per_page' => 9999
				) );
				?>
				<?php if ( $query_products->have_posts() ): ?>
					<div class="options-group">
						<div class="form-field">
							<label for="group_associated_product">
								<span><?php esc_html_e( 'Associated Product', 'ulms' ); ?></span>
								<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Choose product to associate with group and to set a price', 'ulms' ); ?>"></i>
							</label>
							<select name="group_associated_product" class="s2" id="group_associated_product">
								<option value="0"><?php esc_html_e( '--Not chosen--', 'ulms' ); ?></option>
								<?php while ( $query_products->have_posts() ): $query_products->the_post(); ?>
									<option value="<?php echo esc_attr( get_the_ID() ); ?>" <?php selected( $group_associated_product, get_the_ID() ); ?>><?php echo esc_html( get_the_title() ); ?></option>
								<?php endwhile;
								wp_reset_postdata(); ?>
							</select>
						</div>
					</div>
				<?php endif; ?>
			</div>
			<div class="runa-tabs-tab" id="schedule">
				<?php $repeat_days = array( 'Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday' ); ?>
				<script type="text/javascript">
					var schedule_texts = [];
					schedule_texts['start'] = '<?php esc_html_e( 'Start', 'ulms' ); ?>';
					schedule_texts['end'] = '<?php esc_html_e( 'End', 'ulms' ); ?>';
					schedule_texts['repeat'] = '<?php esc_html_e( 'Repeat', 'ulms' ); ?>';
					schedule_texts['delete'] = '<?php esc_html_e( 'Delete Lesson', 'ulms' ); ?>';
					schedule_texts['days'] = <?php echo json_encode( $repeat_days ); ?>;
				</script>
				<div class="schedule-wr">
					<a id="schedule_add_lesson" class="button button-primary button-large" href="#"><?php esc_html_e( 'Add Lesson', 'ulms' ); ?></a>
					<ul id="schedule-list" class="schedule-list">
						<?php if( $schedule ): ?>
							<?php foreach ( $schedule as $key => $val ) : ?>
								<li>
									<div class="datetime-start">
										<label><?php esc_html_e( 'Start', 'ulms' ); ?></label>
										<input class="datetime-picker lesson_start" type="text" name="schedule[<?php echo esc_attr( $key ); ?>][datetime_start]" value="<?php echo esc_attr( $val['datetime_start'] ); ?>" />
									</div>
									<div class="datetime-end">
										<label><?php esc_html_e( 'End', 'ulms' ); ?></label>
										<input class="datetime-picker lesson_end" type="text" name="schedule[<?php echo esc_attr( $key ); ?>][datetime_end]" value="<?php echo esc_attr( $val['datetime_end'] ); ?>" />
									</div>
									<div class="lesson-repeat">
										<label><?php esc_html_e( 'Repeat', 'ulms' ); ?></label>
										<select class="s2 lesson_repeat" name="schedule[<?php echo esc_attr( $key ); ?>][repeat][]" multiple>
											<?php foreach( $repeat_days as $day_id => $day_text ): ?>
												<option <?php if ( ! empty( $val['repeat'] ) ) { selected( true, in_array( $day_id, $val['repeat'] ) ); } ?> value="<?php echo esc_attr( $day_id ); ?>"><?php echo esc_attr( $day_text ); ?></option>
											<?php endforeach; ?>
										</select>
									</div>
									<a class="remove-lesson" href="#"><?php esc_html_e( 'Delete Lesson', 'ulms' ); ?></a>
								</li>
							<?php endforeach; ?>
						<?php endif; ?>
					</ul>
				</div>
			</div>
		</div>

		<?php
	}

	public function save_post( $post_id ) {
		global $post;

		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return;
		}

		if ( ! is_object( $post ) ) {
			return;
		}

		if ( ULMS_GROUPS_POST_TYPE != $post->post_type ) {
			return;
		}

		if ( ! current_user_can( 'edit_post', $post->ID ) ) {
			return;
		}

		$group_course             = isset( $_POST['group_course'] ) ? $_POST['group_course'] : '';
		$group_status             = isset( $_POST['group_status'] ) ? $_POST['group_status'] : '';
		$group_teachers           = isset( $_POST['group_teachers'] ) ? $_POST['group_teachers'] : '';
		$group_max_students       = isset( $_POST['group_max_students'] ) ? $_POST['group_max_students'] : 0;
		$group_students           = isset( $_POST['group_students'] ) ? $_POST['group_students'] : 0;
		$group_languages          = isset( $_POST['group_languages'] ) ? $_POST['group_languages'] : '';
		$group_days_label         = isset( $_POST['group_days_label'] ) ? $_POST['group_days_label'] : '';
		$group_time_label         = isset( $_POST['group_time_label'] ) ? $_POST['group_time_label'] : '';
		$group_pictures           = isset( $_POST['group_pictures'] ) ? $_POST['group_pictures'] : '';
		$group_attachments        = isset( $_POST['group_attachments'] ) ? $_POST['group_attachments'] : '';
		$students_learned         = isset( $_POST['students_learned'] ) ? $_POST['students_learned'] : '';
		$students_learned_private = isset( $_POST['students_learned_private'] ) ? $_POST['students_learned_private'] : 0;
		$attachments_private      = isset( $_POST['attachments_private'] ) ? $_POST['attachments_private'] : 0;
		$schedule                 = isset( $_POST['schedule'] ) ? $_POST['schedule'] : '';
		$free_group               = isset( $_POST['free_group'] ) ? 1 : 0;
		$group_associated_product = isset( $_POST['group_associated_product'] ) ? $_POST['group_associated_product'] : '';
		if ( ! $group_associated_product ) {
			$free_group = true;
		}

		update_post_meta( $post->ID, 'group_course', $group_course );
		update_post_meta( $post->ID, 'group_status', $group_status );
		update_post_meta( $post->ID, 'group_teachers', $group_teachers );
		update_post_meta( $post->ID, 'group_max_students', $group_max_students );
		update_post_meta( $post->ID, 'group_students', $group_students );
		update_post_meta( $post->ID, 'group_languages', $group_languages );
		update_post_meta( $post->ID, 'group_days_label', $group_days_label );
		update_post_meta( $post->ID, 'group_time_label', $group_time_label );
		update_post_meta( $post->ID, 'group_pictures', $group_pictures );
		update_post_meta( $post->ID, 'group_attachments', $group_attachments );
		update_post_meta( $post->ID, 'attachments_private', $attachments_private );
		update_post_meta( $post->ID, 'students_learned', $students_learned );
		update_post_meta( $post->ID, 'students_learned_private', $students_learned_private );
		update_post_meta( $post->ID, 'schedule', $schedule );
		update_post_meta( $post->ID, 'free_group', $free_group );
		update_post_meta( $post->ID, 'group_associated_product', $group_associated_product );

	}

}

Runa_Groups::getInstance();