<?php

class Runa_Lessons {

	private static $_instance = NULL;

	public static function getInstance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}

		return self::$_instance;
	}

	public function __construct() {
		add_action( 'init', array( $this, 'register_meta' ) );
		add_action( 'admin_menu', array( $this, 'add_meta_box' ) );
		add_action( 'save_post', array( $this, 'save_post' ) );

		add_filter( 'manage_' . ULMS_COURSES_LESSONS_POST_TYPE . '_posts_columns', array( $this, 'admin_posts_columns_labels' ) );
		add_action( 'manage_' . ULMS_COURSES_LESSONS_POST_TYPE . '_posts_custom_column', array( $this, 'admin_custom_columns' ), 10, 2 );
	}

	public function register_meta() {
		register_meta( 'post', 'lesson_type', 'esc_attr' );
		register_meta( 'post', 'lesson_duration', 'absint' );
		register_meta( 'post', 'lesson_duration_parameter', 'absint' );
	}

	public function add_meta_box() {
		add_meta_box( 'runa-lesson-settings', esc_html__( 'Lesson Settings', 'ulms' ), array( $this, 'lesson_settings_render' ), array( ULMS_COURSES_LESSONS_POST_TYPE ), 'normal' );
	}

	public function lesson_settings_render() {
		global $post;

		$lesson_type               = $post->lesson_type;
		$lesson_duration           = $post->lesson_duration;
		$lesson_duration_parameter = ( $post->lesson_duration_parameter ) ? $post->lesson_duration_parameter : 60;
		$lesson_embed = ( $post->lesson_embed ) ? $post->lesson_embed : '';
		$lesson_courses = get_post_meta( $post->ID, 'lesson_courses', true );

		?>

		<div class="runa-tabs">
			<ul class="runa-tabs-nav">
				<li>
					<a class="active" href="#general">
						<i class="fa fa-cog"></i>
						<span><?php esc_html_e( 'General', 'ulms' ); ?></span>
					</a>
				</li>
				<li>
					<a href="#embed">
						<i class="fa fa-cog"></i>
						<span><?php esc_html_e( 'Embed', 'ulms' ); ?></span>
					</a>
				</li>
			</ul>
			<div class="runa-tabs-tab active" id="general">
				<div class="options-group">
					<div class="form-field">
						<label for="lesson_type">
							<span><?php esc_html_e( 'lesson Type', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Lesson type for brief information', 'ulms' ); ?>"></i>
						</label>
						<select name="lesson_type" id="lesson_type">
							<option value="video" <?php selected( $lesson_type, 'video' ); ?>><?php esc_html_e( 'Video', 'ulms' ); ?></option>
							<option value="audio" <?php selected( $lesson_type, 'audio' ); ?>><?php esc_html_e( 'Audio', 'ulms' ); ?></option>
							<option value="general" <?php selected( $lesson_type, 'general' ); ?>><?php esc_html_e( 'General', 'ulms' ); ?></option>
						</select>
					</div>
				</div>
				<div class="options-group">
					<div class="form-field">
						<label for="lesson_duration">
							<span><?php esc_html_e( 'Duration', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Duration of lesson', 'ulms' ); ?>"></i>
						</label>
						<input id="lesson_duration" required type="number" name="lesson_duration" class="input-form" min="0" step="1" value="<?php echo esc_attr( $lesson_duration ); ?>" />
					</div>
				</div>
				<div class="options-group">
					<div class="form-field">
						<label for="lesson_duration_parameter">
							<span><?php esc_html_e( 'Duration parameter', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Unit of time', 'ulms' ); ?>"></i>
						</label>
						<select id="lesson_duration_parameter" name="lesson_duration_parameter">
							<option <?php selected( $lesson_duration_parameter, 1 ); ?> value="1"><?php esc_html_e( 'Seconds', 'ulms' ); ?></option>
							<option <?php selected( $lesson_duration_parameter, 60 ); ?> value="60"><?php esc_html_e( 'Minutes', 'ulms' ); ?></option>
							<option <?php selected( $lesson_duration_parameter, 3600 ); ?> value="3600"><?php esc_html_e( 'Hours', 'ulms' ); ?></option>
							<option <?php selected( $lesson_duration_parameter, 86400 ); ?> value="86400"><?php esc_html_e( 'Days', 'ulms' ); ?></option>
							<option <?php selected( $lesson_duration_parameter, 604800 ); ?> value="604800"><?php esc_html_e( 'Weeks', 'ulms' ); ?></option>
							<option <?php selected( $lesson_duration_parameter, 2592000 ); ?> value="2592000"><?php esc_html_e( 'Months', 'ulms' ); ?></option>
						</select>
					</div>
				</div>
				<div class="options-group">
					<div class="form-field">
						<label for="lesson_courses">
							<span><?php esc_html_e( 'Show in Courses', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'List of courses associated with lesson', 'ulms' ); ?>"></i>
						</label>
						<select id="lesson_courses" name="lesson_courses[]" class="s2" multiple>
							<?php
							$courses_list = new WP_Query( array(
								'post_type' => ULMS_COURSES_POST_TYPE,
								'posts_per_page' => -1
							) );
							?>
							<?php if ( $courses_list->have_posts() ): ?>
								<?php while ( $courses_list->have_posts() ): $courses_list->the_post(); ?>
									<option value="<?php echo esc_attr( get_the_ID() ); ?>" <?php if ( $lesson_courses ) { selected( true, in_array( get_the_ID(), $lesson_courses ) ); } ?>><?php echo esc_html( get_the_title() ); ?></option>
								<?php endwhile; wp_reset_postdata(); ?>
							<?php endif; ?>
						</select>
					</div>
				</div>
			</div>
			<div class="runa-tabs-tab" id="embed">
				<div class="options-group">
					<div class="form-field">
						<label for="lesson_type">
							<span><?php esc_html_e( 'Embed', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Enter the block of HTML which is embedded in the page-source.', 'ulms' ); ?>"></i>
						</label>
						<textarea name="lesson_embed"><?php echo wp_kses_post( $lesson_embed ); ?></textarea>
					</div>
				</div>
			</div>
		</div>

		<?php
	}

	public function save_post( $post_id ) {
		global $post;

		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return;
		}

		if ( ! is_object( $post ) ) {
			return;
		}

		if ( ULMS_COURSES_LESSONS_POST_TYPE != $post->post_type ) {
			return;
		}

		if ( ! current_user_can( 'edit_post', $post->ID ) ) {
			return;
		}

		$lesson_type = isset( $_POST['lesson_type'] ) ? $_POST['lesson_type'] : 'video';
		$lesson_duration = isset( $_POST['lesson_duration'] ) ? $_POST['lesson_duration'] : 0;
		$lesson_duration_parameter = isset( $_POST['lesson_duration_parameter'] ) ? $_POST['lesson_duration_parameter'] : 60;
		$lesson_embed = isset( $_POST['lesson_embed'] ) ? $_POST['lesson_embed'] : '';
		$lesson_courses = isset( $_POST['lesson_courses'] ) ? $_POST['lesson_courses'] : '';

		update_post_meta( $post->ID, 'lesson_type', $lesson_type );
		update_post_meta( $post->ID, 'lesson_duration', $lesson_duration );
		update_post_meta( $post->ID, 'lesson_duration_parameter', $lesson_duration_parameter );
		update_post_meta( $post->ID, 'lesson_embed', $lesson_embed );
		update_post_meta( $post->ID, 'lesson_courses', $lesson_courses );

	}

	public function admin_posts_columns_labels( $existing_columns ) {
		unset( $existing_columns['date'] );
		$columns['lesson_type'] = esc_html__( 'Type', 'ulms' );
		$columns['lesson_courses'] = esc_html__( 'Courses', 'ulms' );

		return array_merge( $existing_columns, $columns );
	}

	public function admin_custom_columns( $column, $post_id ) {
		switch ( $column ) {

			case 'lesson_courses' :
				$lesson_courses = get_post_meta( $post_id, 'lesson_courses', true );
				$courses_array = array();
				if( $lesson_courses ){
					foreach ( $lesson_courses as $course ) {
						$courses_array[] = '<a href="' . esc_url( get_the_permalink( $course ) ) . '">' . esc_html( get_the_title( $course ) ) . '</a>';
					}
				}
				if( $courses_array ){
					echo implode( ', ', $courses_array );
				}
				break;

			case 'lesson_type' :
				$lesson_type = get_post_meta( $post_id, 'lesson_type', true );
				if ( $lesson_type == 'general' ):
					esc_html_e( 'General', 'ulms' );
				elseif ( $lesson_type == 'video' ):
					esc_html_e( 'Video', 'ulms' );
				elseif ( $lesson_type == 'audio' ):
					esc_html_e( 'Audio', 'ulms' );
				endif;
				break;

		}
	}

}

Runa_Lessons::getInstance();