<?php

class Runa_Page_Post_Settings {

	private static $_instance = NULL;

	public static function getInstance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}

		return self::$_instance;
	}

	public function __construct() {
		add_action( 'init', array( $this, 'register_meta' ) );

		if ( ! is_admin() ) {
			return;
		}

		add_action( 'admin_menu', array( $this, 'add_meta_box' ) );
		add_action( 'save_post', array( $this, 'save_post' ) );
	}

	public function register_meta() {
		register_meta( 'post', 'enable_transparent_header', 'absint' );
		register_meta( 'post', 'title_box_style', 'esc_attr' );
		register_meta( 'post', 'title_box_image', 'esc_attr' );
		register_meta( 'post', 'sidebar_position', 'esc_attr' );
		register_meta( 'post', 'sidebar', 'esc_attr' );
		register_meta( 'post', 'enable_cta', 'absint' );
		register_meta( 'post', 'cta_icon', 'esc_attr' );
		register_meta( 'post', 'cta_title', 'esc_attr' );
		register_meta( 'post', 'cta_button_text', 'esc_attr' );
		register_meta( 'post', 'cta_button_link', 'esc_url' );
	}

	public function add_meta_box() {
		add_meta_box( 'runa-page-settings', esc_html__( 'Page Settings', 'ulms' ), array( $this, 'page_settings_render' ), array( 'page', 'post' ), 'side' );
		add_meta_box( 'runa-title-box-image', esc_html__( 'Title Box Image', 'ulms' ), array( $this, 'title_box_image_render' ), array( 'page', 'post' ), 'side' );
		add_meta_box( 'runa-cta', esc_html__( 'Call To Action', 'ulms' ), array( $this, 'call_to_action_render' ), array( 'page', 'post' ) );
	}

	public function page_settings_render() {
		global $post;

		$enable_transparent_header = $post->enable_transparent_header;
		$title_box_style = $post->title_box_style;
		$sidebar_position = $post->sidebar_position;
		$sidebar = $post->sidebar;
		?>

		<p>
			<label for="enable_transparent_header">
				<input type="checkbox" name="enable_transparent_header" id="enable_transparent_header" value="1" <?php checked( 1, $enable_transparent_header ); ?>>
				<?php esc_html_e( 'Enable Transparent Header', 'ulms' ); ?>
			</label>
		</p>

		<p>
			<label for="title_box_style"><?php esc_html_e( 'Title Box Style', 'ulms' ); ?></label>
			<select name="title_box_style" id="title_box_style">
				<option value="style_1" <?php selected( $title_box_style, 'style_1' ); ?>><?php esc_html_e( 'Style 1', 'ulms' ); ?></option>
				<option value="style_2" <?php selected( $title_box_style, 'style_2' ); ?>><?php esc_html_e( 'Style 2', 'ulms' ); ?></option>
				<option value="disable" <?php selected( $title_box_style, 'disable' ); ?>><?php esc_html_e( 'Disable', 'ulms' ); ?></option>
			</select>
		</p>

		<p>
			<label for="sidebar_position"><?php esc_html_e( 'Sidebar Position', 'ulms' ); ?></label>
			<select name="sidebar_position" id="sidebar_position">
				<option value="right" <?php selected( $sidebar_position, 'right' ); ?>><?php esc_html_e( 'Right', 'ulms' ); ?></option>
				<option value="left" <?php selected( $sidebar_position, 'left' ); ?>><?php esc_html_e( 'Left', 'ulms' ); ?></option>
			</select>
		</p>

		<p>
			<label for="sidebar_name"><?php esc_html_e( 'Sidebar', 'ulms' ); ?></label>
			<select name="sidebar" id="sidebar_name">
				<?php foreach ( $GLOBALS['wp_registered_sidebars'] as $val ) { ?>
					<option value="<?php echo esc_attr( $val['id'] ); ?>" <?php selected( $sidebar, $val['id'] ); ?>>
						<?php echo ucwords( $val['name'] ); ?>
					</option>
				<?php } ?>
				<option value="disable" <?php selected( $sidebar, 'disable' ); ?>><?php esc_html_e( 'Disable', 'ulms' ); ?></option>
			</select>
		</p>

		<?php
	}

	public function title_box_image_render(){
		global $post;

		$title_box_image = $post->title_box_image;
		?>
		<div class="runa-title-box-image">
			<p class="hide-if-no-js">
				<a href="#" id="set-title-box-image"><?php esc_html_e( 'Set title box image', 'ulms' ); ?></a>
			</p>

			<div id="title-box-image-container" class="hidden">
				<img src="<?php echo wp_get_attachment_url( $title_box_image ); ?>" alt="" />
			</div>

			<p class="hide-if-no-js hidden">
				<a href="#" id="remove-title-box-image"><?php esc_html_e( 'Remove title box image', 'ulms' ); ?></a>
			</p><!-- .hide-if-no-js -->

			<input type="hidden" id="title_box_image_id" name="title_box_image" value="<?php echo esc_attr( $title_box_image ); ?>" />
		</div>

		<?php
	}

	public function call_to_action_render() {
		global $post;

		$enable_cta      = $post->enable_cta;
		$cta_icon        = $post->cta_icon;
		$cta_title       = $post->cta_title;
		$cta_button_text = $post->cta_button_text;
		$cta_button_link = $post->cta_button_link;
		?>

		<div class="runa_table">
			<p>
				<input type="checkbox" name="enable_cta" id="enable_cta" value="1" <?php checked( 1, $enable_cta ); ?>>
				<label for="enable_cta">Enable</label>
			</p>
			<table>
				<tr>
					<td><label for="cta_icon"><?php esc_html_e( 'Icon', 'ulms' ); ?></label></td>
					<td><input id="cta_icon" type="text" name="cta_icon" value="<?php echo esc_attr( $cta_icon ); ?>"/></td>
				</tr>
				<tr>
					<td><label for="cta_title"><?php esc_html_e( 'Title', 'ulms' ); ?></label></td>
					<td><input id="cta_title" type="text" name="cta_title" value="<?php echo esc_attr( $cta_title ); ?>"/></td>
				</tr>
				<tr>
					<td><label for="cta_button_text"><?php esc_html_e( 'Button Text', 'ulms' ); ?></label></td>
					<td><input id="cta_button_text" type="text" name="cta_button_text" value="<?php echo esc_attr( $cta_button_text ); ?>"/></td>
				</tr>
				<tr>
					<td><label for="cta_button_link"><?php esc_html_e( 'Button Link', 'ulms' ); ?></label></td>
					<td><input id="cta_button_link" type="text" name="cta_button_link" value="<?php echo esc_attr( $cta_button_link ); ?>"/></td>
				</tr>
			</table>
			<script type="text/javascript">
				jQuery(document).ready(function ($) {
					$('#cta_icon').fontIconPicker({
						source: ulms_icons_array,
						theme: 'fip-grey'
					});
				});
			</script>
		</div>

		<?php
	}

	public function save_post( $post_id ) {
		global $post;

		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return;
		}

		if ( ! is_object( $post ) ) {
			return;
		}

		if ( 'page' != $post->post_type && 'post' != $post->post_type ) {
			return;
		}

		if ( ! current_user_can( 'edit_post', $post->ID ) ) {
			return;
		}

		$enable_transparent_header = isset( $_POST['enable_transparent_header'] ) ? 1 : 0;
		$title_box_style = isset( $_POST['title_box_style'] ) ? $_POST['title_box_style'] : 'style_1';
		$title_box_image = isset( $_POST['title_box_image'] ) ? $_POST['title_box_image'] : '';
		$sidebar_position = isset( $_POST['sidebar_position'] ) ? $_POST['sidebar_position'] : 'right';
		$sidebar = isset( $_POST['sidebar'] ) ? $_POST['sidebar'] : 'ulms-right-sidebar';
		$enable_cta = isset( $_POST['enable_cta'] ) ? 1 : 0;
		$cta_icon = isset( $_POST['cta_icon'] ) ? $_POST['cta_icon'] : '';
		$cta_title = isset( $_POST['cta_title'] ) ? $_POST['cta_title'] : '';
		$cta_button_text = isset( $_POST['cta_button_text'] ) ? $_POST['cta_button_text'] : '';
		$cta_button_link = isset( $_POST['cta_button_link'] ) ? $_POST['cta_button_link'] : '';

		update_post_meta( $post->ID, 'enable_transparent_header', $enable_transparent_header );
		update_post_meta( $post->ID, 'title_box_style', $title_box_style );
		update_post_meta( $post->ID, 'title_box_image', $title_box_image );
		update_post_meta( $post->ID, 'sidebar_position', $sidebar_position );
		update_post_meta( $post->ID, 'sidebar', $sidebar );
		update_post_meta( $post->ID, 'enable_cta', $enable_cta );
		update_post_meta( $post->ID, 'cta_title', $cta_title );
		update_post_meta( $post->ID, 'cta_icon', $cta_icon );
		update_post_meta( $post->ID, 'cta_button_text', $cta_button_text );
		update_post_meta( $post->ID, 'cta_button_link', $cta_button_link );
	}

}

Runa_Page_Post_Settings::getInstance();