<?php

class Runa_Questions {

	private static $_instance = NULL;

	public static function getInstance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}

		return self::$_instance;
	}

	public function __construct() {
		add_action( 'init', array( $this, 'register_meta' ) );
		add_action( 'admin_menu', array( $this, 'add_meta_box' ) );
		add_action( 'save_post', array( $this, 'save_post' ) );

		add_filter( 'manage_' . ULMS_COURSES_QUESTION_POST_TYPE . '_posts_columns', array( $this, 'admin_posts_columns_labels' ) );
		add_action( 'manage_' . ULMS_COURSES_QUESTION_POST_TYPE . '_posts_custom_column', array( $this, 'admin_custom_columns' ), 10, 2 );
	}

	public function register_meta() {
		register_meta( 'post', 'question_hint', 'esc_attr' );
		register_meta( 'post', 'question_answer', 'absint' );
	}

	public function add_meta_box() {
		add_meta_box( 'runa-question-settings', esc_html__( 'Question Settings', 'ulms' ), array( $this, 'question_settings_render' ), array( ULMS_COURSES_QUESTION_POST_TYPE ), 'normal' );
	}

	public function question_settings_render() {
		global $post;

		$question_hint = $post->question_hint;
		$question_answer = $post->question_answer;
		$question_options = get_post_meta( $post->ID, 'question_options', true );
		$question_quizzes = get_post_meta( $post->ID, 'question_quizzes', true );

		?>

		<div class="runa-tabs">
			<ul class="runa-tabs-nav">
				<li>
					<a class="active" href="#general">
						<i class="fa fa-cog"></i>
						<span><?php esc_html_e( 'General', 'ulms' ); ?></span>
					</a>
				</li>
				<li>
					<a href="#question_options">
						<i class="fa fa-list-ol"></i>
						<span><?php esc_html_e( 'Options', 'ulms' ); ?></span>
					</a>
				</li>
			</ul>
			<div class="runa-tabs-tab active" id="general">
				<div class="options-group">
					<div class="form-field">
						<label for="question_hint">
							<span><?php esc_html_e( 'Hint', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Hint is available optionality if the question too difficult', 'ulms' ); ?>"></i>
						</label>
						<textarea id="question_hint" name="question_hint" style="height: 100px;" class="input-form"><?php echo esc_attr( $question_hint ); ?></textarea>
					</div>
				</div>
				<div class="options-group">
					<div class="form-field">
						<label for="question_quizzes">
							<span><?php esc_html_e( 'Show in Quizzes', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Quizzes associated with question', 'ulms' ); ?>"></i>
						</label>
						<select id="question_quizzes" name="question_quizzes[]" class="s2" multiple>
							<?php
							$quizzes_list = new WP_Query( array(
								'post_type' => ULMS_COURSES_QUIZ_POST_TYPE,
								'posts_per_page' => -1
							) );
							?>
							<?php if ( $quizzes_list->have_posts() ): ?>
								<?php while ( $quizzes_list->have_posts() ): $quizzes_list->the_post(); ?>
									<option value="<?php echo esc_attr( get_the_ID() ); ?>" <?php if ( $question_quizzes ) { selected( true, in_array( get_the_ID(), $question_quizzes ) ); } ?>><?php echo esc_html( get_the_title() ); ?></option>
								<?php endwhile; wp_reset_postdata(); ?>
							<?php endif; ?>
						</select>
					</div>
				</div>
			</div>
			<div class="runa-tabs-tab" id="question_options">
				<div class="question-options-wr">
					<a class="add_question_option button button-primary button-large" href="#"><?php esc_html_e( 'Add Option', 'ulms' ); ?></a>
					<ul id="sortable-question-options" class="curriculum-sortable">
						<?php if ( $question_options ): $i=0; ?>
							<?php foreach ( $question_options as $key => $val ): $i++; ?>
								<li>
									<i class="handle num"><?php echo esc_html( $i ); ?></i>
									<input class="value" type="text" value="<?php echo esc_attr( $val ); ?>" name="question_options[<?php echo esc_attr( $key ); ?>]" />
									<label class="correct-answer">
										<?php esc_html_e( 'Correct', 'ulms' ); ?>
										<input type="radio" <?php checked( $question_answer, $key ); ?> name="question_answer" value="<?php echo esc_attr( $key ); ?>">
									</label>
									<a class="remove" href="#"><i class="fa fa-times"></i></a>
								</li>
							<?php endforeach; ?>
						<?php endif; ?>
					</ul>
				</div>
			</div>
		</div>

		<?php
	}

	public function save_post( $post_id ) {
		global $post;

		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return;
		}

		if ( ! is_object( $post ) ) {
			return;
		}

		if ( ULMS_COURSES_QUESTION_POST_TYPE != $post->post_type ) {
			return;
		}

		if ( ! current_user_can( 'edit_post', $post->ID ) ) {
			return;
		}

		$question_hint = isset( $_POST['question_hint'] ) ? $_POST['question_hint'] : '';
		$question_options = isset( $_POST['question_options'] ) ? $_POST['question_options'] : '';
		$question_answer = isset( $_POST['question_answer'] ) ? $_POST['question_answer'] : '';
		$question_quizzes = isset( $_POST['question_quizzes'] ) ? $_POST['question_quizzes'] : '';

		update_post_meta( $post->ID, 'question_hint', $question_hint );
		update_post_meta( $post->ID, 'question_options', $question_options );
		update_post_meta( $post->ID, 'question_answer', $question_answer );
		update_post_meta( $post->ID, 'question_quizzes', $question_quizzes );

	}

	public function admin_posts_columns_labels( $existing_columns ) {
		unset( $existing_columns['date'] );
		$columns['question_quizzes'] = esc_html__( 'Quizzes', 'ulms' );

		return array_merge( $existing_columns, $columns );
	}

	public function admin_custom_columns( $column, $post_id ) {
		switch ( $column ) {

			case 'question_quizzes' :
				$question_quizzes = get_post_meta( $post_id, 'question_quizzes', true );
				$quizzes_array = array();
				if( $question_quizzes ){
					foreach ( $question_quizzes as $quiz ) {
						$quizzes_array[] = '<a href="' . esc_url( get_the_permalink( $quiz ) ) . '">' . esc_html( get_the_title( $quiz ) ) . '</a>';
					}
				}
				if( $quizzes_array ){
					echo implode( ', ', $quizzes_array );
				}
				break;

		}
	}

}

Runa_Questions::getInstance();