<?php

class Runa_Quizzes {

	private static $_instance = NULL;

	public static function getInstance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}

		return self::$_instance;
	}

	public function __construct() {
		add_action( 'init', array( $this, 'register_meta' ) );
		add_action( 'admin_menu', array( $this, 'add_meta_box' ) );
		add_action( 'save_post', array( $this, 'save_post' ) );

		add_filter( 'manage_' . ULMS_COURSES_QUIZ_POST_TYPE . '_posts_columns', array( $this, 'admin_posts_columns_labels' ) );
		add_action( 'manage_' . ULMS_COURSES_QUIZ_POST_TYPE . '_posts_custom_column', array( $this, 'admin_custom_columns' ), 10, 2 );
	}

	public function register_meta() {
		register_meta( 'post', 'quiz_duration', 'absint' );
		register_meta( 'post', 'quiz_duration_parameter', 'absint' );
		register_meta( 'post', 'quiz_required_points', 'absint' );
	}

	public function add_meta_box() {
		add_meta_box( 'runa-quiz-settings', esc_html__( 'Quiz Settings', 'ulms' ), array( $this, 'quiz_settings_render' ), array( ULMS_COURSES_QUIZ_POST_TYPE ), 'normal' );
	}

	public function quiz_settings_render() {
		global $post;

		$quiz_required_points    = $post->quiz_required_points;
		$quiz_duration           = $post->quiz_duration;
		$quiz_duration_parameter = ( $post->quiz_duration_parameter ) ? $post->quiz_duration_parameter : 60;
		$quiz_questions = get_post_meta( $post->ID, 'quiz_questions', true );
		$quiz_final_message = get_post_meta( $post->ID, 'quiz_final_message', true );
		$quiz_courses = get_post_meta( $post->ID, 'quiz_courses', true );

		?>

		<div class="runa-tabs">
			<ul class="runa-tabs-nav">
				<li>
					<a class="active" href="#general">
						<i class="fa fa-cog"></i>
						<span><?php esc_html_e( 'General', 'ulms' ); ?></span>
					</a>
				</li>
				<li>
					<a href="#questions">
						<i class="fa fa-question-circle"></i>
						<span><?php esc_html_e( 'Questions', 'ulms' ); ?></span>
					</a>
				</li>
			</ul>
			<div class="runa-tabs-tab active" id="general">
				<div class="options-group">
					<div class="form-field">
						<label for="quiz_duration">
							<span><?php esc_html_e( 'Duration', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Duration of quiz', 'ulms' ); ?>"></i>
						</label>
						<input id="quiz_duration" type="number" name="quiz_duration" class="input-form" min="0" step="1" value="<?php echo esc_attr( $quiz_duration ); ?>" />
					</div>
				</div>
				<div class="options-group">
					<div class="form-field">
						<label for="quiz_duration_parameter">
							<span><?php esc_html_e( 'Duration parameter', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Unit of time', 'ulms' ); ?>"></i>
						</label>
						<select id="quiz_duration_parameter" name="quiz_duration_parameter">
							<option <?php selected( $quiz_duration_parameter, 1 ); ?> value="1"><?php esc_html_e( 'Seconds', 'ulms' ); ?></option>
							<option <?php selected( $quiz_duration_parameter, 60 ); ?> value="60"><?php esc_html_e( 'Minutes', 'ulms' ); ?></option>
							<option <?php selected( $quiz_duration_parameter, 3600 ); ?> value="3600"><?php esc_html_e( 'Hours', 'ulms' ); ?></option>
						</select>
					</div>
				</div>
				<div class="options-group">
					<div class="form-field">
						<label for="quiz_required_points">
							<span><?php esc_html_e( 'Min required points', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Minimal required points for passing quiz', 'ulms' ); ?>"></i>
						</label>
						<input id="quiz_required_points" type="number" name="quiz_required_points" class="input-form" min="0" step="1" value="<?php echo esc_attr( $quiz_required_points ); ?>" />
					</div>
				</div>
				<div class="options-group">
					<div class="form-field">
						<label for="quiz_final_message">
							<span><?php esc_html_e( 'Final Message', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'Enter some information or inspiring words for student that will be shown after the end of Quiz.', 'ulms' ); ?>"></i>
						</label>
						<textarea id="quiz_final_message" name="quiz_final_message" class="input-form"><?php echo esc_html( $quiz_final_message ); ?></textarea>
					</div>
				</div>
				<div class="options-group">
					<div class="form-field">
						<label for="quiz_courses">
							<span><?php esc_html_e( 'Show in Courses', 'ulms' ); ?></span>
							<i class="tooltip fa fa-question-circle" title="<?php esc_attr_e( 'List of courses where the quiz is available', 'ulms' ); ?>"></i>
						</label>
						<select id="quiz_courses" name="quiz_courses[]" class="s2" multiple>
							<?php
							$courses_list = get_posts( array(
								'post_type' => ULMS_COURSES_POST_TYPE,
								'posts_per_page' => -1
							) );
							?>
							<?php if ( $courses_list ): ?>
								<?php foreach ( $courses_list as $course ): ?>
									<option value="<?php echo esc_attr( $course->ID ); ?>" <?php if ( $quiz_courses ) { selected( true, in_array( $course->ID, $quiz_courses ) ); } ?>><?php echo esc_html( get_the_title( $course->ID ) ); ?></option>
								<?php endforeach; ?>
							<?php endif; ?>
						</select>
					</div>
				</div>
			</div>
			<div class="runa-tabs-tab" id="questions">
				<?php
				$all_questions       = get_posts( array(
					'post_type'      => ULMS_COURSES_QUESTION_POST_TYPE,
					'posts_per_page' => -1,
					'meta_query'     => array(
						array(
							'key' => 'question_quizzes',
							'value' => $post->ID,
							'compare' => 'LIKE'
						)
					)
				) );
				$all_questions_array = array();
				if ( $all_questions ) {
					foreach ( $all_questions as $val ) {
						$all_questions_array[] = array(
							'id'   => $val->ID,
							'text' => get_the_title( $val->ID )
						);
					}
				}
				?>
				<div class="questions-wr">
					<a class="add_question button button-primary button-large" href="#"><?php esc_html_e( 'Add Question', 'ulms' ); ?></a>
					<ul id="sortable-questions" class="curriculum-sortable">
						<?php if ( $quiz_questions ): $i=0; ?>
							<?php foreach ( $quiz_questions as $key => $val ): $i++; ?>
								<li>
									<i class="handle num"><?php echo esc_html( $i ); ?></i>
									<select class="value s2" name="quiz_questions[<?php echo esc_attr( $key ); ?>][question_id]">
										<?php foreach ( $all_questions as $question ): ?>
											<option <?php selected( $question->ID, $val['question_id'] ); ?> value="<?php echo esc_attr( $question->ID ); ?>"><?php echo esc_html( get_the_title( $question->ID ) ); ?></option>
										<?php endforeach; ?>
									</select>
									<input class="question_point" placeholder="<?php esc_attr_e( 'Point', 'ulms' ); ?>" type="number" value="<?php echo esc_attr( $val['question_point'] ); ?>" name="quiz_questions[<?php echo esc_attr( $key ); ?>][question_point]" />
									<a class="remove" href="#"><i class="fa fa-times"></i></a>
								</li>
							<?php endforeach; ?>
						<?php endif; ?>
					</ul>
					<script type="text/javascript">
						var all_questions_array = [];
						<?php if( $all_questions_array ): ?>
						all_questions_array = <?php echo json_encode( $all_questions_array ); ?>;
						<?php endif; ?>
					</script>
				</div>
			</div>
		</div>

		<?php
	}

	public function save_post( $post_id ) {
		global $post;

		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return;
		}

		if ( ! is_object( $post ) ) {
			return;
		}

		if ( ULMS_COURSES_QUIZ_POST_TYPE != $post->post_type ) {
			return;
		}

		if ( ! current_user_can( 'edit_post', $post->ID ) ) {
			return;
		}

		$quiz_duration           = isset( $_POST['quiz_duration'] ) ? $_POST['quiz_duration'] : 0;
		$quiz_duration_parameter = isset( $_POST['quiz_duration_parameter'] ) ? $_POST['quiz_duration_parameter'] : 60;
		$quiz_questions          = isset( $_POST['quiz_questions'] ) ? $_POST['quiz_questions'] : '';
		$quiz_required_points    = isset( $_POST['quiz_required_points'] ) ? $_POST['quiz_required_points'] : 0;
		$quiz_final_message      = isset( $_POST['quiz_final_message'] ) ? $_POST['quiz_final_message'] : '';
		$quiz_courses            = isset( $_POST['quiz_courses'] ) ? $_POST['quiz_courses'] : '';

		update_post_meta( $post->ID, 'quiz_duration', $quiz_duration );
		update_post_meta( $post->ID, 'quiz_duration_parameter', $quiz_duration_parameter );
		update_post_meta( $post->ID, 'quiz_questions', $quiz_questions );
		update_post_meta( $post->ID, 'quiz_required_points', $quiz_required_points );
		update_post_meta( $post->ID, 'quiz_final_message', $quiz_final_message );
		update_post_meta( $post->ID, 'quiz_courses', $quiz_courses );

	}

	public function admin_posts_columns_labels( $existing_columns ) {
		unset( $existing_columns['date'] );
		$columns['lesson_courses'] = esc_html__( 'Courses', 'ulms' );

		return array_merge( $existing_columns, $columns );
	}

	public function admin_custom_columns( $column, $post_id ) {
		switch ( $column ) {

			case 'lesson_courses' :
				$quiz_courses = get_post_meta( $post_id, 'quiz_courses', true );
				$courses_array = array();
				if( $quiz_courses ){
					foreach ( $quiz_courses as $course ) {
						$courses_array[] = '<a href="' . esc_url( get_the_permalink( $course ) ) . '">' . esc_html( get_the_title( $course ) ) . '</a>';
					}
				}
				if( $courses_array ){
					echo implode( ', ', $courses_array );
				}
				break;

		}
	}

}

Runa_Quizzes::getInstance();