<?php

class Runa_Testimonials {

	private static $_instance = NULL;

	public static function getInstance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}

		return self::$_instance;
	}

	public function __construct() {
		add_action( 'init', array( $this, 'register_meta' ) );

		if ( ! is_admin() ) {
			return;
		}

		add_action( 'admin_menu', array( $this, 'add_meta_box' ) );
		add_action( 'save_post', array( $this, 'save_post' ) );
	}

	public function register_meta() {
		register_meta( 'post', 'testimonial_rating', 'absint' );
	}

	public function add_meta_box() {
		add_meta_box( 'testimonial-settings', esc_html__( 'Settings', 'ulms' ), array( $this, 'settings_render' ), ULMS_TESTIMONIALS_POST_TYPE );
	}

	public function settings_render() {
		global $post;

		$testimonial_rating = $post->testimonial_rating;
		?>

		<p>
			<label for="testimonial_rating"><?php esc_html_e( 'Rating', 'ulms' ); ?></label>
			<select name="testimonial_rating" id="testimonial_rating">
				<option value="0" <?php selected( $testimonial_rating, '0' ); ?>><?php esc_html_e( 'No rating', 'ulms' ); ?></option>
				<option value="1" <?php selected( $testimonial_rating, '1' ); ?>><?php esc_html_e( '1 star', 'ulms' ); ?></option>
				<option value="2" <?php selected( $testimonial_rating, '2' ); ?>><?php esc_html_e( '2 stars', 'ulms' ); ?></option>
				<option value="3" <?php selected( $testimonial_rating, '3' ); ?>><?php esc_html_e( '3 stars', 'ulms' ); ?></option>
				<option value="4" <?php selected( $testimonial_rating, '4' ); ?>><?php esc_html_e( '4 stars', 'ulms' ); ?></option>
				<option value="5" <?php selected( $testimonial_rating, '5' ); ?>><?php esc_html_e( '5 stars', 'ulms' ); ?></option>
			</select>
		</p>

		<?php
	}

	public function save_post( $post_id ) {
		global $post;

		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return;
		}

		if ( ! is_object( $post ) ) {
			return;
		}

		if ( ULMS_TESTIMONIALS_POST_TYPE != $post->post_type ) {
			return;
		}

		if ( ! current_user_can( 'edit_post', $post->ID ) ) {
			return;
		}

		$testimonial_rating = isset( $_POST['testimonial_rating'] ) ? $_POST['testimonial_rating'] : 0;

		update_post_meta( $post->ID, 'testimonial_rating', $testimonial_rating );
	}

}

Runa_Testimonials::getInstance();