<?php

class Runa_Users {

	private static $_instance = NULL;

	public static function getInstance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}

		return self::$_instance;
	}

	public function __construct() {
		add_action( 'show_user_profile', array( $this, 'show_extra_profile_fields' ) );
		add_action( 'edit_user_profile', array( $this, 'show_extra_profile_fields' ) );

		add_action( 'personal_options_update', array( $this, 'save_extra_profile_fields' ) );
		add_action( 'edit_user_profile_update', array( $this, 'save_extra_profile_fields' ) );

		add_filter( 'manage_users_columns', array( $this, 'add_column' ) );
		add_filter( 'manage_users_custom_column', array( $this, 'show_column_content' ), 10, 3 );

		add_action( 'init', array( $this, 'teachers_setup' ) );
		add_action( 'pre_get_posts', array( $this, 'check_user_comments_post' ) );
		add_filter( 'comment_post_redirect', array( $this, 'users_comment_redirect' ), 10, 2 );

	}

	public function users_comment_redirect( $location, $comment ){
		if( $comment ){
			if( get_post_type( $comment->comment_post_ID ) == ULMS_USER_COMMENTS_POST_TYPE ){
				if( ! empty( $_SERVER["HTTP_REFERER"] ) ){
					return $_SERVER["HTTP_REFERER"] . '#comment-' . $comment->comment_ID;
				}
			}
		}
		return $location;
	}

	public function check_user_comments_post($query){
		if ( $query->is_author() ) {
			$user_info = ( $query->query_vars['author_name'] ) ? get_user_by( 'slug', $query->query_vars['author_name'] ) : get_userdata( $query->query_vars['author'] );
			$post_created = false;
			$user_commenting_post = get_user_meta( $user_info->ID, 'user_commenting_post', true );
			if( $user_commenting_post && get_post( $user_commenting_post ) ){
				$post_created = true;
			}
			if( ! $post_created ){
				$post_id = wp_insert_post( array(
					'post_title' => esc_html( sprintf( __( 'User "%s" comments', 'ulms' ), $user_info->display_name ) ),
					'post_type' => ULMS_USER_COMMENTS_POST_TYPE,
					'post_status' => 'publish'
				) );
				if( ! is_wp_error( $post_id ) ){
					update_post_meta( $post_id, 'user_commenting_post', $user_info->ID );
					update_user_meta( $user_info->ID, 'user_commenting_post', $post_id );
				}
			}
		}
	}

	public function teachers_setup() {
		add_rewrite_endpoint( 'courses', EP_AUTHORS );
		add_rewrite_endpoint( 'groups', EP_AUTHORS );
	}

	public static function get_current_page(){
		global $wp_query;
		if ( isset( $wp_query->query_vars['courses'] ) ) {
			return 'courses';
		}else if ( isset( $wp_query->query_vars['groups'] ) ) {
			return 'groups';
		}else if ( isset( $wp_query->query_vars['reviews'] ) ) {
			return 'reviews';
		}else{
			return 'description';
		}
	}

	public function add_column( $columns ){
		$columns['account_status'] = esc_html__( 'Account Status', 'ulms' );
		return $columns;
	}

	function show_column_content( $value, $column_name, $user_id ) {
		if ( $column_name == 'account_status' ){
			$account_status = get_user_meta( $user_id, 'account_status', true );
			if( $account_status == 'locked' ){
				return esc_html__( 'Locked', 'ulms' );
			}else{
				return esc_html__( 'Unlocked', 'ulms' );
			}
		}
		return $value;
	}

	public function show_extra_profile_fields( $user ) { ?>

		<h3><?php esc_html_e( 'Extra profile information', 'ulms' )?></h3>

		<table class="form-table">

			<tr>
				<th><label for="account_status"><?php esc_html_e( 'Account Status', 'ulms' ); ?></label></th>
				<td>
					<?php $locking_data = get_user_meta( $user->ID, 'account_status', true ); ?>
					<select name="account_status" id="account_status">
						<option value="unlocked" <?php selected( $locking_data, '' ) ?> ><?php esc_html_e( 'Unlocked', 'ulms' ); ?></option>
						<option value="locked" <?php selected( $locking_data, 'locked' ) ?> ><?php esc_html_e( 'Locked', 'ulms' ); ?></option>
					</select>
				</td>
			</tr>
			<tr>
				<th><label for="speciality"><?php esc_html_e( 'Speciality', 'ulms' ); ?></label></th>
				<td>
					<input type="text" name="speciality" id="speciality" value="<?php echo esc_attr( get_the_author_meta( 'speciality', $user->ID ) ); ?>" class="regular-text" />
				</td>
			</tr>
			<tr>
				<th><label for="total_pupils"><?php esc_html_e( 'Total Pupils', 'ulms' ); ?></label></th>
				<td>
					<input type="number" step="1" min="0" name="total_pupils" id="total_pupils" value="<?php echo absint( get_the_author_meta( 'total_pupils', $user->ID ) ); ?>" class="regular-text" />
				</td>
			</tr>
			<tr>
				<th><label for="phone"><?php esc_html_e( 'Phone', 'ulms' ); ?></label></th>
				<td>
					<input type="tel" name="phone" id="phone" value="<?php echo esc_attr( get_the_author_meta( 'phone', $user->ID ) ); ?>" class="regular-text" />
				</td>
			</tr>
			<tr>
				<th><label for="facebook"><?php esc_html_e( 'Facebook Account', 'ulms' ); ?></label></th>
				<td>
					<input type="text" name="facebook" id="facebook" value="<?php echo esc_url( get_the_author_meta( 'facebook', $user->ID ) ); ?>" class="regular-text" />
				</td>
			</tr>
			<tr>
				<th><label for="twitter"><?php esc_html_e( 'Twitter Account', 'ulms' ); ?></label></th>
				<td>
					<input type="text" name="twitter" id="twitter" value="<?php echo esc_url( get_the_author_meta( 'twitter', $user->ID ) ); ?>" class="regular-text" />
				</td>
			</tr>
			<tr>
				<th><label for="google_plus"><?php esc_html_e( 'Google+ Account', 'ulms' ); ?></label></th>
				<td>
					<input type="text" name="google_plus" id="google_plus" value="<?php echo esc_url( get_the_author_meta( 'google_plus', $user->ID ) ); ?>" class="regular-text" />
				</td>
			</tr>
			<tr>
				<th><label for="linkedin"><?php esc_html_e( 'LinkedIn Account', 'ulms' ); ?></label></th>
				<td>
					<input type="text" name="linkedin" id="linkedin" value="<?php echo esc_url( get_the_author_meta( 'linkedin', $user->ID ) ); ?>" class="regular-text" />
				</td>
			</tr>
			<tr>
				<th><label for="full_description"><?php esc_html_e( 'Full Description', 'ulms' ); ?></label></th>
				<td>
					<textarea name="full_description" id="full_description" rows="5" cols="30" class="regular-text"><?php echo wp_kses_post( get_the_author_meta( 'full_description', $user->ID ) ); ?></textarea>
				</td>
			</tr>

		</table>
	<?php }

	function save_extra_profile_fields( $user_id ) {

		if ( ! current_user_can( 'edit_user', $user_id ) ) {
			return false;
		}

		if( $_POST['account_status'] == 'unlocked' ){
			delete_user_meta( absint( $user_id ), 'account_status' );
		}elseif( $_POST['account_status'] == 'locked' ){
			update_user_meta( absint( $user_id ), 'account_status', esc_attr( $_POST['account_status'] ) );
		}

		update_user_meta( absint( $user_id ), 'speciality', esc_attr( $_POST['speciality'] ) );
		update_user_meta( absint( $user_id ), 'total_pupils', absint( $_POST['total_pupils'] ) );
		update_user_meta( absint( $user_id ), 'phone', esc_attr( $_POST['phone'] ) );
		update_user_meta( absint( $user_id ), 'facebook', esc_url( $_POST['facebook'] ) );
		update_user_meta( absint( $user_id ), 'twitter', esc_url( $_POST['twitter'] ) );
		update_user_meta( absint( $user_id ), 'google_plus', esc_url( $_POST['google_plus'] ) );
		update_user_meta( absint( $user_id ), 'linkedin', esc_url( $_POST['linkedin'] ) );
		update_user_meta( absint( $user_id ), 'full_description', wp_kses_post( $_POST['full_description'] ) );
	}

}

Runa_Users::getInstance();