<?php

/**
 * For full documentation, please visit: http://docs.reduxframework.com/
 * For a more extensive sample-config file, you may look at:
 * https://github.com/reduxframework/redux-framework/blob/master/sample/sample-config.php
 */

if ( ! class_exists( 'Redux' ) ) {
	return;
}

if ( ! function_exists( 'redux_disable_dev_mode_plugin' ) ) {
	function redux_disable_dev_mode_plugin( $redux ) {
		if ( $redux->args['opt_name'] != 'redux_demo' ) {
			$redux->args['dev_mode']            = false;
			$redux->args['forced_dev_mode_off'] = false;
		}
	}

	add_action( 'redux/construct', 'redux_disable_dev_mode_plugin' );
}

// This is your option name where all the Redux data is stored.
$opt_name = "ulms_option";

/**
 * ---> SET ARGUMENTS
 * All the possible arguments for Redux.
 * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
 * */

$theme = wp_get_theme(); // For use with some settings. Not necessary.

$args = array(
	// TYPICAL -> Change these values as you need/desire
	'opt_name'             => $opt_name,
	// This is where your data is stored in the database and also becomes your global variable name.
	'display_name'         => $theme->get( 'Name' ),
	// Name that appears at the top of your panel
	'display_version'      => $theme->get( 'Version' ),
	// Version that appears at the top of your panel
	'menu_type'            => 'menu',
	//Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
	'allow_sub_menu'       => true,
	// Show the sections below the admin menu item or not
	'menu_title'           => esc_html__( 'Theme Options', 'ulms' ),
	'page_title'           => esc_html__( 'Theme Options', 'ulms' ),
	// You will need to generate a Google API key to use this feature.
	// Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
	'google_api_key'       => '',
	// Set it you want google fonts to update weekly. A google_api_key value is required.
	'google_update_weekly' => false,
	// Must be defined to add google fonts to the typography module
	'async_typography'     => false,
	// Use a asynchronous font on the front end or font string
	//'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
	'admin_bar'            => true,
	// Show the panel pages on the admin bar
	'admin_bar_icon'       => 'dashicons-admin-generic',
	// Choose an icon for the admin bar menu
	'admin_bar_priority'   => 50,
	// Choose an priority for the admin bar menu
	'global_variable'      => '',
	// Set a different name for your global variable other than the opt_name
	'dev_mode'             => false,
	// Show the time the page took to load, etc
	'update_notice'        => false,
	// If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
	'customizer'           => false,
	'customizer_only'      => false,
	// Enable basic customizer support
	//'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
	//'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

	// OPTIONAL -> Give you extra features
	'page_priority'        => null,
	// Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
	'page_parent'          => 'themes.php',
	// For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
	'page_permissions'     => 'manage_options',
	// Permissions needed to access the options panel.
	'menu_icon'            => '',
	// Specify a custom URL to an icon
	'last_tab'             => '',
	// Force your panel to always open to a specific tab (by id)
	'page_icon'            => 'icon-themes',
	// Icon displayed in the admin panel next to your menu_title
	'page_slug'            => 'ulms-theme-options',
	// Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
	'save_defaults'        => true,
	// On load save the defaults to DB before user clicks save or not
	'default_show'         => false,
	// If true, shows the default value next to each field that is not the default value.
	'default_mark'         => '',
	// What to print by the field's title if the value shown is default. Suggested: *
	'show_import_export'   => true,
	// Shows the Import/Export panel when not used as a field.

	// CAREFUL -> These options are for advanced use only
	'transient_time'       => 60 * MINUTE_IN_SECONDS,
	'output'               => true,
	// Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
	'output_tag'           => true,
	// Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
	// 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

	// FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
	'database'             => '',
	// possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
	'use_cdn'              => true,
	// If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

	// HINTS
	'hints'                => array(
		'icon'          => 'el el-question-sign',
		'icon_position' => 'right',
		'icon_color'    => 'lightgray',
		'icon_size'     => 'normal',
		'tip_style'     => array(
			'color'   => 'red',
			'shadow'  => true,
			'rounded' => false,
			'style'   => '',
		),
		'tip_position'  => array(
			'my' => 'top left',
			'at' => 'bottom right',
		),
		'tip_effect'    => array(
			'show' => array(
				'effect'   => 'slide',
				'duration' => '500',
				'event'    => 'mouseover',
			),
			'hide' => array(
				'effect'   => 'slide',
				'duration' => '500',
				'event'    => 'click mouseleave',
			),
		),
	)
);

Redux::setArgs( $opt_name, $args );

/*
 * ---> END ARGUMENTS
 */


/*
 *
 * ---> START SECTIONS
 *
 */

Redux::setSection( $opt_name, array(
	'title'  => esc_html__( 'General', 'ulms' ),
	'fields' => array(
		array(
			'id'       => 'logo',
			'url'      => false,
			'type'     => 'media',
			'title'    => esc_html__( 'Logo', 'ulms' ),
			'default'  => array( 'url' => get_template_directory_uri() . '/assets/images/logo.svg' ),
			'subtitle' => esc_html__( 'Upload your logo file here.', 'ulms' ),
		),
		array(
			'id'       => 'logo-white',
			'url'      => false,
			'type'     => 'media',
			'title'    => esc_html__( 'White Logo', 'ulms' ),
			'default'  => array( 'url' => get_template_directory_uri() . '/assets/images/logo-white.svg' ),
			'subtitle' => esc_html__( 'White logo is necessary for transparent headers', 'ulms' ),
		),
		array(
			'id'      => 'boxed_layout',
			'type'    => 'switch',
			'title'   => esc_html__( 'Boxed Layout', 'ulms' ),
			'default' => false
		),
		array(
			'id'       => 'layout_bg_image',
			'type'     => 'image_select',
			'title'    => esc_html__( 'Background Image', 'ulms' ),
			'options'  => array(
				'example-bg-1' => array(
					'img' => get_template_directory_uri() . '/assets/images/tmp/bg/prev-img-1.png'
				),
				'example-bg-2' => array(
					'img' => get_template_directory_uri() . '/assets/images/tmp/bg/prev-img-2.png'
				),
				'example-bg-3' => array(
					'img' => get_template_directory_uri() . '/assets/images/tmp/bg/prev-img-3.png'
				),
				'example-bg-4' => array(
					'img' => get_template_directory_uri() . '/assets/images/tmp/bg/prev-img-4.png'
				),
				'custom' => array(
					'img' => get_template_directory_uri() . '/assets/images/tmp/bg/prev-custom.png'
				),
			),
			'default'  => 'example-bg-1',
			'required' => array(
				array( 'boxed_layout', '=', true, )
			)
		),
		array(
			'id'       => 'layout_bg_custom_image',
			'type'     => 'background',
			'title'    => esc_html__( 'Custom Background', 'ulms' ),
			'required' => array(
				array( 'boxed_layout', '=', true, ),
				array( 'layout_bg_image', '=', 'custom' )
			),
			'output'   => array(
				'background-image' => 'body'
			)
		),
		array(
			'id'       => 'frontend_customizer_enabled',
			'type'     => 'switch',
			'title'    => esc_html__( 'Frontend Customizer', 'ulms' ),
			'default'  => false
		),
		array(
			'id'     => 'api_keys_section_start',
			'type'   => 'section',
			'title'  => esc_html__( 'API Keys', 'ulms' ),
			'indent' => true
		),
		array(
			'id'      => 'google_api_key',
			'type'    => 'text',
			'title'   => wp_kses( __( '<a href="//console.developers.google.com/flows/enableapi?apiid=maps_backend,geocoding_backend,directions_backend,distance_matrix_backend,elevation_backend,places_backend&reusekey=true" target="_blank">Google API Key</a>', 'ulms' ), array( 'a' => array( 'href' => array(), 'target' => array() ) ) ),
			'default' => ''
		),
		array(
			'id'     => 'api_keys_section_end',
			'type'   => 'section',
			'indent' => false,
		),
	)
) );

Redux::setSection( $opt_name, array(
	'title'  => esc_html__( 'Header', 'ulms' ),
	'icon'   => 'fa fa-window-maximize',
	'fields' => array(
		array(
			'id'      => 'header_style',
			'type'    => 'button_set',
			'title'   => esc_html__( 'Header Style', 'ulms' ),
			'options' => array(
				'header-style-1' => esc_html__( 'Style 1', 'ulms' ),
				'header-style-2' => esc_html__( 'Style 2', 'ulms' ),
				'header-style-3' => esc_html__( 'Style 3', 'ulms' ),
			),
			'default' => 'header-style-1'
		),
		array(
			'id'      => 'header_mode',
			'type'    => 'button_set',
			'title'   => esc_html__( 'Header Mode', 'ulms' ),
			'options' => array(
				'header-mode-static' => esc_html__( 'Static', 'ulms' ),
				'header-mode-sticky' => esc_html__( 'Sticky', 'ulms' )
			),
			'default' => 'header-mode-static'
		),
	)
) );

Redux::setSection( $opt_name, array(
	'title'      => esc_html__( 'Top Bar', 'ulms' ),
	'icon'  => 'el el-website',
	'fields'     => array(
		array(
			'title'   => esc_html__( 'Top Bar', 'ulms' ),
			'id'      => 'top_bar',
			'type'    => 'switch',
			'default' => true
		),
		array(
			'id'       => 'top_bar_wpml',
			'type'     => 'switch',
			'title'    => esc_html__( 'Top Bar WPML Switcher', 'ulms' ),
			'default'  => true,
			'required' => array(
				array( 'top_bar', '=', true )
			),
		),
		array(
			'id'       => 'top_bar_phone',
			'type'     => 'text',
			'title'    => esc_html__( 'Phone', 'ulms' ),
			'default'  => '+1 212-736-3100'
		),
		array(
			'id'       => 'top_bar_address',
			'type'     => 'text',
			'title'    => esc_html__( 'Address', 'ulms' ),
			'default'  => '350 5th Ave, New York, NY 10118, United States'
		),
		array(
			'id'       => 'top_bar_working_hours',
			'type'     => 'text',
			'title'    => esc_html__( 'Working Hours', 'ulms' ),
			'default'  => 'Sun - Sat  8.00 - 18.00'
		),
	)
) );

Redux::setSection( $opt_name, array(
	'title'   => esc_html__( 'Footer', 'ulms' ),
	'desc'    => '',
	'icon'    => 'fa fa-window-minimize',
	'submenu' => true,
	'fields'  => array(
		array(
			'id'      => 'footer_widgets',
			'type'    => 'switch',
			'title'   => esc_html__( 'Enable footer widgets area.', 'ulms' ),
			'default' => true,
		),
		array(
			'id'       => 'footer_sidebar_count',
			'type'     => 'button_set',
			'title'    => esc_html__( 'Footer Columns', 'ulms' ),
			'desc'     => esc_html__( 'Select the number of columns to display in the footer.', 'ulms' ),
			'default'  => '4',
			'required' => array( 'footer_widgets', '=', true, ),
			'options'  => array(
				'1' => esc_html__( '1 Columns', 'ulms' ),
				'2' => esc_html__( '2 Columns', 'ulms' ),
				'3' => esc_html__( '3 Columns', 'ulms' ),
				'4' => esc_html__( '4 Columns', 'ulms' ),
			),
		),
		array(
			'id'       => 'copyright',
			'type'     => 'textarea',
			'title'    => esc_html__( 'Footer Copyright', 'ulms' ),
			'subtitle' => esc_html__( 'Enter the copyright text.', 'ulms' ),
			'default'  => wp_kses( __( "Copyright &copy; 2016 Education Theme by <a href='http://runathemes.com/' target='_blank'>RunaThemes</a>", 'ulms' ), array( 'a' => array( 'href' => array(), 'target' => array() ) ) )
		),
	)
) );

Redux::setSection( $opt_name, array(
	'title'   => __( 'Styling', 'ulms' ),
	'desc'    => '',
	'icon'    => 'el-icon-tint',
	'submenu' => true,
	'fields'  => array(
		array(
			'id'      => 'color_skin',
			'type'    => 'button_set',
			'title'   => esc_html__( 'Color Skin', 'ulms' ),
			'options' => array(
				'skin-1'      => esc_html__( 'Skin 1', 'ulms' ),
				'skin-2'      => esc_html__( 'Skin 2', 'ulms' ),
				'skin-3'      => esc_html__( 'Skin 3', 'ulms' ),
				'skin-4'      => esc_html__( 'Skin 4', 'ulms' ),
				'custom-skin' => esc_html__( 'Custom Skin', 'ulms' ),
			),
			'default' => 'skin-1'
		),
		array(
			'id'         => 'theme_color_1',
			'type'       => 'color',
			'title'      => esc_html__('Color 1', 'ulms'),
			'default'    => '#00aaff',
			'transparent' => false,
			'validate'    => 'color',
			'required' => array( 'color_skin', '=', 'custom-skin' ),
		),
		array(
			'id'          => 'theme_color_2',
			'type'        => 'color',
			'title'       => esc_html__('Color 2', 'ulms'),
			'default'     => '#333e43',
			'transparent' => false,
			'validate'    => 'color',
			'required' => array( 'color_skin', '=', 'custom-skin' ),
		),
		array(
			'id'          => 'theme_color_3',
			'type'        => 'color',
			'title'       => esc_html__('Color 3', 'ulms'),
			'default'     => '#1bb934',
			'transparent' => false,
			'validate'    => 'color',
			'required' => array( 'color_skin', '=', 'custom-skin' ),
		),
		array(
			'id'          => 'theme_color_4',
			'type'        => 'color',
			'title'       => esc_html__('Color 4', 'ulms'),
			'default'     => '#fc7822',
			'transparent' => false,
			'validate'    => 'color',
			'required' => array( 'color_skin', '=', 'custom-skin' ),
		),
		array(
			'id'          => 'theme_color_5',
			'type'        => 'color',
			'title'       => esc_html__('Color 5', 'ulms'),
			'default'     => '#e45454',
			'transparent' => false,
			'validate'    => 'color',
			'required' => array( 'color_skin', '=', 'custom-skin' ),
		)
	)
) );

Redux::setSection( $opt_name, array(
	'title'   => esc_html__( 'Typography', 'ulms' ),
	'icon'    => 'el-icon-font',
	'submenu' => true,
	'fields'  => array(
		array(
			'id'             => 'font_body',
			'type'           => 'typography',
			'title'          => esc_html__( 'Body', 'ulms' ),
			'compiler'       => true,
			'google'         => true,
			'font-backup'    => false,
			'font-weight'    => true,
			'all_styles'     => true,
			'font-style'     => false,
			'subsets'        => true,
			'font-size'      => true,
			'line-height'    => true,
			'text-align'     => false,
			'word-spacing'   => false,
			'letter-spacing' => false,
			'color'          => false,
			'preview'        => true,
			'output'         => array(
				'body,
				.redux-base-font,
				.footer_widgets .widget_recent_entries ul li .post-details .post-categories a,
				.sidebar .widget.widget_recent_entries ul li .post-details .post-categories a,
				.top_nav .main_menu_nav,
				.top_nav .main_menu_nav > li > .sub-menu > li, 
				.top_nav .main_menu_nav > li > .children > li, 
				.top_nav .main_menu_nav > ul > li > .sub-menu > li, 
				.top_nav .main_menu_nav > ul > li > .children > li,
				.top_nav .main_menu_nav > li > .sub-menu > li .sub-menu li, 
				.top_nav .main_menu_nav > li > .sub-menu > li .children li, 
				.top_nav .main_menu_nav > li > .children > li .sub-menu li, 
				.top_nav .main_menu_nav > li > .children > li .children li, 
				.top_nav .main_menu_nav > ul > li > .sub-menu > li .sub-menu li, 
				.top_nav .main_menu_nav > ul > li > .sub-menu > li .children li, 
				.top_nav .main_menu_nav > ul > li > .children > li .sub-menu li, 
				.top_nav .main_menu_nav > ul > li > .children > li .children li,
				body .vc_general.vc_btn3.vc_btn3-style-theme, 
				.woocommerce button.button, 
				.button, 
				.post-password-form input[type="submit"],
				'
			),
			'units'          => 'px',
			'subtitle'       => esc_html__( 'Select custom font for your main body text.', 'ulms' )
		),
		array(
			'id'             => 'font_heading',
			'type'           => 'typography',
			'title'          => esc_html__( 'Heading', 'ulms' ),
			'compiler'       => true,
			'google'         => true,
			'font-backup'    => false,
			'all_styles'     => true,
			'font-weight'    => false,
			'font-style'     => false,
			'subsets'        => true,
			'font-size'      => false,
			'text-align'     => false,
			'line-height'    => false,
			'word-spacing'   => false,
			'letter-spacing' => false,
			'color'          => false,
			'preview'        => true,
			'output'         => array(
				'h1,.h1,h2,.h2,h3,.h3,h4,.h4,h5,.h5,h6,.h6,
				.runa-heading-font,
				.error404-wr p,
				.top_nav .main_menu_nav > li, .top_nav .main_menu_nav > ul > li,
				.main_slider_title_1,
				.main_slider_title_2,
				.vc_custom_heading.quote:before,
				.ulms_vc_info_box_mini .info_box_right .title,
				.ulms_vc_courses_slider .courses_slider_nav_wr .courses_slider_nav li,
				.ulms_vc_courses_slider .show_more_button,
				.ulms_vc_stats_counter .counter_value,
				.ulms_vc_stats_counter .counter_title,
				.ClassyCountdown-wrapper .ClassyCountdown-value div,
				.ClassyCountdown-wrapper .ClassyCountdown-value span,
				.ulms_gmap_carousel .gmap_addresses .item .item_wr .title,
				.runa_testimonials_carousel .testimonials-carousel li .testimonials-info .testimonials-title,
				body .vc_message_box,
				.woocommerce-checkout .col2-set .col-1 h3,
				.woocommerce-checkout .col2-set .col-2 h3, h3,
				body .vc_general.vc_btn3.vc_btn3-style-theme.size-lg, 
				body .vc_general.vc_btn3.vc_btn3-style-theme.vc_btn3-size-lg, 
				.woocommerce button.button.size-lg, 
				.woocommerce button.button.vc_btn3-size-lg, 
				.button.size-lg, 
				.post-password-form input.size-lg[type="submit"], 
				.button.vc_btn3-size-lg, 
				.post-password-form input.vc_btn3-size-lg[type="submit"],
				body .vc_general.vc_btn3.vc_btn3-style-theme.size-sm, body .post-password-form label input.vc_general.vc_btn3.vc_btn3-style-theme[type="password"], .post-password-form label body input.vc_general.vc_btn3.vc_btn3-style-theme[type="password"], body .post-password-form input.vc_general.vc_btn3.vc_btn3-style-theme[type="submit"], .post-password-form body input.vc_general.vc_btn3.vc_btn3-style-theme[type="submit"], body .address-edit-page .vc_general.vc_btn3.vc_btn3-style-theme.input-text, .address-edit-page body .vc_general.vc_btn3.vc_btn3-style-theme.input-text, body .woocommerce-checkout .col2-set .col-1 .vc_general.vc_btn3.vc_btn3-style-theme.input-text, .woocommerce-checkout .col2-set .col-1 body .vc_general.vc_btn3.vc_btn3-style-theme.input-text, body .woocommerce-checkout .col2-set .col-2 .vc_general.vc_btn3.vc_btn3-style-theme.input-text, .woocommerce-checkout .col2-set .col-2 body .vc_general.vc_btn3.vc_btn3-style-theme.input-text, body .woocommerce form.login .form-row .vc_general.vc_btn3.vc_btn3-style-theme.input-text, .woocommerce form.login .form-row body .vc_general.vc_btn3.vc_btn3-style-theme.input-text, body .woocommerce form.login .form-row .vc_general.vc_btn3.vc_btn3-style-theme.button, .woocommerce form.login .form-row body .vc_general.vc_btn3.vc_btn3-style-theme.button, body .woocommerce form.checkout_coupon .form-row .vc_general.vc_btn3.vc_btn3-style-theme.input-text, .woocommerce form.checkout_coupon .form-row body .vc_general.vc_btn3.vc_btn3-style-theme.input-text, body .woocommerce form.checkout_coupon .form-row .vc_general.vc_btn3.vc_btn3-style-theme.button, .woocommerce form.checkout_coupon .form-row body .vc_general.vc_btn3.vc_btn3-style-theme.button, body .account-orders-table .order-actions .vc_general.vc_btn3.vc_btn3-style-theme.button, .account-orders-table .order-actions body .vc_general.vc_btn3.vc_btn3-style-theme.button, body .vc_general.vc_btn3.vc_btn3-style-theme.vc_btn3-size-sm, .woocommerce button.button.size-sm, .woocommerce .address-edit-page button.button.input-text, .address-edit-page .woocommerce button.button.input-text, .woocommerce .woocommerce-checkout .col2-set .col-1 button.button.input-text, .woocommerce-checkout .col2-set .col-1 .woocommerce button.button.input-text, .woocommerce .woocommerce-checkout .col2-set .col-2 button.button.input-text, .woocommerce-checkout .col2-set .col-2 .woocommerce button.button.input-text, .woocommerce form.login .form-row button.button, .woocommerce form.checkout_coupon .form-row button.button, .woocommerce .account-orders-table .order-actions button.button, .account-orders-table .order-actions .woocommerce button.button, .woocommerce button.button.vc_btn3-size-sm, .button.size-sm, .post-password-form label input.button[type="password"], .post-password-form label input[type="password"][type="submit"], .post-password-form input[type="submit"], .address-edit-page .button.input-text, .woocommerce-checkout .col2-set .col-1 .button.input-text, .woocommerce-checkout .col2-set .col-1 .post-password-form input.input-text[type="submit"], .post-password-form .woocommerce-checkout .col2-set .col-1 input.input-text[type="submit"], .woocommerce-checkout .col2-set .col-2 .button.input-text, .woocommerce-checkout .col2-set .col-2 .post-password-form input.input-text[type="submit"], .post-password-form .woocommerce-checkout .col2-set .col-2 input.input-text[type="submit"], .woocommerce form.login .form-row .button, .woocommerce form.login .form-row .post-password-form input[type="submit"], .post-password-form .woocommerce form.login .form-row input[type="submit"], .woocommerce form.checkout_coupon .form-row .button, .woocommerce form.checkout_coupon .form-row .post-password-form input[type="submit"], .post-password-form .woocommerce form.checkout_coupon .form-row input[type="submit"], .account-orders-table .order-actions .button, .account-orders-table .order-actions .post-password-form input[type="submit"], .post-password-form .account-orders-table .order-actions input[type="submit"], .button.vc_btn3-size-sm, .post-password-form input.vc_btn3-size-sm[type="submit"],
				body .vc_general.vc_btn3.vc_btn3-style-theme.size-xs, body .vc_general.vc_btn3.vc_btn3-style-theme.vc_btn3-size-xs, .woocommerce button.button.size-xs, .woocommerce .sidebar .widget.widget_price_filter .price_slider_amount button.button, .sidebar .widget.widget_price_filter .price_slider_amount .woocommerce button.button, .woocommerce .woocommerce-message button.button, .woocommerce-message .woocommerce button.button, .woocommerce .woocommerce-error button.button, .woocommerce-error .woocommerce button.button, .woocommerce .woocommerce-info button.button, .woocommerce-info .woocommerce button.button, .woocommerce button.button.vc_btn3-size-xs, .button.size-xs, .post-password-form input.size-xs[type="submit"], .sidebar .widget.widget_price_filter .price_slider_amount .button, .sidebar .widget.widget_price_filter .price_slider_amount .post-password-form input[type="submit"], .post-password-form .sidebar .widget.widget_price_filter .price_slider_amount input[type="submit"], .woocommerce-message .button, .woocommerce-message .post-password-form input[type="submit"], .post-password-form .woocommerce-message input[type="submit"], .woocommerce-error .button, .woocommerce-error .post-password-form input[type="submit"], .post-password-form .woocommerce-error input[type="submit"], .woocommerce-info .button, .woocommerce-info .post-password-form input[type="submit"], .post-password-form .woocommerce-info input[type="submit"], .button.vc_btn3-size-xs, .post-password-form input.vc_btn3-size-xs[type="submit"],
				.cf7-contact-us-form .input-group .button, .cf7-contact-us-form .input-group .post-password-form input[type="submit"], .post-password-form .cf7-contact-us-form .input-group input[type="submit"],
				#footer .footer_bottom_wr .footer_bottom .footer_nav, #footer .footer_bottom_wr .footer_bottom .footer_nav > ul,
				.footer_widgets .widget_categories ul li, .footer_widgets .widget_archive ul li, .footer_widgets .widget_pages ul li, .footer_widgets .widget_product_categories ul li, .footer_widgets .widget_meta ul li,
				.footer_widgets .widget_calendar .calendar_wrap table caption,
				.footer_widgets .widget_recent_entries ul li a,
				.sidebar .widget.widget_calendar .calendar_wrap table caption,
				.sidebar .widget.widget_categories ul li, .sidebar .widget.widget_archive ul li, .sidebar .widget.widget_pages ul li, .sidebar .widget.widget_nav_menu ul li, .sidebar .widget.widget_product_categories ul li, .sidebar .widget.widget_meta ul li,
				.sidebar .widget.widget_recent_entries ul li a,
				.sidebar .widget.widget_top_rated_products .product_list_widget li .product-title,
				.sidebar .widget.widget_top_rated_products .product_list_widget li .amount,
				.sidebar .widget.widget-course-teacher .course-teacher .teacher-info h4,
				ul.page-numbers li .page-numbers,
				.page-links > span,
				.page-links a span,
				.comments-area .comment-list .comment .comment-body .comment-info .comment-author, 
				.comments-area .comment-list .pingback .comment-body .comment-info .comment-author,
				.comments-area .total-rating .total-rating-left .total-rating-value,
				.fc-event,
				.fc-toolbar .fc-left .fc-today-button,
				div.wpcf7-response-output,
				.attachments-table .show-more-button,
				.blog-grid li .post-thumbnail .sticky-label,
				.blog-grid li .post-categories,
				.blog-list li.has-post-thumbnail .post-thumbnail .post-title .post-categories,
				.blog-list li .post-categories,
				.search-result-container .search-result-header .see-all-link,
				.courses_list.grid li .course_wrapper .course_price,
				.courses_list.list li .course_image .course_price,
				.single-course-info .course-price del .woocommerce-Price-amount,
				.single-course-info .course-price ins, .single-course-info .course-price .woocommerce-Price-amount,
				.quiz-content .quiz-content-header .question-title,
				.quiz-content .quiz-content-header .quiz-type-name,
				.quiz-content .quiz-content-header .quiz-content-header-right .points-num,
				.quiz-content .quiz-content-header .quiz-content-header-right .progress-wrapper .progress strong,
				.quiz-content .quiz-questions .quiz-option .quiz-option-left,
				.quiz-result .quiz-result-message .quiz-result-message-left .title .quiz-report-button,
				.quiz-result .quiz-result-message .quiz-result-message-right .points-num,
				.quiz-result .quiz-result-message .quiz-result-message-right .progress-wrapper .progress strong,
				.quiz-result .quiz-report .quiz-report-list > li .points-num,
				.quiz-result .quiz-report .quiz-report-list > li .quiz-stats li span,
				.groups-list.grid li .group-wrapper .group-image-wr .group-image .group-price,
				.group-students .show-more-button,
				.account-login-form-wr .account-login-form .account-login-form-left .tab .login-form .login-message,
				.account-sidebar .account-nav li,
				.account-courses .isotope-item .item-wr .course-add-info,
				.account-courses .isotope-item .item-wr .course-students-num strong,
				.account-courses .isotope-item .item-wr .course-progress .progress-radial .overlay strong,
				.runa-woocommerce-shop-page .products li .product-wr .price,
				.runa-woocommerce-shop-page .products li .product-wr .price .free,
				.runa-woocommerce-shop-page .product .entry-summary .price,
				.shop_table tbody tr.cart_item td, .shop_table tbody tr.order_item td,
				.quantity .input-text,
				.woocommerce-message, .woocommerce-error, .woocommerce-info,
				div.uploader span.action,
				#header .mobile-header .main-top-menu > ul > li > a'
			),
			'units'          => 'px',
			'subtitle'       => esc_html__( 'Select custom font for headings', 'ulms' )
		),
		array(
			'id'             => 'h1_params',
			'type'           => 'typography',
			'title'          => esc_html__( 'H1', 'ulms' ),
			'compiler'       => true,
			'google'         => false,
			'font-backup'    => false,
			'all_styles'     => true,
			'font-weight'    => true,
			'font-family'    => false,
			'text-align'     => false,
			'font-style'     => false,
			'subsets'        => false,
			'font-size'      => true,
			'line-height'    => true,
			'word-spacing'   => false,
			'letter-spacing' => false,
			'color'          => false,
			'preview'        => true,
			'output'         => array( 'h1,.h1' ),
			'units'          => 'px'
		),
		array(
			'id'             => 'h2_params',
			'type'           => 'typography',
			'title'          => esc_html__( 'H2', 'ulms' ),
			'compiler'       => true,
			'google'         => false,
			'font-backup'    => false,
			'all_styles'     => true,
			'font-weight'    => true,
			'font-family'    => false,
			'text-align'     => false,
			'font-style'     => false,
			'subsets'        => false,
			'font-size'      => true,
			'line-height'    => true,
			'word-spacing'   => false,
			'letter-spacing' => false,
			'color'          => false,
			'preview'        => true,
			'output'         => array( 'h2,.h2' ),
			'units'          => 'px',
		),
		array(
			'id'             => 'h3_params',
			'type'           => 'typography',
			'title'          => esc_html__( 'H3', 'ulms' ),
			'compiler'       => true,
			'google'         => false,
			'font-backup'    => false,
			'all_styles'     => true,
			'font-weight'    => true,
			'font-family'    => false,
			'text-align'     => false,
			'font-style'     => false,
			'subsets'        => false,
			'font-size'      => true,
			'line-height'    => true,
			'word-spacing'   => false,
			'letter-spacing' => false,
			'color'          => false,
			'preview'        => true,
			'output'         => array( 'h3,.h3' ),
			'units'          => 'px'
		),
		array(
			'id'             => 'h4_params',
			'type'           => 'typography',
			'title'          => esc_html__( 'H4', 'ulms' ),
			'compiler'       => true,
			'google'         => false,
			'font-backup'    => false,
			'all_styles'     => true,
			'font-weight'    => true,
			'font-family'    => false,
			'text-align'     => false,
			'font-style'     => false,
			'subsets'        => false,
			'font-size'      => true,
			'line-height'    => true,
			'word-spacing'   => false,
			'letter-spacing' => false,
			'color'          => false,
			'preview'        => true,
			'output'         => array( 'h4,.h4' ),
			'units'          => 'px',
		),
		array(
			'id'             => 'h5_params',
			'type'           => 'typography',
			'title'          => esc_html__( 'H5', 'ulms' ),
			'compiler'       => true,
			'google'         => false,
			'font-backup'    => false,
			'all_styles'     => true,
			'font-weight'    => true,
			'font-family'    => false,
			'text-align'     => false,
			'font-style'     => false,
			'subsets'        => false,
			'font-size'      => true,
			'line-height'    => true,
			'word-spacing'   => false,
			'letter-spacing' => false,
			'color'          => false,
			'preview'        => true,
			'output'         => array( 'h5,.h5' ),
			'units'          => 'px'
		),
		array(
			'id'             => 'h6_params',
			'type'           => 'typography',
			'title'          => esc_html__( 'H6', 'ulms' ),
			'compiler'       => true,
			'google'         => false,
			'font-backup'    => false,
			'all_styles'     => true,
			'font-weight'    => true,
			'font-family'    => false,
			'text-align'     => false,
			'font-style'     => false,
			'subsets'        => false,
			'font-size'      => true,
			'line-height'    => true,
			'word-spacing'   => false,
			'letter-spacing' => false,
			'color'          => false,
			'preview'        => true,
			'output'         => array( 'h6,.h6' ),
			'units'          => 'px',
		),
	)
) );

Redux::setSection( $opt_name, array(
	'title'   => esc_html__( 'Archive Pages', 'ulms' ),
	'desc'    => '',
	'icon'    => 'fa fa-files-o',
	'submenu' => true,
	'fields'  => array(
		array(
			'id'       => 'blog_layout',
			'type'     => 'button_set',
			'title'    => esc_html__( 'Layout', 'ulms' ),
			'default'  => 'grid',
			'options'  => array(
				'grid' => esc_html__( 'Grid View', 'ulms' ),
				'list' => esc_html__( 'List View', 'ulms' ),
			),
			'description' => esc_html__( 'This setting allow to choose grid or list view for Archive Pages.', 'ulms' )
		),
		array(
			'id'       => 'chess_view',
			'type'     => 'switch',
			'title'    => esc_html__( 'Chess View', 'ulms' ),
			'default'  => false,
			'required' => array( 'blog_layout', '=', 'grid' ),
		)
	)
) );

Redux::setSection( $opt_name, array(
	'title'   => esc_html__( 'Account', 'ulms' ),
	'desc'    => '',
	'icon'    => 'dashicons-before dashicons-admin-users',
	'submenu' => true,
	'fields'  => array(
		array(
			'id'       => 'login_page_image',
			'url'      => false,
			'type'     => 'media',
			'title'    => esc_html__( 'Login Page Image', 'ulms' ),
			'description' => esc_html__( 'Choose image for login page.', 'ulms' )
		),
		array(
			'id'       => 'login_page_description',
			'type'     => 'text',
			'title'    => esc_html__( 'Login Page Description', 'ulms' ),
			'description' => esc_html__( 'Enter description for login page.', 'ulms' )
		),
	)
) );

Redux::setSection( $opt_name, array(
	'title'   => esc_html__( 'Courses', 'ulms' ),
	'desc'    => '',
	'icon'    => 'dashicons-before dashicons-welcome-learn-more',
	'submenu' => true,
	'fields'  => array(
		array(
			'id'       => 'course_start_page_id',
			'type'     => 'select',
			'title'    => esc_html__( '"Take This Course" page', 'ulms' ),
			'description' => esc_html__( 'Choose page with the "Course Start" template', 'ulms' ),
			'data'     => 'pages'
		),
		array(
			'id'       => 'courses_page',
			'type'     => 'select',
			'title'    => esc_html__( 'Courses Page', 'ulms' ),
			'description' => esc_html__( 'Choose page with the "Courses" template', 'ulms' ),
			'data'     => 'pages'
		),
		array(
			'id'       => 'courses_limit',
			'type'     => 'text',
			'title'    => esc_html__( 'Courses Limit', 'ulms' ),
			'description' => esc_html__( 'Blog page show at most', 'ulms' ),
			'default'  => '6'
		),
		array(
			'id'       => 'courses_category_base',
			'type'     => 'text',
			'title'    => esc_html__( 'Course Categories Base', 'ulms' ),
			'default'  => 'course-category'
		)
	)
) );

Redux::setSection( $opt_name, array(
	'title'   => esc_html__( 'Social Authentication', 'ulms' ),
	'desc'    => '',
	'icon'    => 'dashicons-before dashicons-share',
	'submenu' => true,
	'fields'  => array(
		array(
			'id'     => 'facebook_authentication_start_section',
			'type'   => 'section',
			'title'  => esc_html__( 'Facebook', 'ulms' ),
			'indent' => true
		),
		array(
			'id'      => 'enable_facebook_authentication',
			'type'    => 'switch',
			'title'   => esc_html__( 'Enable', 'ulms' ),
			'default' => false,
		),
		array(
			'id'       => 'facebook_client_id',
			'type'     => 'text',
			'title'    => esc_html__( 'Facebook Client ID', 'ulms' ),
			'required' => array( 'enable_facebook_authentication', '=', true, ),
			'default'  => ''
		),
		array(
			'id'       => 'facebook_secret_id',
			'type'     => 'text',
			'title'    => esc_html__( 'Facebook Secret ID', 'ulms' ),
			'required' => array( 'enable_facebook_authentication', '=', true, ),
			'default'  => ''
		),
		array(
			'id'     => 'facebook_authentication_end_section',
			'type'   => 'section',
			'indent' => false
		),
		array(
			'id'     => 'twitter_authentication_start_section',
			'type'   => 'section',
			'title'  => esc_html__( 'Twitter', 'ulms' ),
			'indent' => true
		),
		array(
			'id'      => 'enable_twitter_authentication',
			'type'    => 'switch',
			'title'   => esc_html__( 'Enable', 'ulms' ),
			'default' => false,
		),
		array(
			'id'       => 'twitter_consumer_key',
			'type'     => 'text',
			'title'    => esc_html__( 'Twitter Consumer Key', 'ulms' ),
			'required' => array( 'enable_twitter_authentication', '=', true, ),
			'default'  => ''
		),
		array(
			'id'       => 'twitter_consumer_secret',
			'type'     => 'text',
			'title'    => esc_html__( 'Twitter Consumer Secret', 'ulms' ),
			'required' => array( 'enable_twitter_authentication', '=', true, ),
			'default'  => ''
		),
		array(
			'id'     => 'twitter_authentication_end_section',
			'type'   => 'section',
			'indent' => false
		),
		array(
			'id'     => 'google_authentication_start_section',
			'type'   => 'section',
			'title'  => esc_html__( 'Google', 'ulms' ),
			'indent' => true
		),
		array(
			'id'      => 'enable_google_authentication',
			'type'    => 'switch',
			'title'   => esc_html__( 'Enable', 'ulms' ),
			'default' => false,
		),
		array(
			'id'       => 'google_client_id',
			'type'     => 'text',
			'title'    => esc_html__( 'Google Client ID', 'ulms' ),
			'required' => array( 'enable_google_authentication', '=', true, ),
			'default'  => ''
		),
		array(
			'id'       => 'google_secret_id',
			'type'     => 'text',
			'title'    => esc_html__( 'Google Secret ID', 'ulms' ),
			'required' => array( 'enable_google_authentication', '=', true, ),
			'default'  => ''
		),
		array(
			'id'     => 'google_authentication_end_section',
			'type'   => 'section',
			'indent' => false
		),
		array(
			'id'     => 'linkedin_authentication_start_section',
			'type'   => 'section',
			'title'  => esc_html__( 'LinkedIn', 'ulms' ),
			'indent' => true
		),
		array(
			'id'      => 'enable_linkedin_authentication',
			'type'    => 'switch',
			'title'   => esc_html__( 'Enable', 'ulms' ),
			'default' => false,
		),
		array(
			'id'       => 'linkedin_client_id',
			'type'     => 'text',
			'title'    => esc_html__( 'LinkedIn Client ID', 'ulms' ),
			'required' => array( 'enable_linkedin_authentication', '=', true, ),
			'default'  => ''
		),
		array(
			'id'       => 'linkedin_secret_id',
			'type'     => 'text',
			'title'    => esc_html__( 'LinkedIn Secret ID', 'ulms' ),
			'required' => array( 'enable_linkedin_authentication', '=', true, ),
			'default'  => ''
		),
		array(
			'id'     => 'linkedin_authentication_end_section',
			'type'   => 'section',
			'indent' => false
		),
	)
) );

Redux::setSection( $opt_name, array(
	'icon'       => 'el-refresh',
	'icon_class' => 'el-icon-large',
	'title'      => esc_html__( 'One Click Update', 'ulms' ),
	'desc'       => wp_kses_post( __( 'Let us notify you when new versions of this theme are live on ThemeForest! Update with just one button click and forget about manual updates!<br> If you have any troubles while using auto update ( It is likely to be a permissions issue ) then you may want to manually update the theme as normal.', 'ulms' ) ),
	'submenu'    => true,
	'fields'     => array(
		array(
			'id'       => 'envato_username',
			'type'     => 'text',
			'title'    => esc_html__( 'ThemeForest Username', 'ulms' ),
			'subtitle' => '',
			'desc'     => esc_html__( 'Enter here your ThemeForest (or Envato) username account (i.e. RunaThemes).', 'ulms' ),
		),
		array(
			'id'       => 'envato_api',
			'type'     => 'text',
			'title'    => esc_html__( 'ThemeForest Secret API Key', 'ulms' ),
			'subtitle' => '',
			'desc'     => esc_html__( 'Enter here the secret api key you have created on ThemeForest. You can create a new one in the Settings > API Keys section of your profile.', 'ulms' ),
		),
	)
) );

/*
 * <--- END SECTIONS
 */
