<?php

if ( ! function_exists( 'ulms_ajax_login' ) ) {
	function ulms_ajax_login() {

		check_ajax_referer( 'runa-login-nonce', 'security' );

		$info = array();
		$json = array();

		$json['loggedin'] = false;
		$json['message']  = esc_html__( 'Email or password you entered is incorrect. Please try again.', 'ulms' );

		if ( filter_var( $_POST['email'], FILTER_VALIDATE_EMAIL ) ) {
			$user = get_user_by( 'email', $_POST['email'] );
		} else {
			$user = get_user_by( 'login', $_POST['email'] );
		}

		if ( ! $user ) {
			wp_die( json_encode( $json ) );
		}

		$info['user_login']    = $user->data->user_login;
		$info['user_password'] = $_POST['password'];
		if ( ! empty( $_POST['remember'] ) ) {
			$info['remember'] = true;
		} else {
			$info['remember'] = false;
		}

		if ( ! is_wp_error( wp_signon( $info, false ) ) ) {
			$json['loggedin'] = true;
			$json['message']  = esc_html__( 'Redirecting...', 'ulms' );
			$json['redirect'] = esc_url( get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) );
		}

		wp_die( json_encode( $json ) );
	}
}

add_action( 'wp_ajax_nopriv_runa_ajax_login', 'ulms_ajax_login' );


if ( ! function_exists( 'ulms_ajax_register' ) ) {
	function ulms_ajax_register() {

		check_ajax_referer( 'runa-register-nonce', 'security' );

		$json = array();
		$json['registered'] = false;

		if ( ! is_email( $_POST['email'] ) ) {
			$json['message'] = esc_html__( 'Enter a valid email', 'ulms' );
			wp_die( json_encode( $json ) );
		} else {
			if ( $_POST['password'] != $_POST['confirm'] ) {
				$json['message'] = esc_html__( 'The passwords do not match. Please retry.', 'ulms' );
			} elseif ( strlen( $_POST['password'] ) < 4 ) {
				$json['message'] = esc_html__( 'Password too short', 'ulms' );
			} else {
				$user = get_user_by( 'email', $_POST['email'] );
				if ( $user ) {
					if ( get_user_meta( $user->ID, 'account_status', true ) ) {
						$activation_key = get_user_meta( $user->ID, 'activation_code', true );
						$activation_link = esc_url( home_url( '/' ) ) . '?action=activation_user&user_id=' . $user->ID . '&key=' . $activation_key;
						$message = sprintf( wp_kses( __( 'Confirm your email address to complete the registration account. It\'s easy: just click on the <a href="%s">link</a>.', 'ulms' ), array( 'a' => array( 'href' => array() ) ) ), $activation_link );
						$message = apply_filters( 'runa_register_user_message', $message, $_POST['email'], $activation_key, $activation_link );
						$subject = apply_filters( 'runa_register_user_message_subject', sprintf( esc_html__( '[%s] User Activation', 'ulms' ), get_option( 'blogname' ) ), $_POST['email'], $activation_key, $activation_link );
						add_filter( 'wp_mail_content_type', create_function( '', 'return "text/html";' ) );
						wp_mail( $_POST['email'], $subject, $message );

						$json['registered'] = true;
						$json['message']    = esc_html__( 'Please check your email to complete registration', 'ulms' );
					} else {
						$json['message'] = esc_html__( 'Email already exists', 'ulms' );
					}
				}else{
					$email_to_fl_names =  explode( '@', $_POST['email'] );
					$user_name = uniqid( rand( 1, 99 ) );
					$user_create_data = array(
						'user_login'           => $user_name,
						'user_pass'            => $_POST['password'],
						'user_email'           => $_POST['email'],
						'display_name'         => $email_to_fl_names[0],
						'show_admin_bar_front' => 'false'
					);

					$user_id = wp_insert_user( $user_create_data );
					if ( ! is_wp_error( $user_id ) ) {
						$user = new WP_User( $user_id );
						$user->set_role( ULMS_STUDENT_ROLE );
						$activation_key = sha1( $user_id . time() );
						update_user_meta( $user_id, 'account_status', 'locked' );
						update_user_meta( $user_id, 'auth_via', 'native' );
						update_user_meta( $user_id, 'activation_code', $activation_key );

						$activation_link = esc_url( home_url( '/' ) ) . '?action=activation_user&user_id=' . $user_id . '&key=' . $activation_key;
						$message = sprintf( wp_kses( __( 'Confirm your email address to complete the registration account. It\'s easy: just click on the <a href="%s">link</a>.', 'ulms' ), array( 'a' => array( 'href' => array() ) ) ), $activation_link );
						$message = apply_filters( 'runa_register_user_message', $message, $_POST['email'], $activation_key, $activation_link );
						$subject = apply_filters( 'runa_register_user_message_subject', sprintf( esc_html__( '[%s] User Activation', 'ulms' ), get_option( 'blogname' ) ), $_POST['email'], $activation_key, $activation_link );
						add_filter( 'wp_mail_content_type', create_function( '', 'return "text/html";' ) );
						wp_mail( $_POST['email'], $subject, $message );

						$json['registered'] = true;
						$json['message']    = esc_html__( 'Please check your email to complete registration', 'ulms' );
					}
				}
			}
		}


		wp_die( json_encode( $json ) );
	}
}

add_action( 'wp_ajax_nopriv_runa_ajax_register', 'ulms_ajax_register' );


if ( ! function_exists( 'ulms_account_settings' ) ) {
	function ulms_account_settings() {
		if ( ! empty( $_POST['edit_account_settings'] ) && wp_verify_nonce( $_POST['edit_account_settings'], 'runa-account-settings-nonce' ) && ! empty( $_POST['account_info'] ) ) {
			$_POST['errors'] = array();
			$user_info       = wp_get_current_user();

			if ( ! $user_info ) {
				return;
			}

			if ( empty( $_POST['account_info']['email'] ) ) {
				$_POST['errors']['email'] = esc_html__( 'Email is required', 'ulms' );
			} elseif ( ! is_email( $_POST['account_info']['email'] ) ) {
				$_POST['errors']['email'] = esc_html__( 'Enter a valid email', 'ulms' );
			} elseif ( ( $user_info->user_email != $_POST['account_info']['email'] ) && get_user_by( 'email', $_POST['account_info']['email'] ) ) {
				$_POST['errors']['email'] = esc_html__( 'Email already exists', 'ulms' );
			}

			if ( empty( $_POST['account_info']['first_name'] ) ) {
				$_POST['errors']['first_name'] = esc_html__( 'First name is required', 'ulms' );
			}

			if ( empty( $_POST['account_info']['last_name'] ) ) {
				$_POST['errors']['last_name'] = esc_html__( 'Last name is required', 'ulms' );
			}

			if ( ! empty( $_POST['account_info']['password'] ) ) {
				if ( empty( $_POST['account_info']['confirm'] ) ) {
					$_POST['errors']['confirm'] = esc_html__( 'Confirm is required', 'ulms' );
				} elseif ( $_POST['account_info']['password'] != $_POST['account_info']['confirm'] ) {
					$_POST['errors']['password'] = esc_html__( 'Passwords do not match', 'ulms' );
				}
			}

			if ( ! empty( $_POST['account_info']['confirm'] ) && empty( $_POST['account_info']['password'] ) ) {
				$_POST['errors']['password'] = esc_html__( 'Password is required', 'ulms' );
			}

			if ( empty( $_POST['errors'] ) ) {
				$user_id = wp_update_user( array(
					'ID'           => $user_info->ID,
					'first_name'   => $_POST['account_info']['first_name'],
					'last_name'    => $_POST['account_info']['last_name'],
					'user_email'   => $_POST['account_info']['email'],
					'display_name' => $_POST['account_info']['last_name'] . ' ' . $_POST['account_info']['first_name']
				) );

				if ( ! is_wp_error( $user_id ) ) {
					if( isset( $_POST['account_info']['phone'] ) ){
						update_user_meta( $user_id, 'phone', $_POST['account_info']['phone'] );
					}

				}else{
					return;
				}
			}

		}

		if ( ! empty( $_POST['edit_account_additional_settings'] ) && wp_verify_nonce( $_POST['edit_account_additional_settings'], 'runa-account-additional-settings-nonce' ) && ! empty( $_POST['account_additional_info'] ) ) {
			$_POST['errors'] = array();
			$user_info       = wp_get_current_user();

			if ( ! $user_info ) {
				return;
			}

			if( isset( $_POST['account_additional_info']['facebook'] ) ){
				update_user_meta( $user_info->ID, 'facebook', $_POST['account_additional_info']['facebook'] );
			}

			if( isset( $_POST['account_additional_info']['twitter'] ) ){
				update_user_meta( $user_info->ID, 'twitter', $_POST['account_additional_info']['twitter'] );
			}

			if( isset( $_POST['account_additional_info']['google_plus'] ) ){
				update_user_meta( $user_info->ID, 'google_plus', $_POST['account_additional_info']['google_plus'] );
			}

			if( isset( $_POST['account_additional_info']['linkedin'] ) ){
				update_user_meta( $user_info->ID, 'linkedin', $_POST['account_additional_info']['linkedin'] );
			}

			$user_data = array();

			if( isset( $_POST['account_additional_info']['website'] ) ){
				$user_data['user_url'] = $_POST['account_additional_info']['website'];
			}

			if( isset( $_POST['account_additional_info']['description'] ) ){
				$user_data['description'] = $_POST['account_additional_info']['description'];
			}

			if( $user_data ){
				$user_data['ID'] = $user_info->ID;
				wp_update_user( $user_data );
			}

		}

		if ( ! empty( $_POST['account_edit_image_security'] ) && wp_verify_nonce( $_POST['account_edit_image_security'], 'runa-account-edit-image-nonce' ) && ! empty( $_FILES ) ) {
			$user_info = wp_get_current_user();
			if ( ! $user_info ) {
				return;
			}
			require_once( ABSPATH . 'wp-admin/includes/file.php' );
			require_once( ABSPATH . 'wp-admin/includes/image.php' );

			$file_return = wp_handle_upload( $_FILES['image'], array(
				'test_form'   => false,
				'test_size'   => false,
				'test_upload' => true,
			) );

			if ( $file_return && ! isset( $file_return['error'] ) ) {
				$filename        = $file_return['file'];
				$attachment      = array(
					'post_mime_type' => $file_return['type'],
					'post_title'     => preg_replace( '/\.[^.]+$/', '', basename( $filename ) ),
					'post_content'   => '',
					'post_status'    => 'inherit',
					'guid'           => $file_return['url']
				);
				$attach_id       = wp_insert_attachment( $attachment, $file_return['url'] );
				$attachment_data = wp_generate_attachment_metadata( $attach_id, $filename );
				wp_update_attachment_metadata( $attach_id, $attachment_data );
				if ( $attach_id ) {
					global $wpdb;
					if ( $old_image = get_user_meta( $user_info->ID, $wpdb->get_blog_prefix( get_current_blog_id() ) . 'user_avatar', true ) ) {
						wp_delete_attachment( $old_image, true );
					}
					update_user_meta( $user_info->ID, $wpdb->get_blog_prefix( get_current_blog_id() ) . 'user_avatar', $attach_id );
				}
			}
		}

		if ( ! empty( $_POST['account_remove_image_security'] ) && wp_verify_nonce( $_POST['account_remove_image_security'], 'runa-account-remove-image-nonce' ) ) {
			$user_info = wp_get_current_user();
			if ( ! $user_info ) {
				return;
			}
			global $wpdb;
			if ( $old_image = get_user_meta( $user_info->ID, $wpdb->get_blog_prefix( get_current_blog_id() ) . 'user_avatar', true ) ) {
				wp_delete_attachment( $old_image, true );
			}
			delete_user_meta( $user_info->ID, $wpdb->get_blog_prefix( get_current_blog_id() ) . 'user_avatar' );
		}

	}
}

add_action( 'init', 'ulms_account_settings' );


if ( ! function_exists( 'ulms_user_authentication' ) ) {
	function ulms_user_authentication( $user ) {
		$status = get_class( $user );
		if ( $status == 'WP_User' ) {
			if ( get_user_meta( $user->data->ID, 'account_status', true ) ) {
				return new WP_Error( 'authentication_failed', wp_kses( __( '<strong>Error:</strong> Your account has been locked.', 'ulms' ), array( 'strong' => array() ) ) );
			} else {
				return $user;
			}
		}

		return $user;
	}
}

add_filter( 'authenticate', 'ulms_user_authentication', 9999 );


if( ! function_exists( 'ulms_activation_user' ) ){
	function ulms_activation_user(){
		if( ! empty( $_GET['action'] ) && $_GET['action'] == 'activation_user' && ! empty( $_GET['user_id'] ) && ! empty( $_GET['key'] ) ){
			$user_id = intval( $_GET['user_id'] );
			if( ! get_user_meta( $user_id, 'account_status', true ) ){
				wp_redirect( esc_url( home_url( '/' ) ) );
				exit;
			}else{
				if( get_user_meta( $user_id, 'activation_code', true ) == $_GET['key'] ){
					delete_user_meta( $user_id, 'account_status' );
					delete_user_meta( $user_id, 'activation_code' );
					wp_set_auth_cookie( $user_id, false, false );
					wp_set_current_user( $user_id );
					wp_redirect( esc_url( get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) ) );
					exit;
				}
			}
		}
	}
}

add_action( 'init', 'ulms_activation_user' );