<?php

if ( ! function_exists( 'ulms_option' ) ) {
	function ulms_option( $id, $fallback = false, $key = false ) {
		global $ulms_option;
		if ( $fallback == false ) {
			$fallback = '';
		}
		$output = ( isset( $ulms_option[ $id ] ) && $ulms_option[ $id ] !== '' ) ? $ulms_option[ $id ] : $fallback;
		if ( ! empty( $ulms_option[ $id ] ) && $key ) {
			$output = $ulms_option[ $id ][ $key ];
		}

		return $output;
	}
}


if ( ! function_exists( 'ulms_fonts_url' ) ) {
	function ulms_fonts_url() {

		$font_families    = array();
		$open_sans_family = _x( 'on', 'Open Sans font: on or off', 'ulms' );
		$lato_family      = _x( 'on', 'Lato font: on or off', 'ulms' );
		$font_body        = ulms_option( 'font_body' );
		$font_heading     = ulms_option( 'font_heading' );
		if ( 'off' !== $open_sans_family && empty( $font_body['font-family'] ) ) {
			$font_families[] = 'Open Sans:400,300,300italic,400italic,600,600italic,700,700italic,800,800italic&subset=latin,greek,greek-ext,vietnamese,cyrillic-ext,latin-ext,cyrillic';
		}
		if ( 'off' !== $lato_family && empty( $font_heading['font-family'] ) ) {
			$font_families[] = 'Lato:400,100,100italic,300,300italic,400italic,700,700italic,900,900italic&subset=latin,latin-ext';
		}

		if ( $font_families ) {
			$query_args = array(
				'family' => urlencode( implode( '|', $font_families ) )
			);

			$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
		} else {
			$fonts_url = '';
		}

		return esc_url_raw( $fonts_url );
	}
}


if ( ! function_exists( 'ulms_page_title' ) ) {
	function ulms_page_title( $display = true ) {
		global $wp_locale;

		$m        = get_query_var( 'm' );
		$year     = get_query_var( 'year' );
		$monthnum = get_query_var( 'monthnum' );
		$day      = get_query_var( 'day' );
		$title    = '';


		// If there is a post
		if ( is_single() || ( is_home() && ! is_front_page() ) || ( is_page() && ! is_front_page() ) || is_front_page() ) {
			$title = single_post_title( '', false );
		}

		if ( is_home() ) {
			if ( ! get_option( 'page_for_posts' ) ) {
				$title = esc_html__( 'Blog', 'ulms' );
			} else {
				$title = get_the_title( get_option( 'page_for_posts' ) );
			}
		}

		// If there's a post type archive
		if ( is_post_type_archive() ) {
			$post_type = get_query_var( 'post_type' );
			if ( is_array( $post_type ) ) {
				$post_type = reset( $post_type );
			}
			$post_type_object = get_post_type_object( $post_type );
			if ( ! $post_type_object->has_archive ) {
				$title = post_type_archive_title( '', false );
			}
		}

		// If there's a category or tag
		if ( is_category() || is_tag() ) {
			$title = single_term_title( '', false );
		}

		// If there's a taxonomy
		if ( is_tax() ) {
			$term = get_queried_object();
			if ( $term ) {
				$tax   = get_taxonomy( $term->taxonomy );
				$title = single_term_title( '', false );
			}
		}

		// If there's an author
		if ( is_author() && ! is_post_type_archive() ) {
			$author = get_queried_object();
			if ( $author ) {
				$title = esc_html__( 'Profile', 'ulms' );
			}
		}

		// Post type archives with has_archive should override terms.
		if ( is_post_type_archive() && $post_type_object->has_archive ) {
			if ( function_exists( 'is_shop' ) && is_shop() ) {
				$title = get_the_title( get_option( 'woocommerce_shop_page_id' ) );
			} else {
				$title = post_type_archive_title( '', false );
			}
		}

		// If there's a month
		if ( is_archive() && ! empty( $m ) ) {
			$my_year  = substr( $m, 0, 4 );
			$my_month = $wp_locale->get_month( substr( $m, 4, 2 ) );
			$my_day   = intval( substr( $m, 6, 2 ) );
			$title    = $my_year . ( $my_month ? $my_month : '' ) . ( $my_day ? $my_day : '' );
		}

		// If there's a year
		if ( is_archive() && ! empty( $year ) ) {
			$title = $year;
			if ( ! empty( $monthnum ) ) {
				$title .= ' ' . $wp_locale->get_month( $monthnum );
			}
			if ( ! empty( $day ) ) {
				$title .= ' ' . zeroise( $day, 2 );
			}
		}

		// If it's a search
		if ( is_search() ) {
			$title = esc_html__( 'Search', 'ulms' );
		}

		// If it's a 404 page
		if ( is_404() ) {
			$title = esc_html__( 'Page not found', 'ulms' );
		}

		if ( $display ) {
			echo esc_html( $title );
		} else {
			return esc_html( $title );
		}
	}
}


if ( ! function_exists( 'ulms_blog_layout' ) ) {
	function ulms_blog_layout() {
		$blog_layout = ulms_option( 'blog_layout', 'grid' );
		if ( ! empty( $_GET['layout'] ) && ( $_GET['layout'] == 'grid' || $_GET['layout'] == 'list' ) ) {
			$blog_layout = $_GET['layout'];
		}

		return $blog_layout;
	}
}


if ( ! function_exists( 'ulms_sidebar_position' ) ) {
	function ulms_sidebar_position() {
		$post_id        = get_the_ID();
		$page_for_posts = get_option( 'page_for_posts' );
		if ( is_home() || is_category() || is_search() || is_tag() || is_tax() ) {
			$post_id = $page_for_posts;
		}
		if ( is_tax( ULMS_COURSE_CATEGORY_SLUG ) ) {
			$post_id = ulms_option( 'courses_page' );
		}
		$sidebar_position = get_post_meta( $post_id, 'sidebar_position', true );
		if ( ! empty( $_GET['sidebar_position'] ) && ( $_GET['sidebar_position'] == 'left' || $_GET['sidebar_position'] == 'right' ) ) {
			$sidebar_position = $_GET['sidebar_position'];
		}
		if ( $sidebar_position == '' ) {
			return 'right';
		} else {
			return $sidebar_position;
		}
	}
}


if ( ! function_exists( 'ulms_page_sidebar_name' ) ) {
	function ulms_page_sidebar_name() {
		$post_id        = get_the_ID();
		$page_for_posts = get_option( 'page_for_posts' );
		if ( is_home() || is_category() || is_search() || is_tag() || is_tax() ) {
			$post_id = $page_for_posts;
		}
		if ( is_tax( ULMS_COURSE_CATEGORY_SLUG ) ) {
			$post_id = ulms_option( 'courses_page' );
		}
		$sidebar_name = get_post_meta( $post_id, 'sidebar', true );

		if ( ! empty( $_GET['sidebar'] ) && ( $_GET['sidebar'] == 'disable' || $_GET['sidebar'] == 'ulms-right-sidebar' || $_GET['sidebar'] == 'ulms-left-sidebar' ) ) {
			$sidebar_name = $_GET['sidebar'];
		}

		if ( $sidebar_name == '' ) {
			return 'ulms-right-sidebar';
		} else {
			return $sidebar_name;
		}
	}
}


if ( ! function_exists( 'ulms_comment_list' ) ) {
	function ulms_comment_list( $comment, $args, $depth ) {
		if ( 'div' == $args['style'] ) {
			$tag       = 'div';
			$add_below = 'comment';
		} else {
			$tag       = 'li';
			$add_below = 'div-comment';
		}
		$rating = get_comment_meta( get_comment_ID(), 'rating', true );
		?>
		<<?php echo esc_attr( $tag ) ?> <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ); ?> id="comment-<?php comment_ID(); ?>">
		<?php if ( 'div' != $args['style'] ): ?>
			<div id="div-comment-<?php comment_ID(); ?>" class="comment-body clearfix">
		<?php endif; ?>
		<?php if ( $args['avatar_size'] != 0 ): ?>
			<div class="vcard">
				<?php echo get_avatar( $comment, $args['avatar_size'] ); ?>
			</div>
		<?php endif; ?>
		<div class="comment-info clearfix">
			<div class="comment-author"><?php echo get_comment_author_link(); ?></div>
			<?php if( $rating ): ?>
				<div class="br-wrapper br-theme-fontawesome-stars">
					<select class="star_rating_disabled">
						<?php for( $i=1; $i <= 5; $i++ ): ?>
							<option<?php echo ( $rating == $i ) ? ' selected="selected"' : ''; ?> value="<?php echo esc_attr( $i ); ?>"><?php echo esc_html( $i ); ?></option>
						<?php endfor; ?>
					</select>
				</div>
			<?php endif; ?>
			<div class="comment-meta">
				<i class="fa fa-calendar-o" aria-hidden="true"></i>
				<span><?php printf( esc_html__( '%1$s at %2$s', 'ulms' ), get_comment_date(), get_comment_time() ); ?></span>
			</div>
			<div class="comment-text">
				<?php comment_text(); ?>
			</div>
			<div class="comment-buttons">
				<?php comment_reply_link( array_merge( $args, array(
					'reply_text' => wp_kses( __( '<i class="fa fa-reply"></i> Reply', 'ulms' ), array( 'i' => array() ) ),
					'add_below'  => $add_below,
					'depth'      => $depth,
					'max_depth'  => $args['max_depth']
				) ) ); ?>
				<?php edit_comment_link( esc_html__( 'Edit', 'ulms' ), '  ', '' ); ?>
				<?php if ( $comment->comment_approved == '0' ): ?>
					<em class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'ulms' ); ?></em>
				<?php endif; ?>
			</div>
		</div>

		<?php if ( 'div' != $args['style'] ): ?>
			</div>
		<?php endif; ?>
		<?php
	}
}


if ( ! function_exists( 'ulms_comment_form_fields' ) ) {
	function ulms_comment_form_fields( $fields ) {
		$commenter = wp_get_current_commenter();
		$req       = get_option( 'require_name_email' );
		$aria_req  = ( $req ? " aria-required='true'" : '' );
		$html5     = current_theme_supports( 'html5', 'comment-form' ) ? 1 : 0;
		$url_fields = '';
		if( ! is_user_logged_in() ){
			$url_fields .= '<div class="input-group form-submit-button"><button type="submit" class="button size-sm">' . esc_html__( 'Submit Comment', 'ulms' ) . '</button></div>';
		}
		$fields['author'] = '<div class="row">
							<div class="col-xs-12 col-sm-6 col-md-6 col-lg-6">
								<div class="input-group comment-form-author">
									<label for="comment_name">' . esc_html__( 'Name', 'ulms' ) . ( $req ? '<span class="req">*</span>' : '' ) . '</label>
		            				<input id="comment_name" class="form-control" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30"' . $aria_req . ' />
	                            </div>
	                        </div>';
		$fields['email']  = '<div class="col-xs-12 col-sm-6 col-md-6 col-lg-6">
								<div class="input-group comment-form-email">
									<label for="comment_email">' . esc_html__( 'Email', 'ulms' ) . ( $req ? '<span class="req">*</span>' : '' ) . '</label>
									<input id="comment_email" class="form-control" name="email" ' . ( $html5 ? 'type="email"' : 'type="text"' ) . ' value="' . esc_attr( $commenter['comment_author_email'] ) . '" size="30"' . $aria_req . ' />
								</div>
							</div>';
		$fields['url']    = '</div>' . $url_fields;

		return $fields;
	}
}

add_filter( 'comment_form_default_fields', 'ulms_comment_form_fields' );


if ( ! function_exists( 'ulms_comment_form' ) ) {
	function ulms_comment_form( $args ) {

		$args['comment_field'] = '<div class="input-group comment-form-rating">
									<label>' . esc_html__( 'Your Rating', 'ulms' ) . '</label>
									<div class="br-wrapper br-theme-fontawesome-stars">
										<select name="rating" class="star_rating_enabled">
											<option value="">&nbsp;</option>
											<option value="1">1</option>
											<option value="2">2</option>
											<option value="3">3</option>
											<option value="4">4</option>
											<option value="5">5</option>
										</select>
									</div>
								</div>';

		$args['comment_field'] .= '<div class="input-group comment-form-comment">
									<label for="comment_message">' . esc_html( _x( 'Comment', 'noun', 'ulms' ) ) . '<span class="req">*</span></label>
						            <textarea id="comment_message" class="form-control" name="comment" rows="9" aria-required="true"></textarea>
						        </div>';

		if( is_user_logged_in() ){
			$args['comment_field'] .= '<div class="input-group form-submit-button"><button type="submit" class="button size-sm">' . esc_html__( 'Submit Comment', 'ulms' ) . '</button></div>';
		}

		return $args;
	}
}

add_filter( 'comment_form_defaults', 'ulms_comment_form' );


if ( ! function_exists( 'ulms_save_comment_meta_data' ) ) {
	function ulms_save_comment_meta_data( $comment_id ) {
		if ( ( isset( $_POST['rating'] ) ) && ( $_POST['rating'] != '' ) ) {
			$rating = wp_filter_nohtml_kses( $_POST['rating'] );
			add_comment_meta( $comment_id, 'rating', $rating );
		}
	}
}

add_action( 'comment_post', 'ulms_save_comment_meta_data' );


if ( ! function_exists( 'ulms_get_icons_array' ) ) {
	function ulms_get_icons_array() {
		global $wp_filesystem;
		if ( empty( $wp_filesystem ) ) {
			require_once ABSPATH . '/wp-admin/includes/file.php';
			WP_Filesystem();
		}
		$fonts = array();

		$icons = json_decode( $wp_filesystem->get_contents( get_template_directory() . '/assets/js/selection.json' ), true );
		foreach ( $icons['icons'] as $icon ) {
			$fonts[ esc_js( 'ULMS Icons', 'ulms' ) ][] = 'ulms-icon-' . $icon['properties']['name'];
		}

		if ( function_exists( 'vc_iconpicker_type_fontawesome' ) ) {
			foreach ( vc_iconpicker_type_fontawesome( array() ) as $fa_cat => $fa_icons ) {
				foreach ( $fa_icons as $fa_val_1 ) {
					foreach ( $fa_val_1 as $fa_icon => $fa_val_2 ) {
						$fonts[ $fa_cat ][] = $fa_icon;
					}
				}
			}
		}

		return $fonts;
	}
}


if ( ! function_exists( 'ulms_get_rating_count' ) ) {
	function ulms_get_rating_count( $value = null, $post_id = false ) {
		global $wpdb;

		if( $post_id === false ){
			$post_id = get_the_ID();
		}

		$counts     = array();
		$raw_counts = $wpdb->get_results( $wpdb->prepare( "
				SELECT meta_value, COUNT( * ) as meta_value_count FROM $wpdb->commentmeta
				LEFT JOIN $wpdb->comments ON $wpdb->commentmeta.comment_id = $wpdb->comments.comment_ID
				WHERE meta_key = 'rating'
				AND comment_post_ID = %d
				AND comment_approved = '1'
				AND meta_value > 0
				GROUP BY meta_value
			", $post_id ) );

		foreach ( $raw_counts as $count ) {
			$counts[ $count->meta_value ] = $count->meta_value_count;
		}

		if ( is_null( $value ) ) {
			return array_sum( $counts );
		} else {
			return isset( $counts[ $value ] ) ? $counts[ $value ] : 0;
		}
	}
}


if ( ! function_exists( 'ulms_get_average_rating' ) ) {
	function ulms_get_average_rating( $post_id = false ) {
		global $wpdb;

		if( $post_id === false ){
			$post_id = get_the_ID();
		}

		if ( $count = ulms_get_rating_count( null, $post_id ) ) {
			$ratings = $wpdb->get_var( $wpdb->prepare( "
					SELECT SUM(meta_value) FROM $wpdb->commentmeta
					LEFT JOIN $wpdb->comments ON $wpdb->commentmeta.comment_id = $wpdb->comments.comment_ID
					WHERE meta_key = 'rating'
					AND comment_post_ID = %d
					AND comment_approved = '1'
					AND meta_value > 0
				", $post_id ) );
			$average = number_format( $ratings / $count, 2, '.', '' );
		} else {
			$average = 0;
		}

		return (string) floatval( $average );
	}
}


if ( ! function_exists( 'ulms_friendly_duration' ) ) {
	function ulms_friendly_duration( $seconds ) {
		if ( $seconds < 86400 ) {
			return gmdate( "H:i:s", $seconds );
		}
		$measures = array(
			array(
				'label' => esc_html__( 'year', 'ulms' ),
				'multi' => esc_html__( 'years', 'ulms' ),
				'value' => 365 * 30 * 24 * 60 * 60
			),
			array(
				'label' => esc_html__( 'month', 'ulms' ),
				'multi' => esc_html__( 'months', 'ulms' ),
				'value' => 30 * 24 * 60 * 60
			),
			array(
				'label' => esc_html__( 'week', 'ulms' ),
				'multi' => esc_html__( 'weeks', 'ulms' ),
				'value' => 7 * 24 * 60 * 60
			),
			array(
				'label' => esc_html__( 'day', 'ulms' ),
				'multi' => esc_html__( 'days', 'ulms' ),
				'value' => 24 * 60 * 60
			),
			array(
				'label' => esc_html__( 'hour', 'ulms' ),
				'multi' => esc_html__( 'hours', 'ulms' ),
				'value' => 60 * 60
			),
			array(
				'label' => esc_html__( 'minute', 'ulms' ),
				'multi' => esc_html__( 'minutes', 'ulms' ),
				'value' => 60
			),
			array(
				'label' => esc_html__( 'second', 'ulms' ),
				'multi' => esc_html__( 'seconds', 'ulms' ),
				'value' => 1
			),
		);

		foreach ( $measures as $key => $measure ) {
			if ( $measure['value'] > $seconds ) {
				//Continue
			} else {
				$count = floor( $seconds / $measure['value'] );
				break;
			}
		}

		if ( empty( $force ) ) {
			$time_labels = $count . ' ' . ( ( $count > 1 ) ? $measure['multi'] : $measure['label'] );
		} else {
			$time_labels = ( ( $count > 1 ) ? $count : '' ) . ' ' . ( ( $count > 1 ) ? $measure['multi'] : $measure['label'] );
		}

		if ( $measure['value'] > 1 ) {
			$small_measure = $measures[ $key + 1 ];
			$small_count   = floor( ( $seconds % $measure['value'] ) / $small_measure['value'] );
			if ( $small_count ) {
				$time_labels .= ', ' . $small_count . ' ' . ( ( $small_count > 1 ) ? $small_measure['multi'] : $small_measure['label'] );
			}
		}

		return $time_labels;
	}
}


if ( ! function_exists( 'ulms_vacancy_send_action' ) ) {
	function ulms_vacancy_send_action() {
		$json = array();
		if ( wp_verify_nonce( $_POST['security'], 'runa-vacancy-secure' ) && is_email( $_POST['email'] ) && isset( $_POST['name'] ) && isset( $_POST['vacancy_id'] ) && get_post( $_POST['vacancy_id'] ) && ! empty( $_FILES['file'] ) ) {
			add_filter( 'wp_mail_content_type', create_function( '', 'return "text/html";' ) );
			$attachment = $_FILES['file']['tmp_name'];
			$headers[]  = 'From: ' . get_option( 'blogname' ) . ' <' . get_option( 'admin_email' ) . '>';

			$text = esc_html__( 'Vacancy', 'ulms' ) . ':' . get_the_title( $_POST['vacancy_id'] ) . '<br/>';
			$text .= esc_html__( 'Name', 'ulms' ) . ': ' . esc_html( $_POST['name'] ) . '<br/>';
			$text .= esc_html__( 'Email', 'ulms' ) . ': ' . esc_html( $_POST['email'] ) . '<br/>';
			$mail = wp_mail( get_option( 'admin_email' ), esc_html__( 'New resume', 'ulms' ), $text, $headers, $attachment );
			if ( $mail ) {
				$json['success'] = '<p class="success">' . esc_html__( 'Your resume has been sent successfully', 'ulms' ) . '</p>';
			} else {
				$json['error'] = true;
			}
			echo json_encode( $json );
		}
		exit;
	}
}

add_action( 'wp_ajax_send_vacancy', 'ulms_vacancy_send_action' );
add_action( 'wp_ajax_nopriv_send_vacancy', 'ulms_vacancy_send_action' );


if ( ! function_exists( 'ulms_get_archives_link' ) ) {
	function ulms_get_archives_link( $link_html, $url, $text, $format, $before, $after ) {
		if ( $format == 'html' ) {
			return "\t<li>$before<a href='$url'>$text $after</a></li>\n";
		} else {
			return $link_html;
		}
	}
}

add_filter( 'get_archives_link', 'ulms_get_archives_link', 10, 6 );


if ( ! function_exists( 'ulms_updater' ) ) {
	function ulms_updater() {
		global $ulms_option;
		if ( isset( $ulms_option['envato_username'] ) && isset( $ulms_option['envato_api'] ) ) {
			$envato_username = trim( $ulms_option['envato_username'] );
			$envato_api_key  = trim( $ulms_option['envato_api'] );
			if ( ! empty( $envato_username ) && ! empty( $envato_api_key ) ) {
				require_once( ULMS_INC_PATH . '/theme-updater/envato-wp-theme-updater.php' );

				if ( class_exists( 'Envato_Theme_Updater' ) ) {
					Envato_WP_Theme_Updater::init( $envato_username, $envato_api_key, 'RunaThemes' );
				}
			}
		}
	}
}

add_action( 'admin_init', 'ulms_updater' );


if ( ! function_exists( 'ulms_hex2rgba' ) ) {
	function ulms_hex2rgba( $color, $opacity = false ) {

		$default = 'rgb(0,0,0)';

		if ( empty( $color ) ) {
			return $default;
		}

		if ( $color[0] == '#' ) {
			$color = substr( $color, 1 );
		}

		if ( strlen( $color ) == 6 ) {
			$hex = array( $color[0] . $color[1], $color[2] . $color[3], $color[4] . $color[5] );
		} elseif ( strlen( $color ) == 3 ) {
			$hex = array( $color[0] . $color[0], $color[1] . $color[1], $color[2] . $color[2] );
		} else {
			return $default;
		}

		$rgb = array_map( 'hexdec', $hex );

		if ( $opacity ) {
			if ( abs( $opacity ) > 1 ) {
				$opacity = 1.0;
			}
			$output = 'rgba(' . implode( ",", $rgb ) . ',' . $opacity . ')';
		} else {
			$output = 'rgb(' . implode( ",", $rgb ) . ')';
		}

		return $output;
	}
}


if ( ! function_exists( 'ulms_get_file_icon' ) ) {
	function ulms_get_file_icon( $file ) {
		$icon      = 'fa fa-file';
		$file_type = wp_check_filetype( $file );
		$ext       = $file_type['ext'];
		if ( $ext == 'docx' || $ext == 'doc' ) {
			$icon = 'fa fa-file-word-o';
		} elseif ( $ext == 'pdf' ) {
			$icon = 'fa fa-file-pdf-o';
		} elseif ( $ext == 'ppt' || $ext == 'pptx' || $ext == 'pps' || $ext == 'ppsx' ) {
			$icon = 'fa fa-file-powerpoint-o';
		} elseif ( $ext == 'xls' || $ext == 'xlsx' ) {
			$icon = 'fa fa-file-excel-o';
		} elseif ( $ext == 'jpg' || $ext == 'jpeg' || $ext == 'png' || $ext == 'gif' || $ext == 'ico' || $ext == 'psd' ) {
			$icon = 'fa fa-file-image-o';
		} elseif ( $ext == 'mp3' || $ext == 'm4a' || $ext == 'ogg' || $ext == 'wav' ) {
			$icon = 'fa fa-file-audio-o';
		} elseif ( $ext == 'mp4' || $ext == 'm4v' || $ext == 'mov' || $ext == 'wmv' || $ext == 'avi' || $ext == 'mpg' || $ext == 'ogv' || $ext == '3gp' || $ext == '3g2' ) {
			$icon = 'fa fa-file-video-o';
		} elseif ( $ext == 'zip' || $ext == 'gzip' || $ext == 'rar' || $ext == 'tar' ) {
			$icon = 'fa fa-file-archive-o';
		}

		return $icon;
	}
}


if ( ! function_exists( 'ulms_wpml_lang_switcher' ) ) {
	function ulms_wpml_lang_switcher() {
		if ( function_exists( 'icl_get_languages' ) ) {
			$languages = icl_get_languages( 'skip_missing=0&orderby=code' );
			$output    = '';
			if ( ! empty( $languages ) ) {
				$output .= '<div class="wpml_lang_switcher">';
				$output .= '<div class="active_language">' . esc_html( ICL_LANGUAGE_NAME_EN ) . '</div>';
				$output .= '<ul>';
				foreach ( $languages as $l ) {
					if ( ! $l['active'] ) {
						$output .= '<li>';
						$output .= '<a href="' . esc_url( $l['url'] ) . '">';
						$output .= esc_html( icl_disp_language( $l['native_name'] ) );
						$output .= '</a>';
						$output .= '</li>';
					}
				}
				$output .= '</ul>';
				$output .= '</div>';
				echo $output;
			}
		}
	}
}


if ( ! function_exists( 'ulms_get_header_style' ) ) {
	function ulms_get_header_style() {
		$header_style = ulms_option( 'header_style', 'header-style-1' );
		if ( isset( $_REQUEST['header_demo'] ) && $_REQUEST['header_demo'] == 'header-style-1' ) {
			$header_style = 'header-style-1';
		} elseif ( isset( $_REQUEST['header_demo'] ) && $_REQUEST['header_demo'] == 'header-style-2' ) {
			$header_style = 'header-style-2';
		} elseif ( isset( $_REQUEST['header_demo'] ) && $_REQUEST['header_demo'] == 'header-style-3' ) {
			$header_style = 'header-style-3';
		}

		return $header_style;
	}
}