<?php

if ( function_exists( 'vc_set_default_editor_post_types' ) ) {
	vc_set_default_editor_post_types( array(
		'page',
		'post',
		ULMS_COURSES_POST_TYPE,
		ULMS_GROUPS_POST_TYPE
	) );
}


if ( ! function_exists( 'ulms_vc_set_as_theme' ) ) {
	function ulms_vc_set_as_theme() {
		vc_set_as_theme( true );
	}
}

add_action( 'vc_before_init', 'ulms_vc_set_as_theme' );


if ( ! function_exists( 'ulms_update_shortcodes' ) ) {
	function ulms_update_shortcodes() {

		if ( function_exists( 'vc_add_params' ) ) {

			vc_add_params( 'vc_btn', array(
				array(
					'type'        => 'dropdown',
					'heading'     => esc_attr__( 'Style', 'ulms' ),
					'description' => esc_attr__( 'Select button display style.', 'ulms' ),
					'param_name'  => 'style',
					'value'       => array(
						esc_html__( 'Modern', 'ulms' )          => 'modern',
						esc_html__( 'Classic', 'ulms' )         => 'classic',
						esc_html__( 'Flat', 'ulms' )            => 'flat',
						esc_html__( 'Outline', 'ulms' )         => 'outline',
						esc_html__( '3d', 'ulms' )              => '3d',
						esc_html__( 'Custom', 'ulms' )          => 'custom',
						esc_html__( 'Outline custom', 'ulms' )  => 'outline-custom',
						esc_html__( 'Gradient', 'ulms' )        => 'gradient',
						esc_html__( 'Gradient Custom', 'ulms' ) => 'gradient-custom',
						esc_html__( 'Theme', 'ulms' )           => 'theme',
					),
				),
			) );

			vc_add_params( 'vc_tta_accordion', array(
				array(
					'type'               => 'dropdown',
					'param_name'         => 'color',
					'value'              => array_merge(
						getVcShared( 'colors-dashed' ),
						array( esc_html__( 'Theme Color', 'ulms' ) => 'theme-color' )
					),
					'std'                => 'grey',
					'heading'            => esc_html__( 'Color', 'ulms' ),
					'description'        => esc_html__( 'Select accordion color.', 'ulms' ),
					'param_holder_class' => 'vc_colored-dropdown',
				),
			) );

			vc_add_params( 'vc_tta_tabs', array(
				array(
					'type'               => 'dropdown',
					'param_name'         => 'color',
					'value'              => array_merge(
						getVcShared( 'colors-dashed' ),
						array( esc_html__( 'Theme Color', 'ulms' ) => 'theme-color' )
					),
					'std'                => 'grey',
					'heading'            => esc_html__( 'Color', 'ulms' ),
					'description'        => esc_html__( 'Select accordion color.', 'ulms' ),
					'param_holder_class' => 'vc_colored-dropdown',
				),
			) );

			vc_add_params( 'vc_tta_tour', array(
				array(
					'type'               => 'dropdown',
					'param_name'         => 'color',
					'value'              => array_merge(
						getVcShared( 'colors-dashed' ),
						array( esc_html__( 'Theme Color', 'ulms' ) => 'theme-color' )
					),
					'std'                => 'grey',
					'heading'            => esc_html__( 'Color', 'ulms' ),
					'description'        => esc_html__( 'Select accordion color.', 'ulms' ),
					'param_holder_class' => 'vc_colored-dropdown',
				),
			) );

		}
		
	}
}

add_action( 'admin_init', 'ulms_update_shortcodes' );


if ( ! function_exists( 'ulms_vc_elements' ) ) {
	function ulms_vc_elements() {

		if ( function_exists( 'vc_map' ) ) {

			vc_map( array(
				'name'     => esc_html__( 'Info Box', 'ulms' ),
				'base'     => 'ulms_info_box',
				'category' => esc_html__( 'ULMS', 'ulms' ),
				'params'   => array(
					array(
						'type'        => 'dropdown',
						'heading'     => esc_html__( 'Icon library', 'ulms' ),
						'value'       => array(
							esc_html__( 'ULMS Icons', 'ulms' )   => 'ulms',
							esc_html__( 'Font Awesome', 'ulms' ) => 'fontawesome',
							esc_html__( 'Open Iconic', 'ulms' )  => 'openiconic',
							esc_html__( 'Typicons', 'ulms' )     => 'typicons',
							esc_html__( 'Entypo', 'ulms' )       => 'entypo',
							esc_html__( 'Linecons', 'ulms' )     => 'linecons',
							esc_html__( 'Mono Social', 'ulms' )  => 'monosocial',
						),
						'param_name'  => 'icon_type',
						'description' => esc_html__( 'Select icon library.', 'ulms' ),
					),
					array(
						'type'        => 'iconpicker',
						'heading'     => esc_html__( 'Icon', 'ulms' ),
						'param_name'  => 'icon_ulms',
						'settings'    => array(
							'type' => 'ulms_icons'
						),
						'dependency'  => array(
							'element' => 'icon_type',
							'value'   => 'ulms',
						),
						'description' => esc_html__( 'Select icon from library.', 'ulms' ),
					),
					array(
						'type'        => 'iconpicker',
						'heading'     => esc_html__( 'Icon', 'ulms' ),
						'param_name'  => 'icon_fontawesome',
						'value'       => 'fa fa-adjust', // default value to backend editor admin_label
						'settings'    => array(
							'emptyIcon'    => false,
							// default true, display an "EMPTY" icon?
							'iconsPerPage' => 4000,
							// default 100, how many icons per/page to display, we use (big number) to display all icons in single page
						),
						'dependency'  => array(
							'element' => 'icon_type',
							'value'   => 'fontawesome',
						),
						'description' => esc_html__( 'Select icon from library.', 'ulms' ),
					),
					array(
						'type'        => 'iconpicker',
						'heading'     => esc_html__( 'Icon', 'ulms' ),
						'param_name'  => 'icon_openiconic',
						'value'       => 'vc-oi vc-oi-dial', // default value to backend editor admin_label
						'settings'    => array(
							'emptyIcon'    => false, // default true, display an "EMPTY" icon?
							'type'         => 'openiconic',
							'iconsPerPage' => 4000, // default 100, how many icons per/page to display
						),
						'dependency'  => array(
							'element' => 'icon_type',
							'value'   => 'openiconic',
						),
						'description' => esc_html__( 'Select icon from library.', 'ulms' ),
					),
					array(
						'type'        => 'iconpicker',
						'heading'     => esc_html__( 'Icon', 'ulms' ),
						'param_name'  => 'icon_typicons',
						'value'       => 'typcn typcn-adjust-brightness', // default value to backend editor admin_label
						'settings'    => array(
							'emptyIcon'    => false, // default true, display an "EMPTY" icon?
							'type'         => 'typicons',
							'iconsPerPage' => 4000, // default 100, how many icons per/page to display
						),
						'dependency'  => array(
							'element' => 'icon_type',
							'value'   => 'typicons',
						),
						'description' => esc_html__( 'Select icon from library.', 'ulms' ),
					),
					array(
						'type'       => 'iconpicker',
						'heading'    => esc_html__( 'Icon', 'ulms' ),
						'param_name' => 'icon_entypo',
						'value'      => 'entypo-icon entypo-icon-note', // default value to backend editor admin_label
						'settings'   => array(
							'emptyIcon'    => false, // default true, display an "EMPTY" icon?
							'type'         => 'entypo',
							'iconsPerPage' => 4000, // default 100, how many icons per/page to display
						),
						'dependency' => array(
							'element' => 'icon_type',
							'value'   => 'entypo',
						),
					),
					array(
						'type'        => 'iconpicker',
						'heading'     => esc_html__( 'Icon', 'ulms' ),
						'param_name'  => 'icon_linecons',
						'value'       => 'vc_li vc_li-heart', // default value to backend editor admin_label
						'settings'    => array(
							'emptyIcon'    => false, // default true, display an "EMPTY" icon?
							'type'         => 'linecons',
							'iconsPerPage' => 4000, // default 100, how many icons per/page to display
						),
						'dependency'  => array(
							'element' => 'icon_type',
							'value'   => 'linecons',
						),
						'description' => esc_html__( 'Select icon from library.', 'ulms' ),
					),
					array(
						'type'        => 'iconpicker',
						'heading'     => esc_html__( 'Icon', 'ulms' ),
						'param_name'  => 'icon_monosocial',
						'value'       => 'vc-mono vc-mono-fivehundredpx', // default value to backend editor admin_label
						'settings'    => array(
							'emptyIcon'    => false, // default true, display an "EMPTY" icon?
							'type'         => 'monosocial',
							'iconsPerPage' => 4000, // default 100, how many icons per/page to display
						),
						'dependency'  => array(
							'element' => 'icon_type',
							'value'   => 'monosocial',
						),
						'description' => esc_html__( 'Select icon from library.', 'ulms' ),
					),
					array(
						'type'       => 'number',
						'heading'    => esc_html__( 'Icon Wrapper Width', 'ulms' ),
						'suffix'     => 'px',
						'value'      => 75,
						'param_name' => 'icon_wr_width'
					),
					array(
						'type'       => 'number',
						'heading'    => esc_html__( 'Icon Size', 'ulms' ),
						'value'      => 50,
						'suffix'     => 'px',
						'param_name' => 'icon_size'
					),
					array(
						'type'       => 'textfield',
						'holder'     => 'div',
						'heading'    => esc_html__( 'Title', 'ulms' ),
						'param_name' => 'title'
					),
					array(
						'type'       => 'textarea',
						'heading'    => esc_html__( 'Text', 'ulms' ),
						'param_name' => 'content'
					),
					array(
						'type'       => 'colorpicker',
						'heading'    => esc_html__( 'Text Color', 'ulms' ),
						'param_name' => 'color'
					),
					array(
						'type'       => 'checkbox',
						'heading'    => esc_html__( 'Enable Hover Animation', 'ulms' ),
						'param_name' => 'enable_hover_animation',
						'value'      => array(
							esc_html__( 'Yes', 'ulms' ) => 'yes'
						),
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'ulms' ),
						'param_name'  => 'extra_class',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'ulms' )
					),
					array(
						'type'       => 'css_editor',
						'heading'    => esc_html__( 'Css', 'ulms' ),
						'param_name' => 'css',
						'group'      => esc_html__( 'Design options', 'ulms' )
					)
				)
			) );

			vc_map( array(
				'name'     => esc_html__( 'Info Box (Mini)', 'ulms' ),
				'base'     => 'ulms_info_box_mini',
				'category' => esc_html__( 'ULMS', 'ulms' ),
				'params'   => array(
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Style', 'ulms' ),
						'value'      => array(
							esc_html__( 'Style 1', 'ulms' ) => 'style_1',
							esc_html__( 'Style 2', 'ulms' ) => 'style_2',
						),
						'param_name' => 'style',
					),
					array(
						'type'        => 'dropdown',
						'heading'     => esc_html__( 'Icon library', 'ulms' ),
						'value'       => array(
							esc_html__( 'ULMS Icons', 'ulms' )   => 'ulms',
							esc_html__( 'Font Awesome', 'ulms' ) => 'fontawesome',
							esc_html__( 'Open Iconic', 'ulms' )  => 'openiconic',
							esc_html__( 'Typicons', 'ulms' )     => 'typicons',
							esc_html__( 'Entypo', 'ulms' )       => 'entypo',
							esc_html__( 'Linecons', 'ulms' )     => 'linecons',
							esc_html__( 'Mono Social', 'ulms' )  => 'monosocial',
						),
						'param_name'  => 'icon_type',
						'description' => esc_html__( 'Select icon library.', 'ulms' ),
					),
					array(
						'type'        => 'iconpicker',
						'heading'     => esc_html__( 'Icon', 'ulms' ),
						'param_name'  => 'icon_ulms',
						'settings'    => array(
							'type' => 'ulms_icons'
						),
						'dependency'  => array(
							'element' => 'icon_type',
							'value'   => 'ulms',
						),
						'description' => esc_html__( 'Select icon from library.', 'ulms' ),
					),
					array(
						'type'        => 'iconpicker',
						'heading'     => esc_html__( 'Icon', 'ulms' ),
						'param_name'  => 'icon_fontawesome',
						'value'       => 'fa fa-adjust', // default value to backend editor admin_label
						'settings'    => array(
							'emptyIcon'    => false,
							// default true, display an "EMPTY" icon?
							'iconsPerPage' => 4000,
							// default 100, how many icons per/page to display, we use (big number) to display all icons in single page
						),
						'dependency'  => array(
							'element' => 'icon_type',
							'value'   => 'fontawesome',
						),
						'description' => esc_html__( 'Select icon from library.', 'ulms' ),
					),
					array(
						'type'        => 'iconpicker',
						'heading'     => esc_html__( 'Icon', 'ulms' ),
						'param_name'  => 'icon_openiconic',
						'value'       => 'vc-oi vc-oi-dial', // default value to backend editor admin_label
						'settings'    => array(
							'emptyIcon'    => false, // default true, display an "EMPTY" icon?
							'type'         => 'openiconic',
							'iconsPerPage' => 4000, // default 100, how many icons per/page to display
						),
						'dependency'  => array(
							'element' => 'icon_type',
							'value'   => 'openiconic',
						),
						'description' => esc_html__( 'Select icon from library.', 'ulms' ),
					),
					array(
						'type'        => 'iconpicker',
						'heading'     => esc_html__( 'Icon', 'ulms' ),
						'param_name'  => 'icon_typicons',
						'value'       => 'typcn typcn-adjust-brightness', // default value to backend editor admin_label
						'settings'    => array(
							'emptyIcon'    => false, // default true, display an "EMPTY" icon?
							'type'         => 'typicons',
							'iconsPerPage' => 4000, // default 100, how many icons per/page to display
						),
						'dependency'  => array(
							'element' => 'icon_type',
							'value'   => 'typicons',
						),
						'description' => esc_html__( 'Select icon from library.', 'ulms' ),
					),
					array(
						'type'       => 'iconpicker',
						'heading'    => esc_html__( 'Icon', 'ulms' ),
						'param_name' => 'icon_entypo',
						'value'      => 'entypo-icon entypo-icon-note', // default value to backend editor admin_label
						'settings'   => array(
							'emptyIcon'    => false, // default true, display an "EMPTY" icon?
							'type'         => 'entypo',
							'iconsPerPage' => 4000, // default 100, how many icons per/page to display
						),
						'dependency' => array(
							'element' => 'icon_type',
							'value'   => 'entypo',
						),
					),
					array(
						'type'        => 'iconpicker',
						'heading'     => esc_html__( 'Icon', 'ulms' ),
						'param_name'  => 'icon_linecons',
						'value'       => 'vc_li vc_li-heart', // default value to backend editor admin_label
						'settings'    => array(
							'emptyIcon'    => false, // default true, display an "EMPTY" icon?
							'type'         => 'linecons',
							'iconsPerPage' => 4000, // default 100, how many icons per/page to display
						),
						'dependency'  => array(
							'element' => 'icon_type',
							'value'   => 'linecons',
						),
						'description' => esc_html__( 'Select icon from library.', 'ulms' ),
					),
					array(
						'type'        => 'iconpicker',
						'heading'     => esc_html__( 'Icon', 'ulms' ),
						'param_name'  => 'icon_monosocial',
						'value'       => 'vc-mono vc-mono-fivehundredpx', // default value to backend editor admin_label
						'settings'    => array(
							'emptyIcon'    => false, // default true, display an "EMPTY" icon?
							'type'         => 'monosocial',
							'iconsPerPage' => 4000, // default 100, how many icons per/page to display
						),
						'dependency'  => array(
							'element' => 'icon_type',
							'value'   => 'monosocial',
						),
						'description' => esc_html__( 'Select icon from library.', 'ulms' ),
					),
					array(
						'type'       => 'colorpicker',
						'heading'    => esc_html__( 'Icon Color', 'ulms' ),
						'param_name' => 'icon_color'
					),
					array(
						'type'       => 'number',
						'heading'    => esc_html__( 'Icon Wrapper Width', 'ulms' ),
						'suffix'     => 'px',
						'value'      => 35,
						'param_name' => 'icon_wr_width',
						'dependency' => array(
							'element' => 'style',
							'value'   => 'style_1',
						),
					),
					array(
						'type'       => 'number',
						'heading'    => esc_html__( 'Icon Size', 'ulms' ),
						'value'      => 26,
						'suffix'     => 'px',
						'param_name' => 'icon_size'
					),
					array(
						'type'       => 'textfield',
						'holder'     => 'div',
						'heading'    => esc_html__( 'Title', 'ulms' ),
						'param_name' => 'title'
					),
					array(
						'type'       => 'textarea',
						'heading'    => esc_html__( 'Text', 'ulms' ),
						'param_name' => 'content'
					),
					array(
						'type'       => 'colorpicker',
						'heading'    => esc_html__( 'Text Color', 'ulms' ),
						'param_name' => 'color'
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'ulms' ),
						'param_name'  => 'extra_class',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'ulms' )
					),
					array(
						'type'       => 'css_editor',
						'heading'    => esc_html__( 'Css', 'ulms' ),
						'param_name' => 'css',
						'group'      => esc_html__( 'Design options', 'ulms' )
					)
				)
			) );

			vc_map( array(
				'name'     => esc_html__( 'Courses', 'ulms' ),
				'base'     => 'ulms_courses',
				'category' => esc_html__( 'ULMS', 'ulms' ),
				'params'   => array(
					array(
						'type'       => 'checkbox',
						'heading'    => esc_html__( 'Disable Child Categories', 'ulms' ),
						'param_name' => 'disable_child_categories',
						'value'      => array(
							esc_html__( 'Yes', 'ulms' ) => 'yes'
						),
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'ulms' ),
						'param_name'  => 'extra_class',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'ulms' )
					),
					array(
						'type'       => 'css_editor',
						'heading'    => esc_html__( 'Css', 'ulms' ),
						'param_name' => 'css',
						'group'      => esc_html__( 'Design options', 'ulms' )
					)
				)
			) );

			vc_map( array(
				'name'     => esc_html__( 'Stats Counter', 'ulms' ),
				'base'     => 'ulms_stats_counter',
				'category' => esc_html__( 'ULMS', 'ulms' ),
				'params'   => array(
					array(
						'type'       => 'textfield',
						'holder'     => 'div',
						'heading'    => esc_html__( 'Title', 'ulms' ),
						'param_name' => 'title'
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Value', 'ulms' ),
						'param_name' => 'value',
						'value'      => '1000'
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Prefix', 'ulms' ),
						'param_name' => 'prefix',
						'value'      => ''
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Suffix', 'ulms' ),
						'param_name' => 'suffix',
						'value'      => ''
					),
					array(
						'type'       => 'colorpicker',
						'heading'    => esc_html__( 'Title Color', 'ulms' ),
						'param_name' => 'title_color'
					),
					array(
						'type'       => 'colorpicker',
						'heading'    => esc_html__( 'Value Color', 'ulms' ),
						'param_name' => 'value_color'
					),
					array(
						'type'        => 'dropdown',
						'heading'     => esc_html__( 'Icon library', 'ulms' ),
						'value'       => array(
							esc_html__( 'ULMS Icons', 'ulms' )   => 'ulms',
							esc_html__( 'Font Awesome', 'ulms' ) => 'fontawesome',
							esc_html__( 'Open Iconic', 'ulms' )  => 'openiconic',
							esc_html__( 'Typicons', 'ulms' )     => 'typicons',
							esc_html__( 'Entypo', 'ulms' )       => 'entypo',
							esc_html__( 'Linecons', 'ulms' )     => 'linecons',
							esc_html__( 'Mono Social', 'ulms' )  => 'monosocial',
						),
						'param_name'  => 'icon_type',
						'description' => esc_html__( 'Select icon library.', 'ulms' ),
						'group'       => esc_html__( 'Icon', 'ulms' )
					),
					array(
						'type'        => 'iconpicker',
						'heading'     => esc_html__( 'Icon', 'ulms' ),
						'param_name'  => 'icon_ulms',
						'settings'    => array(
							'type' => 'ulms_icons'
						),
						'dependency'  => array(
							'element' => 'icon_type',
							'value'   => 'ulms',
						),
						'description' => esc_html__( 'Select icon from library.', 'ulms' ),
						'group'       => esc_html__( 'Icon', 'ulms' )
					),
					array(
						'type'        => 'iconpicker',
						'heading'     => esc_html__( 'Icon', 'ulms' ),
						'param_name'  => 'icon_fontawesome',
						'value'       => 'fa fa-adjust', // default value to backend editor admin_label
						'settings'    => array(
							'emptyIcon'    => false,
							// default true, display an "EMPTY" icon?
							'iconsPerPage' => 4000,
							// default 100, how many icons per/page to display, we use (big number) to display all icons in single page
						),
						'dependency'  => array(
							'element' => 'icon_type',
							'value'   => 'fontawesome',
						),
						'description' => esc_html__( 'Select icon from library.', 'ulms' ),
						'group'       => esc_html__( 'Icon', 'ulms' )
					),
					array(
						'type'        => 'iconpicker',
						'heading'     => esc_html__( 'Icon', 'ulms' ),
						'param_name'  => 'icon_openiconic',
						'value'       => 'vc-oi vc-oi-dial', // default value to backend editor admin_label
						'settings'    => array(
							'emptyIcon'    => false, // default true, display an "EMPTY" icon?
							'type'         => 'openiconic',
							'iconsPerPage' => 4000, // default 100, how many icons per/page to display
						),
						'dependency'  => array(
							'element' => 'icon_type',
							'value'   => 'openiconic',
						),
						'description' => esc_html__( 'Select icon from library.', 'ulms' ),
						'group'       => esc_html__( 'Icon', 'ulms' )
					),
					array(
						'type'        => 'iconpicker',
						'heading'     => esc_html__( 'Icon', 'ulms' ),
						'param_name'  => 'icon_typicons',
						'value'       => 'typcn typcn-adjust-brightness', // default value to backend editor admin_label
						'settings'    => array(
							'emptyIcon'    => false, // default true, display an "EMPTY" icon?
							'type'         => 'typicons',
							'iconsPerPage' => 4000, // default 100, how many icons per/page to display
						),
						'dependency'  => array(
							'element' => 'icon_type',
							'value'   => 'typicons',
						),
						'description' => esc_html__( 'Select icon from library.', 'ulms' ),
						'group'       => esc_html__( 'Icon', 'ulms' )
					),
					array(
						'type'       => 'iconpicker',
						'heading'    => esc_html__( 'Icon', 'ulms' ),
						'param_name' => 'icon_entypo',
						'value'      => 'entypo-icon entypo-icon-note', // default value to backend editor admin_label
						'settings'   => array(
							'emptyIcon'    => false, // default true, display an "EMPTY" icon?
							'type'         => 'entypo',
							'iconsPerPage' => 4000, // default 100, how many icons per/page to display
						),
						'dependency' => array(
							'element' => 'icon_type',
							'value'   => 'entypo',
						),
						'group'      => esc_html__( 'Icon', 'ulms' )
					),
					array(
						'type'        => 'iconpicker',
						'heading'     => esc_html__( 'Icon', 'ulms' ),
						'param_name'  => 'icon_linecons',
						'value'       => 'vc_li vc_li-heart', // default value to backend editor admin_label
						'settings'    => array(
							'emptyIcon'    => false, // default true, display an "EMPTY" icon?
							'type'         => 'linecons',
							'iconsPerPage' => 4000, // default 100, how many icons per/page to display
						),
						'dependency'  => array(
							'element' => 'icon_type',
							'value'   => 'linecons',
						),
						'description' => esc_html__( 'Select icon from library.', 'ulms' ),
						'group'       => esc_html__( 'Icon', 'ulms' )
					),
					array(
						'type'        => 'iconpicker',
						'heading'     => esc_html__( 'Icon', 'ulms' ),
						'param_name'  => 'icon_monosocial',
						'value'       => 'vc-mono vc-mono-fivehundredpx', // default value to backend editor admin_label
						'settings'    => array(
							'emptyIcon'    => false, // default true, display an "EMPTY" icon?
							'type'         => 'monosocial',
							'iconsPerPage' => 4000, // default 100, how many icons per/page to display
						),
						'dependency'  => array(
							'element' => 'icon_type',
							'value'   => 'monosocial',
						),
						'description' => esc_html__( 'Select icon from library.', 'ulms' ),
						'group'       => esc_html__( 'Icon', 'ulms' )
					),
					array(
						'type'       => 'colorpicker',
						'heading'    => esc_html__( 'Icon Color', 'ulms' ),
						'param_name' => 'icon_color',
						'group'      => esc_html__( 'Icon', 'ulms' )
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Icon Wrapper Height', 'ulms' ),
						'value'      => 120,
						'param_name' => 'icon_wr_height',
						'group'      => esc_html__( 'Icon', 'ulms' )
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Icon Size', 'ulms' ),
						'value'      => 80,
						'param_name' => 'icon_size',
						'group'      => esc_html__( 'Icon', 'ulms' )
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'ulms' ),
						'param_name'  => 'extra_class',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'ulms' )
					),
					array(
						'type'       => 'css_editor',
						'heading'    => esc_html__( 'Css', 'ulms' ),
						'param_name' => 'css',
						'group'      => esc_html__( 'Design options', 'ulms' )
					)
				)
			) );

			vc_map( array(
				'name'     => esc_html__( 'News', 'ulms' ),
				'base'     => 'ulms_news',
				'category' => esc_html__( 'ULMS', 'ulms' ),
				'params'   => array(
					array(
						'type'       => 'loop',
						'heading'    => esc_html__( 'Query', 'ulms' ),
						'param_name' => 'loop',
						'value'      => 'size:3|post_type:post',
						'settings'   => array(
							'size' => array( 'hidden' => false, 'value' => 3 )
						),
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'ulms' ),
						'param_name'  => 'extra_class',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'ulms' )
					),
					array(
						'type'       => 'css_editor',
						'heading'    => esc_html__( 'Css', 'ulms' ),
						'param_name' => 'css',
						'group'      => esc_html__( 'Design options', 'ulms' )
					)
				)
			) );

			vc_map( array(
				'name'     => esc_html__( 'Count Down Timer', 'ulms' ),
				'base'     => 'ulms_countdown_timer',
				'category' => esc_html__( 'ULMS', 'ulms' ),
				'params'   => array(
					array(
						'type'       => 'datetimepicker',
						'heading'    => esc_html__( 'Target Time For Countdown', 'ulms' ),
						'param_name' => 'datetime'
					),
					array(
						'type'       => 'colorpicker',
						'heading'    => esc_html__( 'Base Color', 'ulms' ),
						'param_name' => 'color'
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'ulms' ),
						'param_name'  => 'extra_class',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'ulms' )
					),
					array(
						'type'       => 'css_editor',
						'heading'    => esc_html__( 'Css', 'ulms' ),
						'param_name' => 'css',
						'group'      => esc_html__( 'Design options', 'ulms' )
					)
				)
			) );

			vc_map( array(
				'name'     => esc_html__( 'Teachers', 'ulms' ),
				'base'     => 'ulms_teachers',
				'category' => esc_html__( 'ULMS', 'ulms' ),
				'params'   => array(
					array(
						'type'       => 'number',
						'heading'    => esc_html__( 'The number of authors', 'ulms' ),
						'param_name' => 'number',
						'min'        => 1,
						'value'      => 4
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'ulms' ),
						'param_name'  => 'extra_class',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'ulms' )
					),
					array(
						'type'       => 'css_editor',
						'heading'    => esc_html__( 'Css', 'ulms' ),
						'param_name' => 'css',
						'group'      => esc_html__( 'Design options', 'ulms' )
					)
				)
			) );

			vc_map( array(
				'name'     => esc_html__( 'Image Carousel', 'ulms' ),
				'base'     => 'ulms_image_carousel',
				'icon'     => 'ulms_image_carousel',
				'category' => esc_html__( 'ULMS', 'ulms' ),
				'params'   => array(
					array(
						'type'       => 'attach_images',
						'heading'    => esc_html__( 'Images', 'ulms' ),
						'param_name' => 'images'
					),
					array(
						'type'       => 'vc_link',
						'heading'    => esc_html__( 'Link', 'ulms' ),
						'param_name' => 'link'
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Image size', 'ulms' ),
						'param_name'  => 'img_size',
						'value'       => 'thumbnail',
						'description' => esc_html__( 'Enter image size. Example: thumbnail, medium, large, full or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height). Leave empty to use default size.', 'ulms' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'ulms' ),
						'param_name'  => 'extra_class',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'ulms' )
					),
					array(
						'type'       => 'checkbox',
						'param_name' => 'nav_buttons',
						'value'      => array(
							esc_html__( 'Show next/prev buttons.', 'ulms' ) => 'show'
						),
						'group'      => esc_html__( 'Carousel', 'ulms' )
					),
					array(
						'type'       => 'checkbox',
						'param_name' => 'dots',
						'value'      => array(
							esc_html__( 'Show dots navigation.', 'ulms' ) => 'show'
						),
						'group'      => esc_html__( 'Carousel', 'ulms' )
					),
					array(
						'type'        => 'checkbox',
						'heading'     => esc_html__( 'Slider autoplay', 'ulms' ),
						'param_name'  => 'autoplay',
						'description' => esc_html__( 'Enables Autoplay', 'ulms' ),
						'value'       => array(
							esc_html__( 'Yes', 'ulms' ) => 'yes'
						),
						'group'       => esc_html__( 'Carousel', 'ulms' )
					),
					array(
						'type'        => 'number',
						'heading'     => esc_html__( 'Autoplay Timeout', 'ulms' ),
						'param_name'  => 'timeout',
						'value'       => '5000',
						'min'         => 1,
						'suffix'      => 'ms.',
						'description' => esc_html__( 'Autoplay Speed in milliseconds', 'ulms' ),
						'dependency'  => array(
							'element' => 'autoplay',
							'value'   => array( 'yes' ),
						),
						'group'       => esc_html__( 'Carousel', 'ulms' ),
					),
					array(
						'type'        => 'checkbox',
						'heading'     => esc_html__( 'Slider loop', 'ulms' ),
						'param_name'  => 'loop',
						'description' => esc_html__( 'Infinite loop sliding', 'ulms' ),
						'value'       => array(
							esc_html__( 'Yes', 'ulms' ) => 'yes'
						),
						'group'       => esc_html__( 'Carousel', 'ulms' ),
					),
					array(
						'type'        => 'number',
						'heading'     => esc_html__( 'Speed', 'ulms' ),
						'description' => esc_html__( 'Slide animation speed', 'ulms' ),
						'param_name'  => 'smart_speed',
						'value'       => '250',
						'suffix'      => 'ms.',
						'min'         => 1,
						'group'       => esc_html__( 'Carousel', 'ulms' ),
					),
					array(
						'type'        => 'number',
						'heading'     => esc_html__( 'Items', 'ulms' ),
						'param_name'  => 'items',
						'min'         => 1,
						'value'       => '6',
						'description' => esc_html__( '# of slides to show', 'ulms' ),
						'group'       => esc_html__( 'Carousel', 'ulms' ),
					),
					array(
						'type'        => 'number',
						'heading'     => esc_html__( 'Items To Scroll', 'ulms' ),
						'description' => esc_html__( '# of slides to scroll', 'ulms' ),
						'param_name'  => 'items_to_scroll',
						'min'         => 1,
						'value'       => '6',
						'description' => esc_html__( '# of slides to show', 'ulms' ),
						'group'       => esc_html__( 'Carousel', 'ulms' ),
					),
					array(
						'type'        => 'number',
						'heading'     => esc_html__( 'Items (Small Desktop)', 'ulms' ),
						'param_name'  => 'items_small_desktop',
						'value'       => '5',
						'min'         => 1,
						'description' => esc_html__( 'Number of items the carousel will display. Default: at <1024px - 3 items.', 'ulms' ),
						'group'       => esc_html__( 'Carousel', 'ulms' ),
					),
					array(
						'type'        => 'number',
						'heading'     => esc_html__( 'Items (Tablet)', 'ulms' ),
						'param_name'  => 'items_tablet',
						'value'       => '4',
						'min'         => 1,
						'description' => esc_html__( 'Number of items the carousel will display. Default: at <600px - 2 items.', 'ulms' ),
						'group'       => esc_html__( 'Carousel', 'ulms' ),
					),
					array(
						'type'        => 'number',
						'heading'     => esc_html__( 'Items (Mobile)', 'ulms' ),
						'param_name'  => 'items_mobile',
						'value'       => '1',
						'min'         => 1,
						'description' => esc_html__( 'Number of items the carousel will display. Default: at <480px - 1 item.', 'ulms' ),
						'group'       => esc_html__( 'Carousel', 'ulms' ),
					),
					array(
						'type'       => 'css_editor',
						'heading'    => esc_html__( 'Css', 'ulms' ),
						'param_name' => 'css',
						'group'      => esc_html__( 'Design options', 'ulms' )
					)
				)
			) );

			vc_map( array(
				'name'     => esc_html__( 'Google Map', 'ulms' ),
				'base'     => 'ulms_gmap',
				'category' => esc_html__( 'ULMS', 'ulms' ),
				'params'   => array(
					array(
						'type'       => 'number',
						'heading'    => esc_html__( 'Height', 'ulms' ),
						'param_name' => 'height',
						'value'      => '620',
						'suffix'     => 'px.',
					),
					array(
						'type'       => 'attach_image',
						'heading'    => esc_html__( 'Marker Image', 'ulms' ),
						'param_name' => 'marker'
					),
					array(
						'type'       => 'checkbox',
						'param_name' => 'disable_mouse_whell',
						'value'      => array(
							esc_html__( 'Disable map zoom on mouse wheel scroll', 'ulms' ) => 'disable'
						)
					),
					array(
						'type'       => 'number',
						'heading'    => esc_html__( 'Zoom', 'ulms' ),
						'param_name' => 'zoom',
						'value'      => '8'
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Latitude', 'ulms' ),
						'param_name'  => 'lat',
						'description' => wp_kses( __( "<a href=\"http://www.latlong.net/convert-address-to-lat-long.html\">Here is a tool</a> where you can find Latitude & Longitude of your location", 'ulms' ), array( 'a' => array( 'href' => array() ) ) )
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Longitude', 'ulms' ),
						'param_name'  => 'lng',
						'description' => wp_kses( __( "<a href=\"http://www.latlong.net/convert-address-to-lat-long.html\">Here is a tool</a> where you can find Latitude & Longitude of your location", 'ulms' ), array( 'a' => array( 'href' => array() ) ) )
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'ulms' ),
						'param_name'  => 'extra_class',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'ulms' )
					),
					array(
						'type'       => 'css_editor',
						'heading'    => esc_html__( 'Css', 'ulms' ),
						'param_name' => 'css',
						'group'      => esc_html__( 'Design options', 'ulms' )
					)
				)
			) );

			vc_map( array(
				'name'                    => esc_html__( 'Google Map (Multiple Markers)', 'ulms' ),
				'base'                    => 'ulms_gmap_carousel',
				'as_parent'               => array( 'only' => 'ulms_gmap_carousel_address' ),
				'show_settings_on_create' => true,
				'js_view'                 => 'VcColumnView',
				'category'                => esc_html__( 'ULMS', 'ulms' ),
				'params'                  => array(
					array(
						'type'       => 'number',
						'heading'    => esc_html__( 'Height', 'ulms' ),
						'param_name' => 'height',
						'value'      => '620',
						'suffix'     => 'px',
					),
					array(
						'type'       => 'attach_image',
						'heading'    => esc_html__( 'Marker Image', 'ulms' ),
						'param_name' => 'marker'
					),
					array(
						'type'       => 'checkbox',
						'param_name' => 'disable_mouse_whell',
						'value'      => array(
							esc_html__( 'Disable map zoom on mouse wheel scroll', 'ulms' ) => 'disable'
						)
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'ulms' ),
						'param_name'  => 'extra_class',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'ulms' )
					),
					array(
						'type'       => 'css_editor',
						'heading'    => esc_html__( 'Css', 'ulms' ),
						'param_name' => 'css',
						'group'      => esc_html__( 'Design options', 'ulms' )
					)
				)
			) );

			vc_map( array(
				'name'     => esc_html__( 'Address', 'ulms' ),
				'base'     => 'ulms_gmap_carousel_address',
				'as_child' => array( 'only' => 'ulms_gmap_carousel' ),
				'params'   => array(
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Title', 'ulms' ),
						'admin_label' => true,
						'param_name'  => 'title'
					),
					array(
						'type'       => 'textarea',
						'heading'    => esc_html__( 'Address', 'ulms' ),
						'param_name' => 'address'
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Email', 'ulms' ),
						'param_name' => 'email'
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Phone', 'ulms' ),
						'param_name' => 'phone'
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Latitude', 'ulms' ),
						'param_name'  => 'lat',
						'description' => wp_kses( __( "<a href=\"http://www.latlong.net/convert-address-to-lat-long.html\">Here is a tool</a> where you can find Latitude & Longitude of your location", 'ulms' ), array( 'a' => array( 'href' => array() ) ) )
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Longitude', 'ulms' ),
						'param_name'  => 'lng',
						'description' => wp_kses( __( "<a href=\"http://www.latlong.net/convert-address-to-lat-long.html\">Here is a tool</a> where you can find Latitude & Longitude of your location", 'ulms' ), array( 'a' => array( 'href' => array() ) ) )
					),
				)
			) );

			vc_map( array(
				'name'     => esc_html__( 'Social Links', 'ulms' ),
				'base'     => 'ulms_social_links',
				'category' => esc_html__( 'ULMS', 'ulms' ),
				'params'   => array(
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Facebook', 'ulms' ),
						'param_name' => 'facebook'
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Twitter', 'ulms' ),
						'param_name' => 'twitter'
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Google Plus', 'ulms' ),
						'param_name' => 'google_plus'
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'LinkedIn', 'ulms' ),
						'param_name' => 'linkedin'
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'ulms' ),
						'param_name'  => 'extra_class',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'ulms' )
					),
					array(
						'type'       => 'css_editor',
						'heading'    => esc_html__( 'Css', 'ulms' ),
						'param_name' => 'css',
						'group'      => esc_html__( 'Design options', 'ulms' )
					)
				)
			) );

			vc_map( array(
				'name'     => esc_html__( 'Testimonials', 'ulms' ),
				'base'     => 'ulms_testimonials',
				'category' => esc_html__( 'ULMS', 'ulms' ),
				'params'   => array(
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'ulms' ),
						'param_name'  => 'extra_class',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'ulms' )
					),
					array(
						'type'       => 'css_editor',
						'heading'    => esc_html__( 'Css', 'ulms' ),
						'param_name' => 'css',
						'group'      => esc_html__( 'Design options', 'ulms' )
					)
				)
			) );


			$members = array();

			$users_list = get_users( array(
				'role'   => ULMS_TEACHERS_ROLE,
				'fields' => array( 'ID', 'display_name' )
			) );

			if ( $users_list ) {
				foreach ( $users_list as $user ) {
					$members[ $user->display_name ] = $user->ID;
				}
			}

			vc_map( array(
				'name'     => esc_html__( 'Team Member', 'ulms' ),
				'base'     => 'ulms_team_member',
				'category' => esc_html__( 'ULMS', 'ulms' ),
				'params'   => array(
					array(
						'type'        => 'dropdown',
						'heading'     => __( 'Select Member', 'ulms' ),
						'value'       => $members,
						'admin_label' => true,
						'param_name'  => 'user_id'
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'ulms' ),
						'param_name'  => 'extra_class',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'ulms' )
					),
					array(
						'type'       => 'css_editor',
						'heading'    => esc_html__( 'Css', 'ulms' ),
						'param_name' => 'css',
						'group'      => esc_html__( 'Design options', 'ulms' )
					)
				)
			) );

		}

	}
}

add_action( 'init', 'ulms_vc_elements' );


if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
	class WPBakeryShortCode_Ulms_Gmap_Carousel extends WPBakeryShortCodesContainer {
	}
}

if ( class_exists( 'WPBakeryShortCode' ) ) {
	class WPBakeryShortCode_Ulms_Info_Box extends WPBakeryShortCode {
	}

	class WPBakeryShortCode_Ulms_Info_Box_Mini extends WPBakeryShortCode {
	}

	class WPBakeryShortCode_Ulms_Courses extends WPBakeryShortCode {
	}

	class WPBakeryShortCode_Ulms_Stats_Counter extends WPBakeryShortCode {
	}

	class WPBakeryShortCode_Ulms_News extends WPBakeryShortCode {
	}

	class WPBakeryShortCode_Ulms_Countdown_Timer extends WPBakeryShortCode {
	}

	class WPBakeryShortCode_Ulms_Teachers extends WPBakeryShortCode {
	}

	class WPBakeryShortCode_Ulms_Image_Carousel extends WPBakeryShortCode {
	}

	class WPBakeryShortCode_Ulms_Gmap extends WPBakeryShortCode {
	}

	class WPBakeryShortCode_Ulms_Gmap_Carousel_Address extends WPBakeryShortCode {
	}

	class WPBakeryShortCode_Ulms_Social_Links extends WPBakeryShortCode {
	}

	class WPBakeryShortCode_Ulms_Testimonials extends WPBakeryShortCode {
	}

	class WPBakeryShortCode_Ulms_Team_Member extends WPBakeryShortCode {
	}
}


if ( ! function_exists( 'ulms_vc_icons' ) ) {
	function ulms_vc_icons( $fonts ) {
		global $wp_filesystem;
		if ( empty( $wp_filesystem ) ) {
			require_once ABSPATH . '/wp-admin/includes/file.php';
			WP_Filesystem();
		}
		$icons = json_decode( $wp_filesystem->get_contents( get_template_directory() . '/assets/js/selection.json' ), true );

		foreach ( $icons['icons'] as $icon ) {
			$fonts[] = array( "ulms-icon-" . $icon['properties']['name'] => $icon['properties']['name'] );
		}

		return $fonts;
	}
}

add_filter( 'vc_iconpicker-type-ulms_icons', 'ulms_vc_icons' );