<?php if ( $courses = get_user_meta( get_current_user_id(), 'courses', true ) ): ?>
	<?php if( ! empty( $_REQUEST['notice'] ) && $_REQUEST['notice'] == '1' ): ?>
		<div class="woocommerce-message"><?php esc_html_e( 'Course successfully added', 'ulms' ); ?></div>
	<?php endif; ?>
	<ul class="account-tabs hidden-xs" id="account-courses-filter">
		<li><a href="#all" class="active"><?php esc_html_e( 'All', 'ulms' ); ?></a></li>
		<li><a href="#online"><?php esc_html_e( 'Online', 'ulms' ); ?></a></li>
		<li><a href="#onsite"><?php esc_html_e( 'Onsite', 'ulms' ); ?></a></li>
		<li><a href="#inprogress"><?php esc_html_e( 'In Progress', 'ulms' ); ?></a></li>
		<li><a href="#finished"><?php esc_html_e( 'Finished', 'ulms' ); ?></a></li>
	</ul>

	<div class="account-courses">
		<?php foreach ( $courses as $course_id => $data ): ?>
			<?php
				$course_data = Runa_Courses::get_course( $course_id );
				$item_class = 'isotope-item all';
				if ( $course_data['course_type'] == 'online' ){
					$item_class .= ' online';
				}elseif( $course_data['course_type'] == 'onsite' ){
					$item_class .= ' onsite';
				}
				if( ! empty( $data['passed_lessons'] ) && count( $data['passed_lessons'] ) >= $course_data['total_lessons'] ){
					$item_class .= ' finished';
				}elseif( ! empty( $data['passed_lessons'] ) && count( $data['passed_lessons'] ) <= $course_data['total_lessons'] ){
					$item_class .= ' inprogress';
				}
			?>
			<div class="<?php echo esc_attr( $item_class ); ?>">
				<div class="item-wr">
					<div class="course-info">
						<div class="course-image">
							<?php if( has_post_thumbnail( $course_id ) ): ?>
								<a href="<?php echo esc_url( get_the_permalink( $course_id ) ); ?>">
									<?php echo get_the_post_thumbnail( $course_id, 'ulms-70x70-cropped' ); ?>
								</a>
							<?php endif; ?>
						</div>
						<div class="info">
							<h4>
								<a href="<?php echo esc_url( get_the_permalink( $course_id ) ); ?>"><?php echo esc_html( get_the_title( $course_id ) ); ?></a>
							</h4>
							<div class="course-type">
								<?php if ( $course_data['course_type'] == 'online' ): ?>
									<?php esc_html_e( 'Online Course', 'ulms' ); ?>
								<?php elseif ( $course_data['course_type'] == 'onsite' ): ?>
									<?php esc_html_e( 'Onsite Course', 'ulms' ); ?>
									<?php if( ! empty( $data['group_id'] ) ): ?>
										<span>&bull;</span>
										<a href="<?php echo esc_url( get_the_permalink( $data['group_id'] ) ); ?>"><?php echo esc_html( get_the_title( $data['group_id'] ) ); ?></a>
									<?php endif; ?>
								<?php endif; ?>
							</div>
						</div>
					</div>
					<div class="course-add-info">
						<?php if( ! empty( $data['passed_lessons'] ) && count( $data['passed_lessons'] ) >= $course_data['total_lessons'] ): ?>
							<div class="course-passed">
								<i class="fa fa-trophy"></i>
								<span><?php esc_html_e( 'course passed', 'ulms' ); ?></span>
							</div>
						<?php else: ?>
							&mdash;
						<?php endif; ?>
					</div>
					<div class="course-students-num">
						<?php if ( $course_data['course_type'] == 'online' ): ?>
							<strong><?php echo number_format( get_post_meta( $course_id, 'students', true ), 0, '.', ' ' ); ?></strong>
						<?php elseif ( $course_data['course_type'] == 'onsite' ): ?>
							<strong><?php echo number_format( get_post_meta( $data['group_id'], 'group_students', true ), 0, '.', ' ' ); ?></strong>
						<?php endif; ?>
						<span><?php esc_html_e( 'students', 'ulms' ); ?></span>
					</div>
					<div class="course-progress">
						<?php if( ! empty( $data['passed_lessons'] ) ): ?>
							<?php $percent = count( $data['passed_lessons'] ) * 100 / $course_data['total_lessons']; ?>
							<div class="progress-radial progress-<?php echo esc_attr( round( $percent ) ); ?>">
								<div class="overlay">
									<strong><?php echo esc_html( count( $data['passed_lessons'] ) )?>/<?php echo esc_html( $course_data['total_lessons'] ); ?></strong>
									<span><?php esc_html_e( 'passed', 'ulms' ); ?></span>
								</div>
							</div>
						<?php else: ?>
							<div class="progress-radial progress-0">
								<div class="overlay">
									<strong>0/<?php echo esc_html( $course_data['total_lessons'] ); ?></strong>
									<span><?php esc_html_e( 'passed', 'ulms' ); ?></span>
								</div>
							</div>
						<?php endif; ?>
					</div>
					<div class="course-remove">
						<form method="post" action="">
							<button><i class="fa fa-times"></i></button>
							<input type="hidden" name="course_id" value="<?php echo esc_attr( $course_id ); ?>" />
							<?php wp_nonce_field( 'runa-delete-course-nonce', 'delete_course' ); ?>
						</form>
					</div>
				</div>
			</div>
		<?php endforeach; wp_reset_postdata(); ?>
	</div>
	<script type="text/javascript">
		jQuery(document).ready(function ($) {
			var courses_isotope = $(".account-courses");
			courses_isotope.isotope({
				itemSelector: '.isotope-item',
				stagger: 50
			});
			$('#account-courses-filter a').on('click', function () {
				$(this).closest('ul').find('.active').removeClass('active');
				$(this).addClass('active');
				var courses_type = $(this).attr('href');
				console.log(courses_type.replace('#',''));
				courses_isotope.isotope({filter: '.' + courses_type.replace('#','')});
				return false;
			});
		});
	</script>
<?php else: ?>
	<div class="woocommerce-message woocommerce-info"><?php esc_html_e( 'Courses not found', 'ulms' ); ?></div>
<?php endif; ?>