<?php
/**
 * Edit account form
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/myaccount/form-edit-account.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woothemes.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 2.6.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

do_action( 'woocommerce_before_edit_account_form' ); ?>

<?php global $wpdb; $user_info = wp_get_current_user(); ?>
<div class="account-settings">
	<h2 class="account-page-title"><?php esc_html_e( 'Settings', 'ulms' )?></h2>
	<div class="account-image-settings">
		<div class="account-image">
			<?php echo get_avatar( $user_info->ID, 70 ); ?>
		</div>
		<a href="#" id="update_user_image" class="update_account_image button size-xs bordered"><?php esc_html_e( 'Update Photo', 'ulms' ); ?></a>
		<?php if( get_user_meta( $user_info->ID, $wpdb->get_blog_prefix( get_current_blog_id() ) . 'user_avatar', true ) ) : ?>
			<form method="post" action="">
				<a href="#" id="delete_account_image"><?php esc_html_e( 'Delete photo', 'ulms' ); ?></a>
				<?php wp_nonce_field( 'runa-account-remove-image-nonce', 'account_remove_image_security' ); ?>
			</form>
		<?php endif; ?>
		<form method="post" action="" enctype="multipart/form-data">
			<input type="file" name="image" id="user_image_file" style="display: none;" />
			<?php wp_nonce_field( 'runa-account-edit-image-nonce', 'account_edit_image_security' ); ?>
		</form>
	</div>
	<div class="account-info-fields">
		<form method="post" action="">
			<div class="row">
				<div class="col-xs-12 col-sm-6 col-md-6 col-lg-6">
					<div class="input-group">
						<label for="account_name"><?php esc_html_e( 'First Name', 'ulms' ); ?><span class="req">*</span></label>
						<input id="account_name" class="form-control<?php echo ( ! empty( $_POST['errors']['first_name'] ) ? ' error"' : '' ); ?>" name="account_info[first_name]" type="text" value="<?php echo ( isset( $_POST['account_info']['first_name'] ) ) ? esc_attr( $_POST['account_info']['first_name'] ) : esc_attr( $user_info->first_name ); ?>" required />
						<?php if( ! empty( $_POST['errors']['first_name'] ) ) : ?>
							<span class="error-label"><?php echo esc_html( $_POST['errors']['first_name'] ); ?></span>
						<?php endif; ?>
					</div>
				</div>
				<div class="col-xs-12 col-sm-6 col-md-6 col-lg-6">
					<div class="input-group">
						<label for="account_last_name"><?php esc_html_e( 'Last Name', 'ulms' ); ?><span class="req">*</span></label>
						<input id="account_last_name" class="form-control<?php echo ( ! empty( $_POST['errors']['last_name'] ) ? ' error"' : '' ); ?>" name="account_info[last_name]" type="text" value="<?php echo ( isset( $_POST['account_info']['last_name'] ) ) ? esc_attr( $_POST['account_info']['last_name'] ) : esc_attr( $user_info->last_name ); ?>" required />
						<?php if( ! empty( $_POST['errors']['last_name'] ) ) : ?>
							<span class="error-label"><?php echo esc_html( $_POST['errors']['last_name'] ); ?></span>
						<?php endif; ?>
					</div>
				</div>
			</div>
			<div class="row">
				<div class="col-xs-12 col-sm-6 col-md-6 col-lg-6">
					<div class="input-group">
						<label for="account_email"><?php esc_html_e( 'Email', 'ulms' ); ?><span class="req">*</span></label>
						<input id="account_email" class="form-control<?php echo ( ! empty( $_POST['errors']['email'] ) ? ' error"' : '' ); ?>" name="account_info[email]" type="email" value="<?php echo ( isset( $_POST['account_info']['email'] ) ) ? esc_attr( $_POST['account_info']['email'] ) : esc_attr( $user_info->user_email ); ?>" required />
						<?php if( ! empty( $_POST['errors']['email'] ) ) : ?>
							<span class="error-label"><?php echo esc_html( $_POST['errors']['email'] ); ?></span>
						<?php endif; ?>
					</div>
				</div>
				<div class="col-xs-12 col-sm-6 col-md-6 col-lg-6">
					<div class="input-group">
						<label for="account_phone"><?php esc_html_e( 'Phone', 'ulms' ); ?></label>
						<input id="account_phone" class="form-control" name="account_info[phone]" type="tel" value="<?php echo ( isset( $_POST['account_info']['phone'] ) ) ? esc_attr( $_POST['account_info']['phone'] ) : esc_attr( get_user_meta( $user_info->ID, 'phone', true ) ); ?>" />
					</div>
				</div>
			</div>
			<div class="row">
				<div class="col-xs-12 col-sm-6 col-md-6 col-lg-6">
					<div class="input-group">
						<label for="account_new_password"><?php esc_html_e( 'New Password', 'ulms' ); ?></label>
						<input id="account_new_password" class="form-control<?php echo ( ! empty( $_POST['errors']['password'] ) || ! empty( $_POST['errors']['confirm'] ) ? ' error"' : '' ); ?>" name="account_info[password]" type="password" value="" />
						<?php if( ! empty( $_POST['errors']['password'] ) ) : ?>
							<span class="error-label"><?php echo esc_html( $_POST['errors']['password'] ); ?></span>
						<?php endif; ?>
					</div>
				</div>
				<div class="col-xs-12 col-sm-6 col-md-6 col-lg-6">
					<div class="input-group">
						<label for="account_confirm"><?php esc_html_e( 'Confirm Password', 'ulms' ); ?></label>
						<input id="account_confirm" class="form-control<?php echo ( ! empty( $_POST['errors']['password'] ) || ! empty( $_POST['errors']['confirm'] ) ? ' error"' : '' ); ?>" name="account_info[confirm]" type="password" value="" />
						<?php if( ! empty( $_POST['errors']['confirm'] ) ) : ?>
							<span class="error-label"><?php echo esc_html( $_POST['errors']['confirm'] ); ?></span>
						<?php endif; ?>
					</div>
				</div>
			</div>
			<div class="account-submit-buttons">
				<div class="input-group">
					<button class="button"><?php esc_html_e( 'Save Changes', 'ulms' ); ?></button>
					<?php wp_nonce_field( 'runa-account-settings-nonce', 'edit_account_settings' ); ?>
				</div>
			</div>
		</form>
	</div>
	<div class="account-info-fields">
		<form method="post" action="">
			<div class="row">
				<div class="col-xs-12 col-sm-6 col-md-6 col-lg-6">
					<div class="input-group">
						<label for="account_facebook"><?php esc_html_e( 'Facebook', 'ulms' ); ?></label>
						<input id="account_facebook" class="form-control" name="account_additional_info[facebook]" placeholder="<?php esc_attr_e( 'Enter profile link', 'ulms' ); ?>" type="text" value="<?php echo ( isset( $_POST['account_additional_info']['facebook'] ) ) ? esc_url( $_POST['account_additional_info']['facebook'] ) : esc_url( get_user_meta( $user_info->ID, 'facebook', true ) ); ?>" />
					</div>
				</div>
				<div class="col-xs-12 col-sm-6 col-md-6 col-lg-6">
					<div class="input-group">
						<label for="account_twitter"><?php esc_html_e( 'Twitter', 'ulms' ); ?></label>
						<input id="account_twitter" class="form-control" name="account_additional_info[twitter]" placeholder="<?php esc_attr_e( 'Enter profile link', 'ulms' ); ?>" type="text" value="<?php echo ( isset( $_POST['account_additional_info']['twitter'] ) ) ? esc_url( $_POST['account_additional_info']['twitter'] ) : esc_url( get_user_meta( $user_info->ID, 'twitter', true ) ); ?>" />
					</div>
				</div>
			</div>
			<div class="row">
				<div class="col-xs-12 col-sm-6 col-md-6 col-lg-6">
					<div class="input-group">
						<label for="account_google_plus"><?php esc_html_e( 'Google+', 'ulms' ); ?></label>
						<input id="account_google_plus" class="form-control" name="account_additional_info[google_plus]" placeholder="<?php esc_attr_e( 'Enter profile link', 'ulms' ); ?>" type="text" value="<?php echo ( isset( $_POST['account_additional_info']['google_plus'] ) ) ? esc_url( $_POST['account_additional_info']['google_plus'] ) : esc_url( get_user_meta( $user_info->ID, 'google_plus', true ) ); ?>" />
					</div>
				</div>
				<div class="col-xs-12 col-sm-6 col-md-6 col-lg-6">
					<div class="input-group">
						<label for="account_linkedin"><?php esc_html_e( 'LinkedIn', 'ulms' ); ?></label>
						<input id="account_linkedin" class="form-control" name="account_additional_info[linkedin]" placeholder="<?php esc_attr_e( 'Enter profile link', 'ulms' ); ?>" type="text" value="<?php echo ( isset( $_POST['account_additional_info']['linkedin'] ) ) ? esc_url( $_POST['account_additional_info']['linkedin'] ) : esc_url( get_user_meta( $user_info->ID, 'linkedin', true ) ); ?>" />
					</div>
				</div>
			</div>
			<div class="row">
				<div class="col-xs-12 col-sm-6 col-md-6 col-lg-6">
					<div class="input-group">
						<label for="account_website"><?php esc_html_e( 'Website', 'ulms' ); ?></label>
						<input id="account_website" class="form-control" name="account_additional_info[website]" placeholder="<?php esc_attr_e( 'Enter your website', 'ulms' ); ?>" type="text" value="<?php echo ( isset( $_POST['account_additional_info']['website'] ) ) ? esc_url( $_POST['account_additional_info']['website'] ) : esc_url( $user_info->user_url ); ?>" />
					</div>
				</div>
			</div>
			<div class="input-group">
				<label for="account_bio"><?php esc_html_e( 'Bio', 'ulms' ); ?></label>
				<textarea id="account_bio" class="form-control" name="account_additional_info[description]"><?php echo ( isset( $_POST['account_additional_info']['description'] ) ) ? esc_attr( $_POST['account_additional_info']['description'] ) : esc_attr( get_user_meta( $user_info->ID, 'description', true ) ); ?></textarea>
			</div>
			<div class="account-submit-buttons">
				<div class="input-group">
					<button class="button"><?php esc_html_e( 'Save Changes', 'ulms' ); ?></button>
					<?php wp_nonce_field( 'runa-account-additional-settings-nonce', 'edit_account_additional_settings' ); ?>
				</div>
			</div>
		</form>
	</div>
</div>

<?php do_action( 'woocommerce_after_edit_account_form' ); ?>
