<?php
/**
 * Login Form
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/myaccount/form-login.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woothemes.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 2.6.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

?>

<div class="account-login-form-wr">
	<div class="account-login-form">
		<div class="account-login-form-left">
			<ul class="tab-nav" id="login_tabs">
				<li><a href="#login"<?php echo ( ! isset( $_GET['action'] ) || $_GET['action'] != 'register' ) ? ' class="active"' : ''; ?>><?php esc_html_e( 'Login', 'ulms' ); ?></a></li>
				<li><a href="#register"<?php echo ( ! empty( $_GET['action'] ) && $_GET['action'] == 'register' ) ? ' class="active"' : ''; ?>><?php esc_html_e( 'Register', 'ulms' ); ?></a></li>
			</ul>
			<div class="tab login<?php echo ( ! isset( $_GET['action'] ) || $_GET['action'] != 'register' ) ? ' active' : ''; ?>" id="login">
				<form action="" onsubmit="runa_login( jQuery(this) ); return false;" method="post">
					<div class="login-form">
						<div class="messages"></div>
						<div class="input-group">
							<div class="icon_wrapper">
								<input type="email" name="email" id="login-email" value="" placeholder="<?php esc_attr_e( 'E-mail', 'ulms' ); ?>" class="form-control" required />
								<label class="addon" for="login-email">
									<i class="fa fa-envelope-o"></i>
								</label>
							</div>
						</div>
						<div class="input-group">
							<div class="icon_wrapper">
								<input type="password" name="password" id="login-password" value="" placeholder="<?php esc_attr_e( 'Password', 'ulms' ); ?>" class="form-control" required />
								<label class="addon" for="login-password">
									<i class="fa fa-lock"></i>
								</label>
							</div>
						</div>
						<div class="input-group">
							<div class="remember_me">
								<label>
									<input type="checkbox" name="remember" value="1" /> <span class="uniform_label"><?php esc_html_e( 'Keep me signed in', 'ulms' ); ?></span>
								</label>
							</div>
							<div class="forgot_link"><a href="<?php echo wp_lostpassword_url( esc_url( home_url( '/' ) ) ); ?>"><?php esc_html_e( 'Forgot password?', 'ulms' ); ?></a></div>
						</div>
						<div class="input-group">
							<button class="button login-action">
								<span class="text"><?php esc_html_e( 'Login', 'ulms' ); ?></span>
								<span class="loader"></span>
							</button>
							<?php wp_nonce_field( 'runa-login-nonce', 'security' ); ?>
						</div>
					</div>
				</form>
				<?php if( class_exists( 'Runa_Social_Auth' ) && Runa_Social_Auth::$_auth_links ): ?>
					<div class="social-login-wr">
						<div class="social-login-title"><span><?php esc_html_e( 'or connect with', 'ulms' ); ?></span></div>
						<?php get_template_part( 'template-parts/social-auth-links' ); ?>
					</div>
				<?php endif; ?>
			</div>
			<div class="tab<?php echo ( ! empty( $_GET['action'] ) && $_GET['action'] == 'register' ) ? ' active' : ''; ?>" id="register">
				<form action="" onsubmit="runa_register( jQuery(this) ); return false;" method="post">
					<div class="login-form">
						<div class="messages"></div>
						<div class="input-group">
							<div class="icon_wrapper">
								<input type="email" name="email" id="register-email" value="" placeholder="<?php esc_attr_e( 'E-mail', 'ulms' ); ?>" class="form-control" required />
								<label class="addon" for="register-email">
									<i class="fa fa-envelope-o"></i>
								</label>
							</div>
						</div>
						<div class="input-group">
							<div class="icon_wrapper">
								<input type="password" name="password" id="register-password" value="" placeholder="<?php esc_attr_e( 'Password', 'ulms' ); ?>" class="form-control" required />
								<label class="addon" for="register-password">
									<i class="fa fa-lock"></i>
								</label>
							</div>
						</div>
						<div class="input-group">
							<div class="icon_wrapper">
								<input type="password" name="confirm" id="register-confirm" value="" placeholder="<?php esc_attr_e( 'Confirm Password', 'ulms' ); ?>" class="form-control" required />
								<label class="addon" for="register-confirm">
									<i class="fa fa-repeat"></i>
								</label>
							</div>
						</div>
						<div class="input-group">
							<button class="button login-action">
								<span class="text"><?php esc_html_e( 'Register', 'ulms' ); ?></span>
								<span class="loader"></span>
							</button>
							<?php wp_nonce_field( 'runa-register-nonce', 'security' ); ?>
						</div>
					</div>
				</form>
				<?php if( class_exists( 'Runa_Social_Auth' ) && Runa_Social_Auth::$_auth_links ): ?>
					<div class="social-login-wr">
						<div class="social-login-title"><span><?php esc_html_e( 'or connect with', 'ulms' ); ?></span></div>
						<?php get_template_part( 'template-parts/social-auth-links' ); ?>
					</div>
				<?php endif; ?>
			</div>
		</div>
		<div class="account-login-form-right" style="background-image: url( <?php echo esc_url( wp_get_attachment_image_url( ulms_option( 'login_page_image', false, 'id' ), 'large' ) ); ?> );">
			<div class="slogan">
				<h2><?php echo wp_kses_post( ulms_option( 'login_page_description' ) ); ?></h2>
			</div>
		</div>
	</div>
</div>
