<?php
/**
 * My Account navigation
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/myaccount/navigation.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woothemes.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 2.6.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

do_action( 'woocommerce_before_account_navigation' );
?>

<?php $user_info = wp_get_current_user(); ?>

<div class="account-sidebar">
	<div class="account-image">
		<a href="<?php echo esc_url( get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) ); ?>">
			<?php echo get_avatar( $user_info->ID, 120 ); ?>
		</a>
	</div>
	<div class="account-name">
		<h4>
			<a href="<?php echo esc_url( get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) ); ?>">
				<?php echo esc_html( $user_info->display_name ); ?>
			</a>
		</h4>
	</div>
	<div class="account-email">
		<a href="mailto:<?php echo antispambot( $user_info->user_email ); ?>"><?php echo antispambot( $user_info->user_email ); ?></a>
	</div>
	<div class="account-phone">
		<?php echo esc_html( get_user_meta( $user_info->ID, 'phone', true ) ); ?>
	</div>
	<ul class="account-nav">
		<?php foreach ( wc_get_account_menu_items() as $endpoint => $label ) : ?>
			<li class="<?php echo wc_get_account_menu_item_classes( $endpoint ); ?>">
				<a href="<?php echo esc_url( wc_get_account_endpoint_url( $endpoint ) ); ?>"><?php echo esc_html( $label ); ?></a>
			</li>
		<?php endforeach; ?>
	</ul>
	<?php
	$facebook    = get_user_meta( $user_info->ID, 'facebook', true );
	$twitter     = get_user_meta( $user_info->ID, 'twitter', true );
	$google_plus = get_user_meta( $user_info->ID, 'google_plus', true );
	$linkedin    = get_user_meta( $user_info->ID, 'linkedin', true );
	?>
	<?php if( $facebook || $twitter || $google_plus || $linkedin ): ?>
		<ul class="social_links">
			<?php if( $facebook ): ?>
				<li><a href="<?php echo esc_url( $facebook ); ?>" class="facebook"><i class="fa fa-facebook"></i></a></li>
			<?php endif; ?>
			<?php if( $twitter ): ?>
				<li><a href="<?php echo esc_url( $twitter ); ?>" class="twitter"><i class="fa fa-twitter"></i></a></li>
			<?php endif; ?>
			<?php if( $google_plus ): ?>
				<li><a href="<?php echo esc_url( $google_plus ); ?>" class="google-plus"><i class="fa fa-google-plus"></i></a></li>
			<?php endif; ?>
			<?php if( $linkedin ): ?>
				<li><a href="<?php echo esc_url( $linkedin ); ?>" class="linkedin"><i class="fa fa-linkedin"></i></a></li>
			<?php endif; ?>
		</ul>
	<?php endif; ?>
</div>

<?php do_action( 'woocommerce_after_account_navigation' ); ?>
