<?php
/**
 * Single Product Meta
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product/meta.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     1.6.4
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

global $post, $product;

$cat_count = sizeof( get_the_terms( $post->ID, 'product_cat' ) );
$tag_count = sizeof( get_the_terms( $post->ID, 'product_tag' ) );

?>
<div class="product_meta">

	<?php do_action( 'woocommerce_product_meta_start' ); ?>

	<?php if ( wc_product_sku_enabled() && ( $product->get_sku() || $product->is_type( 'variable' ) ) ) : ?>

		<span class="sku_wrapper"><?php esc_html_e( 'SKU:', 'ulms' ); ?> <span class="sku" itemprop="sku"><?php echo ( $sku = $product->get_sku() ) ? $sku : esc_html__( 'N/A', 'ulms' ); ?></span></span>

	<?php endif; ?>
	<?php
		$courses = get_post_meta( $post->ID, '_courses_included', true );
		$groups = get_post_meta( $post->ID, '_groups_included', true );
	?>
	<?php if( $courses || $groups ) : ?>
		<?php
		$courses_array = array();
		foreach( $courses as $key => $val ){
			$courses_array[] = '<a href="' . get_the_permalink( $val ) . '">' . get_the_title( $val ) . '</a>';
		}
		foreach( $groups as $key => $val ){
			$group_course_id = get_post_meta( $val, 'group_course', true );
			if( $group_course_id ){
				$courses_array[] = '<a href="' . get_the_permalink( $val ) . '">' . get_the_title( $group_course_id ) . ' - ' . get_the_title( $val ) . '</a>';
			}
		}
		?>
		<span class="courses_included">
			<span class="meta-title"><?php esc_html_e( 'Courses Included', 'ulms' ); ?></span>
			<?php echo implode( ', ', $courses_array ); ?>
		</span>
	<?php endif; ?>

	<?php echo $product->get_categories( ', ', '<span class="posted_in"><span class="meta-title">' . _n( 'Category:', 'Categories:', $cat_count, 'ulms' ) . '</span> ', '</span>' ); ?>

	<?php echo $product->get_tags( ', ', '<span class="tagged_as"><span class="meta-title">' . _n( 'Tag:', 'Tags:', $tag_count, 'ulms' ) . '</span> ', '</span>' ); ?>

	<?php do_action( 'woocommerce_product_meta_end' ); ?>

</div>
